#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

#include "libspotify/api.h"

/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_album *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 764), // sp_album *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_albumbrowse *)
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 765), // sp_albumbrowse *
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_albumbrowse *, int)
/*  7 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/*  9 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 10 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_artist *)
/* 11 */ _CFFI_OP(_CFFI_OP_POINTER, 767), // sp_artist *
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 13 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_artistbrowse *)
/* 14 */ _CFFI_OP(_CFFI_OP_POINTER, 768), // sp_artistbrowse *
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 16 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_error)
/* 17 */ _CFFI_OP(_CFFI_OP_ENUM, 11), // sp_error
/* 18 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 19 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_playlist *)
/* 20 */ _CFFI_OP(_CFFI_OP_POINTER, 778), // sp_playlist *
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_playlist *, int)
/* 23 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 24 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 25 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 26 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_search *)
/* 27 */ _CFFI_OP(_CFFI_OP_POINTER, 786), // sp_search *
/* 28 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 29 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_search *, int)
/* 30 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 31 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 32 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 33 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_session *)
/* 34 */ _CFFI_OP(_CFFI_OP_POINTER, 787), // sp_session *
/* 35 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_track *)
/* 37 */ _CFFI_OP(_CFFI_OP_POINTER, 793), // sp_track *
/* 38 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 39 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(sp_user *)
/* 40 */ _CFFI_OP(_CFFI_OP_POINTER, 796), // sp_user *
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // char const *()(void)
/* 43 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 44 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_album *)
/* 45 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 46 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_albumbrowse *)
/* 48 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 49 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 50 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_artistbrowse *)
/* 51 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 52 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_link *, char *, int)
/* 54 */ _CFFI_OP(_CFFI_OP_POINTER, 775), // sp_link *
/* 55 */ _CFFI_OP(_CFFI_OP_POINTER, 762), // char *
/* 56 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 57 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_playlist *)
/* 59 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 60 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_playlist *, int)
/* 62 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 63 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 64 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_playlistcontainer *)
/* 66 */ _CFFI_OP(_CFFI_OP_POINTER, 782), // sp_playlistcontainer *
/* 67 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 68 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_playlistcontainer *, sp_playlist *)
/* 69 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 70 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 71 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 72 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_playlistcontainer *, sp_playlist *, sp_track * *, int)
/* 73 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 74 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 75 */ _CFFI_OP(_CFFI_OP_POINTER, 37), // sp_track * *
/* 76 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 77 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 78 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_search *)
/* 79 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 80 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 81 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_session *)
/* 82 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 83 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 84 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_session *, char *, size_t)
/* 85 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 86 */ _CFFI_OP(_CFFI_OP_NOOP, 55),
/* 87 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 89 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_session *, sp_audioformat const *, void const *, int)
/* 90 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 91 */ _CFFI_OP(_CFFI_OP_POINTER, 770), // sp_audioformat const *
/* 92 */ _CFFI_OP(_CFFI_OP_POINTER, 817), // void const *
/* 93 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 94 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 95 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_session *, sp_playlist *)
/* 96 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 97 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 98 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 99 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_toplistbrowse *)
/* 100 */ _CFFI_OP(_CFFI_OP_POINTER, 792), // sp_toplistbrowse *
/* 101 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 102 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // int()(sp_track *)
/* 103 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 104 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 105 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // sp_album *()(sp_albumbrowse *)
/* 106 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 107 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 108 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // sp_album *()(sp_artistbrowse *, int)
/* 109 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 110 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 111 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 112 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // sp_album *()(sp_link *)
/* 113 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 114 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 115 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // sp_album *()(sp_search *, int)
/* 116 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 117 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 118 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 119 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // sp_album *()(sp_toplistbrowse *, int)
/* 120 */ _CFFI_OP(_CFFI_OP_NOOP, 100),
/* 121 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 122 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 123 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // sp_album *()(sp_track *)
/* 124 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 125 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 126 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // sp_albumbrowse *()(sp_session *, sp_album *, void(*)(sp_albumbrowse *, void *), void *)
/* 127 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 128 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 129 */ _CFFI_OP(_CFFI_OP_POINTER, 642), // void(*)(sp_albumbrowse *, void *)
/* 130 */ _CFFI_OP(_CFFI_OP_POINTER, 817), // void *
/* 131 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 132 */ _CFFI_OP(_CFFI_OP_FUNCTION, 766), // sp_albumtype()(sp_album *)
/* 133 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 134 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 135 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // sp_artist *()(sp_album *)
/* 136 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 137 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 138 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // sp_artist *()(sp_albumbrowse *)
/* 139 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 140 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 141 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // sp_artist *()(sp_artistbrowse *)
/* 142 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 143 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 144 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // sp_artist *()(sp_artistbrowse *, int)
/* 145 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 146 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 147 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 148 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // sp_artist *()(sp_link *)
/* 149 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 150 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 151 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // sp_artist *()(sp_search *, int)
/* 152 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 153 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 154 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 155 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // sp_artist *()(sp_toplistbrowse *, int)
/* 156 */ _CFFI_OP(_CFFI_OP_NOOP, 100),
/* 157 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 158 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 159 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // sp_artist *()(sp_track *, int)
/* 160 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 161 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 162 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 163 */ _CFFI_OP(_CFFI_OP_FUNCTION, 14), // sp_artistbrowse *()(sp_session *, sp_artist *, sp_artistbrowse_type, void(*)(sp_artistbrowse *, void *), void *)
/* 164 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 165 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 166 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // sp_artistbrowse_type
/* 167 */ _CFFI_OP(_CFFI_OP_POINTER, 646), // void(*)(sp_artistbrowse *, void *)
/* 168 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 169 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 170 */ _CFFI_OP(_CFFI_OP_FUNCTION, 771), // sp_connectionstate()(sp_session *)
/* 171 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 172 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 173 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_album *)
/* 174 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 175 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 176 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_albumbrowse *)
/* 177 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 178 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 179 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_artist *)
/* 180 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 181 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 182 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_artistbrowse *)
/* 183 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 184 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 185 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_image *)
/* 186 */ _CFFI_OP(_CFFI_OP_POINTER, 772), // sp_image *
/* 187 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 188 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_image *, void(*)(sp_image *, void *), void *)
/* 189 */ _CFFI_OP(_CFFI_OP_NOOP, 186),
/* 190 */ _CFFI_OP(_CFFI_OP_POINTER, 650), // void(*)(sp_image *, void *)
/* 191 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 192 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 193 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_inbox *)
/* 194 */ _CFFI_OP(_CFFI_OP_POINTER, 774), // sp_inbox *
/* 195 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 196 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_link *)
/* 197 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 198 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 199 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlist *)
/* 200 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 201 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 202 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlist *, char const *)
/* 203 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 204 */ _CFFI_OP(_CFFI_OP_POINTER, 762), // char const *
/* 205 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 206 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlist *, int const *, int)
/* 207 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 208 */ _CFFI_OP(_CFFI_OP_POINTER, 8), // int const *
/* 209 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 210 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 211 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlist *, int const *, int, int)
/* 212 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 213 */ _CFFI_OP(_CFFI_OP_NOOP, 208),
/* 214 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 215 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 216 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 217 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlist *, int, unsigned char)
/* 218 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 219 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 220 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 221 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 222 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlist *, sp_playlist_callbacks *, void *)
/* 223 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 224 */ _CFFI_OP(_CFFI_OP_POINTER, 779), // sp_playlist_callbacks *
/* 225 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 226 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 227 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlist *, sp_track * const *, int, int, sp_session *)
/* 228 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 229 */ _CFFI_OP(_CFFI_OP_POINTER, 37), // sp_track * const *
/* 230 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 231 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 232 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 233 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 234 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlist *, unsigned char)
/* 235 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 236 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 237 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 238 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlistcontainer *)
/* 239 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 240 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 241 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlistcontainer *, int)
/* 242 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 243 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 244 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 245 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlistcontainer *, int, char *, int)
/* 246 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 247 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 248 */ _CFFI_OP(_CFFI_OP_NOOP, 55),
/* 249 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 250 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 251 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlistcontainer *, int, char const *)
/* 252 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 253 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 254 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 255 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 256 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlistcontainer *, int, int, unsigned char)
/* 257 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 258 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 259 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 260 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 261 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 262 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_playlistcontainer *, sp_playlistcontainer_callbacks *, void *)
/* 263 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 264 */ _CFFI_OP(_CFFI_OP_POINTER, 783), // sp_playlistcontainer_callbacks *
/* 265 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 266 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 267 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_search *)
/* 268 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 269 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 270 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *)
/* 271 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 272 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 273 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, char const *, char const *, unsigned char, char const *)
/* 274 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 275 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 276 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 277 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 278 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 279 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 280 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, int *)
/* 281 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 282 */ _CFFI_OP(_CFFI_OP_POINTER, 8), // int *
/* 283 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 284 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, int)
/* 285 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 286 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 287 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 288 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, size_t)
/* 289 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 290 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 291 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 292 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_bitrate)
/* 293 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 294 */ _CFFI_OP(_CFFI_OP_ENUM, 7), // sp_bitrate
/* 295 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 296 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_bitrate, unsigned char)
/* 297 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 298 */ _CFFI_OP(_CFFI_OP_NOOP, 294),
/* 299 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 300 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 301 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_connection_rules)
/* 302 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 303 */ _CFFI_OP(_CFFI_OP_ENUM, 8), // sp_connection_rules
/* 304 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 305 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_connection_type)
/* 306 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 307 */ _CFFI_OP(_CFFI_OP_ENUM, 9), // sp_connection_type
/* 308 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 309 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_playlist *)
/* 310 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 311 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 312 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 313 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_playlist *, unsigned char)
/* 314 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 315 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 316 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 317 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 318 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_social_provider, char const *, char const *)
/* 319 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 320 */ _CFFI_OP(_CFFI_OP_ENUM, 19), // sp_social_provider
/* 321 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 322 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 323 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 324 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_social_provider, sp_scrobbling_state *)
/* 325 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 326 */ _CFFI_OP(_CFFI_OP_NOOP, 320),
/* 327 */ _CFFI_OP(_CFFI_OP_POINTER, 332), // sp_scrobbling_state *
/* 328 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 329 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_social_provider, sp_scrobbling_state)
/* 330 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 331 */ _CFFI_OP(_CFFI_OP_NOOP, 320),
/* 332 */ _CFFI_OP(_CFFI_OP_ENUM, 17), // sp_scrobbling_state
/* 333 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 334 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_social_provider, unsigned char *)
/* 335 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 336 */ _CFFI_OP(_CFFI_OP_NOOP, 320),
/* 337 */ _CFFI_OP(_CFFI_OP_POINTER, 220), // unsigned char *
/* 338 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 339 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_track * const *, int, unsigned char)
/* 340 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 341 */ _CFFI_OP(_CFFI_OP_NOOP, 229),
/* 342 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 343 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 344 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 345 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, sp_track *)
/* 346 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 347 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 348 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 349 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session *, unsigned char)
/* 350 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 351 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 352 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 353 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_session_config const *, sp_session * *)
/* 354 */ _CFFI_OP(_CFFI_OP_POINTER, 790), // sp_session_config const *
/* 355 */ _CFFI_OP(_CFFI_OP_POINTER, 34), // sp_session * *
/* 356 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 357 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_subscribers *)
/* 358 */ _CFFI_OP(_CFFI_OP_POINTER, 791), // sp_subscribers *
/* 359 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 360 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_toplistbrowse *)
/* 361 */ _CFFI_OP(_CFFI_OP_NOOP, 100),
/* 362 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 363 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_track *)
/* 364 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 365 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 366 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // sp_error()(sp_user *)
/* 367 */ _CFFI_OP(_CFFI_OP_NOOP, 40),
/* 368 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 369 */ _CFFI_OP(_CFFI_OP_FUNCTION, 186), // sp_image *()(sp_session *, sp_link *)
/* 370 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 371 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 372 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 373 */ _CFFI_OP(_CFFI_OP_FUNCTION, 186), // sp_image *()(sp_session *, unsigned char const *)
/* 374 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 375 */ _CFFI_OP(_CFFI_OP_POINTER, 220), // unsigned char const *
/* 376 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 377 */ _CFFI_OP(_CFFI_OP_FUNCTION, 773), // sp_imageformat()(sp_image *)
/* 378 */ _CFFI_OP(_CFFI_OP_NOOP, 186),
/* 379 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 380 */ _CFFI_OP(_CFFI_OP_FUNCTION, 194), // sp_inbox *()(sp_session *, char const *, sp_track * const *, int, char const *, void(*)(sp_inbox *, void *), void *)
/* 381 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 382 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 383 */ _CFFI_OP(_CFFI_OP_NOOP, 229),
/* 384 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 385 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 386 */ _CFFI_OP(_CFFI_OP_POINTER, 654), // void(*)(sp_inbox *, void *)
/* 387 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 388 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 389 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(char const *)
/* 390 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 391 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 392 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_album *)
/* 393 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 394 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 395 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_album *, sp_image_size)
/* 396 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 397 */ _CFFI_OP(_CFFI_OP_ENUM, 12), // sp_image_size
/* 398 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 399 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_artist *)
/* 400 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 401 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 402 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_artist *, sp_image_size)
/* 403 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 404 */ _CFFI_OP(_CFFI_OP_NOOP, 397),
/* 405 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 406 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_artistbrowse *, int)
/* 407 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 408 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 409 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 410 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_image *)
/* 411 */ _CFFI_OP(_CFFI_OP_NOOP, 186),
/* 412 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 413 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_playlist *)
/* 414 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 415 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 416 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_search *)
/* 417 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 418 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 419 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_track *, int)
/* 420 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 421 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 422 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 423 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // sp_link *()(sp_user *)
/* 424 */ _CFFI_OP(_CFFI_OP_NOOP, 40),
/* 425 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 426 */ _CFFI_OP(_CFFI_OP_FUNCTION, 776), // sp_linktype()(sp_link *)
/* 427 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 428 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 429 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // sp_playlist *()(sp_playlistcontainer *, char const *)
/* 430 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 431 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 432 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 433 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // sp_playlist *()(sp_playlistcontainer *, int)
/* 434 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 435 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 436 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 437 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // sp_playlist *()(sp_playlistcontainer *, sp_link *)
/* 438 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 439 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 440 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 441 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // sp_playlist *()(sp_search *, int)
/* 442 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 443 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 444 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 445 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // sp_playlist *()(sp_session *)
/* 446 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 447 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 448 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // sp_playlist *()(sp_session *, char const *)
/* 449 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 450 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 451 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 452 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // sp_playlist *()(sp_session *, sp_link *)
/* 453 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 454 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 455 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 456 */ _CFFI_OP(_CFFI_OP_FUNCTION, 780), // sp_playlist_offline_status()(sp_session *, sp_playlist *)
/* 457 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 458 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 459 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 460 */ _CFFI_OP(_CFFI_OP_FUNCTION, 781), // sp_playlist_type()(sp_playlistcontainer *, int)
/* 461 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 462 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 463 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 464 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // sp_playlistcontainer *()(sp_session *)
/* 465 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 466 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 467 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // sp_playlistcontainer *()(sp_session *, char const *)
/* 468 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 469 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 470 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 471 */ _CFFI_OP(_CFFI_OP_FUNCTION, 27), // sp_search *()(sp_session *, char const *, int, int, int, int, int, int, int, int, sp_search_type, void(*)(sp_search *, void *), void *)
/* 472 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 473 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 474 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 475 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 476 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 477 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 478 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 479 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 480 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 481 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 482 */ _CFFI_OP(_CFFI_OP_ENUM, 18), // sp_search_type
/* 483 */ _CFFI_OP(_CFFI_OP_POINTER, 733), // void(*)(sp_search *, void *)
/* 484 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 485 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 486 */ _CFFI_OP(_CFFI_OP_FUNCTION, 358), // sp_subscribers *()(sp_playlist *)
/* 487 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 488 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 489 */ _CFFI_OP(_CFFI_OP_FUNCTION, 100), // sp_toplistbrowse *()(sp_session *, sp_toplisttype, sp_toplistregion, char const *, void(*)(sp_toplistbrowse *, void *), void *)
/* 490 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 491 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // sp_toplisttype
/* 492 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // sp_toplistregion
/* 493 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 494 */ _CFFI_OP(_CFFI_OP_POINTER, 756), // void(*)(sp_toplistbrowse *, void *)
/* 495 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 496 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 497 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(char const *, char const *, char const *, int)
/* 498 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 499 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 500 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 501 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 502 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 503 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(sp_albumbrowse *, int)
/* 504 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 505 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 506 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 507 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(sp_artistbrowse *, int)
/* 508 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 509 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 510 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 511 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(sp_link *)
/* 512 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 513 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 514 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(sp_link *, int *)
/* 515 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 516 */ _CFFI_OP(_CFFI_OP_NOOP, 282),
/* 517 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 518 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(sp_playlist *, int)
/* 519 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 520 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 521 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 522 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(sp_search *, int)
/* 523 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 524 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 525 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 526 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(sp_session *, sp_track *)
/* 527 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 528 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 529 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 530 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // sp_track *()(sp_toplistbrowse *, int)
/* 531 */ _CFFI_OP(_CFFI_OP_NOOP, 100),
/* 532 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 533 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 534 */ _CFFI_OP(_CFFI_OP_FUNCTION, 794), // sp_track_availability()(sp_session *, sp_track *)
/* 535 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 536 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 537 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 538 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // sp_track_offline_status()(sp_track *)
/* 539 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 540 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 541 */ _CFFI_OP(_CFFI_OP_FUNCTION, 40), // sp_user *()(sp_link *)
/* 542 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 543 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 544 */ _CFFI_OP(_CFFI_OP_FUNCTION, 40), // sp_user *()(sp_playlist *)
/* 545 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 546 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 547 */ _CFFI_OP(_CFFI_OP_FUNCTION, 40), // sp_user *()(sp_playlist *, int)
/* 548 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 549 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 550 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 551 */ _CFFI_OP(_CFFI_OP_FUNCTION, 40), // sp_user *()(sp_playlistcontainer *)
/* 552 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 553 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 554 */ _CFFI_OP(_CFFI_OP_FUNCTION, 40), // sp_user *()(sp_session *)
/* 555 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 556 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 557 */ _CFFI_OP(_CFFI_OP_FUNCTION, 797), // uint64_t()(sp_playlistcontainer *, int)
/* 558 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 559 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 560 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 561 */ _CFFI_OP(_CFFI_OP_FUNCTION, 375), // unsigned char const *()(sp_album *, sp_image_size)
/* 562 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 563 */ _CFFI_OP(_CFFI_OP_NOOP, 397),
/* 564 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 565 */ _CFFI_OP(_CFFI_OP_FUNCTION, 375), // unsigned char const *()(sp_artist *, sp_image_size)
/* 566 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 567 */ _CFFI_OP(_CFFI_OP_NOOP, 397),
/* 568 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 569 */ _CFFI_OP(_CFFI_OP_FUNCTION, 375), // unsigned char const *()(sp_artistbrowse *, int)
/* 570 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 571 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 572 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 573 */ _CFFI_OP(_CFFI_OP_FUNCTION, 375), // unsigned char const *()(sp_image *)
/* 574 */ _CFFI_OP(_CFFI_OP_NOOP, 186),
/* 575 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 576 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_album *)
/* 577 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 578 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 579 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_albumbrowse *)
/* 580 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 581 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 582 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_artist *)
/* 583 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 584 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 585 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_artistbrowse *)
/* 586 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 587 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 588 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_image *)
/* 589 */ _CFFI_OP(_CFFI_OP_NOOP, 186),
/* 590 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 591 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_playlist *)
/* 592 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 593 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 594 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_playlist *, int)
/* 595 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 596 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 597 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 598 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_playlist *, unsigned char *)
/* 599 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 600 */ _CFFI_OP(_CFFI_OP_NOOP, 337),
/* 601 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 602 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_playlistcontainer *)
/* 603 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 604 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 605 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_search *)
/* 606 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 607 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 608 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_session *)
/* 609 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 610 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 611 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_session *, sp_offline_sync_status *)
/* 612 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 613 */ _CFFI_OP(_CFFI_OP_POINTER, 777), // sp_offline_sync_status *
/* 614 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 615 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_session *, sp_playlist *)
/* 616 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 617 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 618 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 619 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_session *, sp_track *)
/* 620 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 621 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 622 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 623 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_toplistbrowse *)
/* 624 */ _CFFI_OP(_CFFI_OP_NOOP, 100),
/* 625 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 626 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_track *)
/* 627 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 628 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 629 */ _CFFI_OP(_CFFI_OP_FUNCTION, 220), // unsigned char()(sp_user *)
/* 630 */ _CFFI_OP(_CFFI_OP_NOOP, 40),
/* 631 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 632 */ _CFFI_OP(_CFFI_OP_FUNCTION, 798), // unsigned int()(sp_playlist *)
/* 633 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 634 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 635 */ _CFFI_OP(_CFFI_OP_FUNCTION, 130), // void *()(sp_session *)
/* 636 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 637 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 638 */ _CFFI_OP(_CFFI_OP_FUNCTION, 92), // void const *()(sp_image *, size_t *)
/* 639 */ _CFFI_OP(_CFFI_OP_NOOP, 186),
/* 640 */ _CFFI_OP(_CFFI_OP_POINTER, 87), // size_t *
/* 641 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 642 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_albumbrowse *, void *)
/* 643 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 644 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 645 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 646 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_artistbrowse *, void *)
/* 647 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 648 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 649 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 650 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_image *, void *)
/* 651 */ _CFFI_OP(_CFFI_OP_NOOP, 186),
/* 652 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 653 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 654 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_inbox *, void *)
/* 655 */ _CFFI_OP(_CFFI_OP_NOOP, 194),
/* 656 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 657 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 658 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, char const *, void *)
/* 659 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 660 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 661 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 662 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 663 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, int const *, int, int, void *)
/* 664 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 665 */ _CFFI_OP(_CFFI_OP_NOOP, 208),
/* 666 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 667 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 668 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 669 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 670 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, int const *, int, void *)
/* 671 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 672 */ _CFFI_OP(_CFFI_OP_NOOP, 208),
/* 673 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 674 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 675 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 676 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, int, char const *, void *)
/* 677 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 678 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 679 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 680 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 681 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 682 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, int, sp_user *, int, void *)
/* 683 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 684 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 685 */ _CFFI_OP(_CFFI_OP_NOOP, 40),
/* 686 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 687 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 688 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 689 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, int, unsigned char, void *)
/* 690 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 691 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 692 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 693 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 694 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 695 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, sp_track * const *, int, int, void *)
/* 696 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 697 */ _CFFI_OP(_CFFI_OP_NOOP, 229),
/* 698 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 699 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 700 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 701 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 702 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, unsigned char const *, void *)
/* 703 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 704 */ _CFFI_OP(_CFFI_OP_NOOP, 375),
/* 705 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 706 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 707 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, unsigned char, void *)
/* 708 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 709 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 710 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 711 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 712 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlist *, void *)
/* 713 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 714 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 715 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 716 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlistcontainer *, sp_playlist *, int, int, void *)
/* 717 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 718 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 719 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 720 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 721 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 722 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 723 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlistcontainer *, sp_playlist *, int, void *)
/* 724 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 725 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 726 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 727 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 728 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 729 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_playlistcontainer *, void *)
/* 730 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 731 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 732 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 733 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_search *, void *)
/* 734 */ _CFFI_OP(_CFFI_OP_NOOP, 27),
/* 735 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 736 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 737 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_session *)
/* 738 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 739 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 740 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_session *, char const *)
/* 741 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 742 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 743 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 744 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_session *, sp_audio_buffer_stats *)
/* 745 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 746 */ _CFFI_OP(_CFFI_OP_POINTER, 769), // sp_audio_buffer_stats *
/* 747 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 748 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_session *, sp_error)
/* 749 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 750 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 751 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 752 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_session *, unsigned char)
/* 753 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 754 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 755 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 756 */ _CFFI_OP(_CFFI_OP_FUNCTION, 817), // void()(sp_toplistbrowse *, void *)
/* 757 */ _CFFI_OP(_CFFI_OP_NOOP, 100),
/* 758 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 759 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 760 */ _CFFI_OP(_CFFI_OP_ARRAY, 55), // char *[1]
/* 761 */ (_cffi_opcode_t)(1),
/* 762 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 763 */ _CFFI_OP(_CFFI_OP_POINTER, 89), // int(*)(sp_session *, sp_audioformat const *, void const *, int)
/* 764 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // sp_album
/* 765 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // sp_albumbrowse
/* 766 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // sp_albumtype
/* 767 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // sp_artist
/* 768 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // sp_artistbrowse
/* 769 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // sp_audio_buffer_stats
/* 770 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // sp_audioformat
/* 771 */ _CFFI_OP(_CFFI_OP_ENUM, 10), // sp_connectionstate
/* 772 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // sp_image
/* 773 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // sp_imageformat
/* 774 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // sp_inbox
/* 775 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // sp_link
/* 776 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // sp_linktype
/* 777 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // sp_offline_sync_status
/* 778 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // sp_playlist
/* 779 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // sp_playlist_callbacks
/* 780 */ _CFFI_OP(_CFFI_OP_ENUM, 13), // sp_playlist_offline_status
/* 781 */ _CFFI_OP(_CFFI_OP_ENUM, 14), // sp_playlist_type
/* 782 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // sp_playlistcontainer
/* 783 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // sp_playlistcontainer_callbacks
/* 784 */ _CFFI_OP(_CFFI_OP_ENUM, 15), // sp_relation_type
/* 785 */ _CFFI_OP(_CFFI_OP_ENUM, 16), // sp_sampletype
/* 786 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 14), // sp_search
/* 787 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 15), // sp_session
/* 788 */ _CFFI_OP(_CFFI_OP_POINTER, 789), // sp_session_callbacks const *
/* 789 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 16), // sp_session_callbacks
/* 790 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 17), // sp_session_config
/* 791 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 18), // sp_subscribers
/* 792 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 19), // sp_toplistbrowse
/* 793 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 20), // sp_track
/* 794 */ _CFFI_OP(_CFFI_OP_ENUM, 6), // sp_track_availability
/* 795 */ _CFFI_OP(_CFFI_OP_ENUM, 20), // sp_track_offline_status
/* 796 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 21), // sp_user
/* 797 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 24), // uint64_t
/* 798 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 799 */ _CFFI_OP(_CFFI_OP_POINTER, 658), // void(*)(sp_playlist *, char const *, void *)
/* 800 */ _CFFI_OP(_CFFI_OP_POINTER, 663), // void(*)(sp_playlist *, int const *, int, int, void *)
/* 801 */ _CFFI_OP(_CFFI_OP_POINTER, 670), // void(*)(sp_playlist *, int const *, int, void *)
/* 802 */ _CFFI_OP(_CFFI_OP_POINTER, 676), // void(*)(sp_playlist *, int, char const *, void *)
/* 803 */ _CFFI_OP(_CFFI_OP_POINTER, 682), // void(*)(sp_playlist *, int, sp_user *, int, void *)
/* 804 */ _CFFI_OP(_CFFI_OP_POINTER, 689), // void(*)(sp_playlist *, int, unsigned char, void *)
/* 805 */ _CFFI_OP(_CFFI_OP_POINTER, 695), // void(*)(sp_playlist *, sp_track * const *, int, int, void *)
/* 806 */ _CFFI_OP(_CFFI_OP_POINTER, 702), // void(*)(sp_playlist *, unsigned char const *, void *)
/* 807 */ _CFFI_OP(_CFFI_OP_POINTER, 707), // void(*)(sp_playlist *, unsigned char, void *)
/* 808 */ _CFFI_OP(_CFFI_OP_POINTER, 712), // void(*)(sp_playlist *, void *)
/* 809 */ _CFFI_OP(_CFFI_OP_POINTER, 716), // void(*)(sp_playlistcontainer *, sp_playlist *, int, int, void *)
/* 810 */ _CFFI_OP(_CFFI_OP_POINTER, 723), // void(*)(sp_playlistcontainer *, sp_playlist *, int, void *)
/* 811 */ _CFFI_OP(_CFFI_OP_POINTER, 729), // void(*)(sp_playlistcontainer *, void *)
/* 812 */ _CFFI_OP(_CFFI_OP_POINTER, 737), // void(*)(sp_session *)
/* 813 */ _CFFI_OP(_CFFI_OP_POINTER, 740), // void(*)(sp_session *, char const *)
/* 814 */ _CFFI_OP(_CFFI_OP_POINTER, 744), // void(*)(sp_session *, sp_audio_buffer_stats *)
/* 815 */ _CFFI_OP(_CFFI_OP_POINTER, 748), // void(*)(sp_session *, sp_error)
/* 816 */ _CFFI_OP(_CFFI_OP_POINTER, 752), // void(*)(sp_session *, unsigned char)
/* 817 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_SP_ALBUMTYPE_ALBUM(unsigned long long *o)
{
  int n = (SP_ALBUMTYPE_ALBUM) <= 0;
  *o = (unsigned long long)((SP_ALBUMTYPE_ALBUM) | 0);  /* check that SP_ALBUMTYPE_ALBUM is an integer */
  return n;
}

static int _cffi_const_SP_ALBUMTYPE_SINGLE(unsigned long long *o)
{
  int n = (SP_ALBUMTYPE_SINGLE) <= 0;
  *o = (unsigned long long)((SP_ALBUMTYPE_SINGLE) | 0);  /* check that SP_ALBUMTYPE_SINGLE is an integer */
  return n;
}

static int _cffi_const_SP_ALBUMTYPE_COMPILATION(unsigned long long *o)
{
  int n = (SP_ALBUMTYPE_COMPILATION) <= 0;
  *o = (unsigned long long)((SP_ALBUMTYPE_COMPILATION) | 0);  /* check that SP_ALBUMTYPE_COMPILATION is an integer */
  return n;
}

static int _cffi_const_SP_ALBUMTYPE_UNKNOWN(unsigned long long *o)
{
  int n = (SP_ALBUMTYPE_UNKNOWN) <= 0;
  *o = (unsigned long long)((SP_ALBUMTYPE_UNKNOWN) | 0);  /* check that SP_ALBUMTYPE_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_SP_IMAGE_FORMAT_UNKNOWN(unsigned long long *o)
{
  int n = (SP_IMAGE_FORMAT_UNKNOWN) <= 0;
  *o = (unsigned long long)((SP_IMAGE_FORMAT_UNKNOWN) | 0);  /* check that SP_IMAGE_FORMAT_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_SP_IMAGE_FORMAT_JPEG(unsigned long long *o)
{
  int n = (SP_IMAGE_FORMAT_JPEG) <= 0;
  *o = (unsigned long long)((SP_IMAGE_FORMAT_JPEG) | 0);  /* check that SP_IMAGE_FORMAT_JPEG is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_INVALID(unsigned long long *o)
{
  int n = (SP_LINKTYPE_INVALID) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_INVALID) | 0);  /* check that SP_LINKTYPE_INVALID is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_TRACK(unsigned long long *o)
{
  int n = (SP_LINKTYPE_TRACK) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_TRACK) | 0);  /* check that SP_LINKTYPE_TRACK is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_ALBUM(unsigned long long *o)
{
  int n = (SP_LINKTYPE_ALBUM) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_ALBUM) | 0);  /* check that SP_LINKTYPE_ALBUM is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_ARTIST(unsigned long long *o)
{
  int n = (SP_LINKTYPE_ARTIST) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_ARTIST) | 0);  /* check that SP_LINKTYPE_ARTIST is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_SEARCH(unsigned long long *o)
{
  int n = (SP_LINKTYPE_SEARCH) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_SEARCH) | 0);  /* check that SP_LINKTYPE_SEARCH is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_PLAYLIST(unsigned long long *o)
{
  int n = (SP_LINKTYPE_PLAYLIST) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_PLAYLIST) | 0);  /* check that SP_LINKTYPE_PLAYLIST is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_PROFILE(unsigned long long *o)
{
  int n = (SP_LINKTYPE_PROFILE) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_PROFILE) | 0);  /* check that SP_LINKTYPE_PROFILE is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_STARRED(unsigned long long *o)
{
  int n = (SP_LINKTYPE_STARRED) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_STARRED) | 0);  /* check that SP_LINKTYPE_STARRED is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_LOCALTRACK(unsigned long long *o)
{
  int n = (SP_LINKTYPE_LOCALTRACK) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_LOCALTRACK) | 0);  /* check that SP_LINKTYPE_LOCALTRACK is an integer */
  return n;
}

static int _cffi_const_SP_LINKTYPE_IMAGE(unsigned long long *o)
{
  int n = (SP_LINKTYPE_IMAGE) <= 0;
  *o = (unsigned long long)((SP_LINKTYPE_IMAGE) | 0);  /* check that SP_LINKTYPE_IMAGE is an integer */
  return n;
}

static int _cffi_const_SP_TOPLIST_REGION_EVERYWHERE(unsigned long long *o)
{
  int n = (SP_TOPLIST_REGION_EVERYWHERE) <= 0;
  *o = (unsigned long long)((SP_TOPLIST_REGION_EVERYWHERE) | 0);  /* check that SP_TOPLIST_REGION_EVERYWHERE is an integer */
  return n;
}

static int _cffi_const_SP_TOPLIST_REGION_USER(unsigned long long *o)
{
  int n = (SP_TOPLIST_REGION_USER) <= 0;
  *o = (unsigned long long)((SP_TOPLIST_REGION_USER) | 0);  /* check that SP_TOPLIST_REGION_USER is an integer */
  return n;
}

static int _cffi_const_SP_TOPLIST_TYPE_ARTISTS(unsigned long long *o)
{
  int n = (SP_TOPLIST_TYPE_ARTISTS) <= 0;
  *o = (unsigned long long)((SP_TOPLIST_TYPE_ARTISTS) | 0);  /* check that SP_TOPLIST_TYPE_ARTISTS is an integer */
  return n;
}

static int _cffi_const_SP_TOPLIST_TYPE_ALBUMS(unsigned long long *o)
{
  int n = (SP_TOPLIST_TYPE_ALBUMS) <= 0;
  *o = (unsigned long long)((SP_TOPLIST_TYPE_ALBUMS) | 0);  /* check that SP_TOPLIST_TYPE_ALBUMS is an integer */
  return n;
}

static int _cffi_const_SP_TOPLIST_TYPE_TRACKS(unsigned long long *o)
{
  int n = (SP_TOPLIST_TYPE_TRACKS) <= 0;
  *o = (unsigned long long)((SP_TOPLIST_TYPE_TRACKS) | 0);  /* check that SP_TOPLIST_TYPE_TRACKS is an integer */
  return n;
}

static int _cffi_const_SP_ARTISTBROWSE_FULL(unsigned long long *o)
{
  int n = (SP_ARTISTBROWSE_FULL) <= 0;
  *o = (unsigned long long)((SP_ARTISTBROWSE_FULL) | 0);  /* check that SP_ARTISTBROWSE_FULL is an integer */
  return n;
}

static int _cffi_const_SP_ARTISTBROWSE_NO_TRACKS(unsigned long long *o)
{
  int n = (SP_ARTISTBROWSE_NO_TRACKS) <= 0;
  *o = (unsigned long long)((SP_ARTISTBROWSE_NO_TRACKS) | 0);  /* check that SP_ARTISTBROWSE_NO_TRACKS is an integer */
  return n;
}

static int _cffi_const_SP_ARTISTBROWSE_NO_ALBUMS(unsigned long long *o)
{
  int n = (SP_ARTISTBROWSE_NO_ALBUMS) <= 0;
  *o = (unsigned long long)((SP_ARTISTBROWSE_NO_ALBUMS) | 0);  /* check that SP_ARTISTBROWSE_NO_ALBUMS is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_AVAILABILITY_UNAVAILABLE(unsigned long long *o)
{
  int n = (SP_TRACK_AVAILABILITY_UNAVAILABLE) <= 0;
  *o = (unsigned long long)((SP_TRACK_AVAILABILITY_UNAVAILABLE) | 0);  /* check that SP_TRACK_AVAILABILITY_UNAVAILABLE is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_AVAILABILITY_AVAILABLE(unsigned long long *o)
{
  int n = (SP_TRACK_AVAILABILITY_AVAILABLE) <= 0;
  *o = (unsigned long long)((SP_TRACK_AVAILABILITY_AVAILABLE) | 0);  /* check that SP_TRACK_AVAILABILITY_AVAILABLE is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_AVAILABILITY_NOT_STREAMABLE(unsigned long long *o)
{
  int n = (SP_TRACK_AVAILABILITY_NOT_STREAMABLE) <= 0;
  *o = (unsigned long long)((SP_TRACK_AVAILABILITY_NOT_STREAMABLE) | 0);  /* check that SP_TRACK_AVAILABILITY_NOT_STREAMABLE is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_AVAILABILITY_BANNED_BY_ARTIST(unsigned long long *o)
{
  int n = (SP_TRACK_AVAILABILITY_BANNED_BY_ARTIST) <= 0;
  *o = (unsigned long long)((SP_TRACK_AVAILABILITY_BANNED_BY_ARTIST) | 0);  /* check that SP_TRACK_AVAILABILITY_BANNED_BY_ARTIST is an integer */
  return n;
}

static int _cffi_const_SP_BITRATE_160k(unsigned long long *o)
{
  int n = (SP_BITRATE_160k) <= 0;
  *o = (unsigned long long)((SP_BITRATE_160k) | 0);  /* check that SP_BITRATE_160k is an integer */
  return n;
}

static int _cffi_const_SP_BITRATE_320k(unsigned long long *o)
{
  int n = (SP_BITRATE_320k) <= 0;
  *o = (unsigned long long)((SP_BITRATE_320k) | 0);  /* check that SP_BITRATE_320k is an integer */
  return n;
}

static int _cffi_const_SP_BITRATE_96k(unsigned long long *o)
{
  int n = (SP_BITRATE_96k) <= 0;
  *o = (unsigned long long)((SP_BITRATE_96k) | 0);  /* check that SP_BITRATE_96k is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_RULE_NETWORK(unsigned long long *o)
{
  int n = (SP_CONNECTION_RULE_NETWORK) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_RULE_NETWORK) | 0);  /* check that SP_CONNECTION_RULE_NETWORK is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_RULE_NETWORK_IF_ROAMING(unsigned long long *o)
{
  int n = (SP_CONNECTION_RULE_NETWORK_IF_ROAMING) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_RULE_NETWORK_IF_ROAMING) | 0);  /* check that SP_CONNECTION_RULE_NETWORK_IF_ROAMING is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_RULE_ALLOW_SYNC_OVER_MOBILE(unsigned long long *o)
{
  int n = (SP_CONNECTION_RULE_ALLOW_SYNC_OVER_MOBILE) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_RULE_ALLOW_SYNC_OVER_MOBILE) | 0);  /* check that SP_CONNECTION_RULE_ALLOW_SYNC_OVER_MOBILE is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI(unsigned long long *o)
{
  int n = (SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI) | 0);  /* check that SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_TYPE_UNKNOWN(unsigned long long *o)
{
  int n = (SP_CONNECTION_TYPE_UNKNOWN) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_TYPE_UNKNOWN) | 0);  /* check that SP_CONNECTION_TYPE_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_TYPE_NONE(unsigned long long *o)
{
  int n = (SP_CONNECTION_TYPE_NONE) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_TYPE_NONE) | 0);  /* check that SP_CONNECTION_TYPE_NONE is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_TYPE_MOBILE(unsigned long long *o)
{
  int n = (SP_CONNECTION_TYPE_MOBILE) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_TYPE_MOBILE) | 0);  /* check that SP_CONNECTION_TYPE_MOBILE is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_TYPE_MOBILE_ROAMING(unsigned long long *o)
{
  int n = (SP_CONNECTION_TYPE_MOBILE_ROAMING) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_TYPE_MOBILE_ROAMING) | 0);  /* check that SP_CONNECTION_TYPE_MOBILE_ROAMING is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_TYPE_WIFI(unsigned long long *o)
{
  int n = (SP_CONNECTION_TYPE_WIFI) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_TYPE_WIFI) | 0);  /* check that SP_CONNECTION_TYPE_WIFI is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_TYPE_WIRED(unsigned long long *o)
{
  int n = (SP_CONNECTION_TYPE_WIRED) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_TYPE_WIRED) | 0);  /* check that SP_CONNECTION_TYPE_WIRED is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_STATE_LOGGED_OUT(unsigned long long *o)
{
  int n = (SP_CONNECTION_STATE_LOGGED_OUT) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_STATE_LOGGED_OUT) | 0);  /* check that SP_CONNECTION_STATE_LOGGED_OUT is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_STATE_LOGGED_IN(unsigned long long *o)
{
  int n = (SP_CONNECTION_STATE_LOGGED_IN) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_STATE_LOGGED_IN) | 0);  /* check that SP_CONNECTION_STATE_LOGGED_IN is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_STATE_DISCONNECTED(unsigned long long *o)
{
  int n = (SP_CONNECTION_STATE_DISCONNECTED) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_STATE_DISCONNECTED) | 0);  /* check that SP_CONNECTION_STATE_DISCONNECTED is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_STATE_UNDEFINED(unsigned long long *o)
{
  int n = (SP_CONNECTION_STATE_UNDEFINED) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_STATE_UNDEFINED) | 0);  /* check that SP_CONNECTION_STATE_UNDEFINED is an integer */
  return n;
}

static int _cffi_const_SP_CONNECTION_STATE_OFFLINE(unsigned long long *o)
{
  int n = (SP_CONNECTION_STATE_OFFLINE) <= 0;
  *o = (unsigned long long)((SP_CONNECTION_STATE_OFFLINE) | 0);  /* check that SP_CONNECTION_STATE_OFFLINE is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OK(unsigned long long *o)
{
  int n = (SP_ERROR_OK) <= 0;
  *o = (unsigned long long)((SP_ERROR_OK) | 0);  /* check that SP_ERROR_OK is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_BAD_API_VERSION(unsigned long long *o)
{
  int n = (SP_ERROR_BAD_API_VERSION) <= 0;
  *o = (unsigned long long)((SP_ERROR_BAD_API_VERSION) | 0);  /* check that SP_ERROR_BAD_API_VERSION is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_API_INITIALIZATION_FAILED(unsigned long long *o)
{
  int n = (SP_ERROR_API_INITIALIZATION_FAILED) <= 0;
  *o = (unsigned long long)((SP_ERROR_API_INITIALIZATION_FAILED) | 0);  /* check that SP_ERROR_API_INITIALIZATION_FAILED is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_TRACK_NOT_PLAYABLE(unsigned long long *o)
{
  int n = (SP_ERROR_TRACK_NOT_PLAYABLE) <= 0;
  *o = (unsigned long long)((SP_ERROR_TRACK_NOT_PLAYABLE) | 0);  /* check that SP_ERROR_TRACK_NOT_PLAYABLE is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_BAD_APPLICATION_KEY(unsigned long long *o)
{
  int n = (SP_ERROR_BAD_APPLICATION_KEY) <= 0;
  *o = (unsigned long long)((SP_ERROR_BAD_APPLICATION_KEY) | 0);  /* check that SP_ERROR_BAD_APPLICATION_KEY is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_BAD_USERNAME_OR_PASSWORD(unsigned long long *o)
{
  int n = (SP_ERROR_BAD_USERNAME_OR_PASSWORD) <= 0;
  *o = (unsigned long long)((SP_ERROR_BAD_USERNAME_OR_PASSWORD) | 0);  /* check that SP_ERROR_BAD_USERNAME_OR_PASSWORD is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_USER_BANNED(unsigned long long *o)
{
  int n = (SP_ERROR_USER_BANNED) <= 0;
  *o = (unsigned long long)((SP_ERROR_USER_BANNED) | 0);  /* check that SP_ERROR_USER_BANNED is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_UNABLE_TO_CONTACT_SERVER(unsigned long long *o)
{
  int n = (SP_ERROR_UNABLE_TO_CONTACT_SERVER) <= 0;
  *o = (unsigned long long)((SP_ERROR_UNABLE_TO_CONTACT_SERVER) | 0);  /* check that SP_ERROR_UNABLE_TO_CONTACT_SERVER is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_CLIENT_TOO_OLD(unsigned long long *o)
{
  int n = (SP_ERROR_CLIENT_TOO_OLD) <= 0;
  *o = (unsigned long long)((SP_ERROR_CLIENT_TOO_OLD) | 0);  /* check that SP_ERROR_CLIENT_TOO_OLD is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OTHER_PERMANENT(unsigned long long *o)
{
  int n = (SP_ERROR_OTHER_PERMANENT) <= 0;
  *o = (unsigned long long)((SP_ERROR_OTHER_PERMANENT) | 0);  /* check that SP_ERROR_OTHER_PERMANENT is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_BAD_USER_AGENT(unsigned long long *o)
{
  int n = (SP_ERROR_BAD_USER_AGENT) <= 0;
  *o = (unsigned long long)((SP_ERROR_BAD_USER_AGENT) | 0);  /* check that SP_ERROR_BAD_USER_AGENT is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_MISSING_CALLBACK(unsigned long long *o)
{
  int n = (SP_ERROR_MISSING_CALLBACK) <= 0;
  *o = (unsigned long long)((SP_ERROR_MISSING_CALLBACK) | 0);  /* check that SP_ERROR_MISSING_CALLBACK is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_INVALID_INDATA(unsigned long long *o)
{
  int n = (SP_ERROR_INVALID_INDATA) <= 0;
  *o = (unsigned long long)((SP_ERROR_INVALID_INDATA) | 0);  /* check that SP_ERROR_INVALID_INDATA is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_INDEX_OUT_OF_RANGE(unsigned long long *o)
{
  int n = (SP_ERROR_INDEX_OUT_OF_RANGE) <= 0;
  *o = (unsigned long long)((SP_ERROR_INDEX_OUT_OF_RANGE) | 0);  /* check that SP_ERROR_INDEX_OUT_OF_RANGE is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_USER_NEEDS_PREMIUM(unsigned long long *o)
{
  int n = (SP_ERROR_USER_NEEDS_PREMIUM) <= 0;
  *o = (unsigned long long)((SP_ERROR_USER_NEEDS_PREMIUM) | 0);  /* check that SP_ERROR_USER_NEEDS_PREMIUM is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OTHER_TRANSIENT(unsigned long long *o)
{
  int n = (SP_ERROR_OTHER_TRANSIENT) <= 0;
  *o = (unsigned long long)((SP_ERROR_OTHER_TRANSIENT) | 0);  /* check that SP_ERROR_OTHER_TRANSIENT is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_IS_LOADING(unsigned long long *o)
{
  int n = (SP_ERROR_IS_LOADING) <= 0;
  *o = (unsigned long long)((SP_ERROR_IS_LOADING) | 0);  /* check that SP_ERROR_IS_LOADING is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_NO_STREAM_AVAILABLE(unsigned long long *o)
{
  int n = (SP_ERROR_NO_STREAM_AVAILABLE) <= 0;
  *o = (unsigned long long)((SP_ERROR_NO_STREAM_AVAILABLE) | 0);  /* check that SP_ERROR_NO_STREAM_AVAILABLE is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_PERMISSION_DENIED(unsigned long long *o)
{
  int n = (SP_ERROR_PERMISSION_DENIED) <= 0;
  *o = (unsigned long long)((SP_ERROR_PERMISSION_DENIED) | 0);  /* check that SP_ERROR_PERMISSION_DENIED is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_INBOX_IS_FULL(unsigned long long *o)
{
  int n = (SP_ERROR_INBOX_IS_FULL) <= 0;
  *o = (unsigned long long)((SP_ERROR_INBOX_IS_FULL) | 0);  /* check that SP_ERROR_INBOX_IS_FULL is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_NO_CACHE(unsigned long long *o)
{
  int n = (SP_ERROR_NO_CACHE) <= 0;
  *o = (unsigned long long)((SP_ERROR_NO_CACHE) | 0);  /* check that SP_ERROR_NO_CACHE is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_NO_SUCH_USER(unsigned long long *o)
{
  int n = (SP_ERROR_NO_SUCH_USER) <= 0;
  *o = (unsigned long long)((SP_ERROR_NO_SUCH_USER) | 0);  /* check that SP_ERROR_NO_SUCH_USER is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_NO_CREDENTIALS(unsigned long long *o)
{
  int n = (SP_ERROR_NO_CREDENTIALS) <= 0;
  *o = (unsigned long long)((SP_ERROR_NO_CREDENTIALS) | 0);  /* check that SP_ERROR_NO_CREDENTIALS is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_NETWORK_DISABLED(unsigned long long *o)
{
  int n = (SP_ERROR_NETWORK_DISABLED) <= 0;
  *o = (unsigned long long)((SP_ERROR_NETWORK_DISABLED) | 0);  /* check that SP_ERROR_NETWORK_DISABLED is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_INVALID_DEVICE_ID(unsigned long long *o)
{
  int n = (SP_ERROR_INVALID_DEVICE_ID) <= 0;
  *o = (unsigned long long)((SP_ERROR_INVALID_DEVICE_ID) | 0);  /* check that SP_ERROR_INVALID_DEVICE_ID is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_CANT_OPEN_TRACE_FILE(unsigned long long *o)
{
  int n = (SP_ERROR_CANT_OPEN_TRACE_FILE) <= 0;
  *o = (unsigned long long)((SP_ERROR_CANT_OPEN_TRACE_FILE) | 0);  /* check that SP_ERROR_CANT_OPEN_TRACE_FILE is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_APPLICATION_BANNED(unsigned long long *o)
{
  int n = (SP_ERROR_APPLICATION_BANNED) <= 0;
  *o = (unsigned long long)((SP_ERROR_APPLICATION_BANNED) | 0);  /* check that SP_ERROR_APPLICATION_BANNED is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OFFLINE_TOO_MANY_TRACKS(unsigned long long *o)
{
  int n = (SP_ERROR_OFFLINE_TOO_MANY_TRACKS) <= 0;
  *o = (unsigned long long)((SP_ERROR_OFFLINE_TOO_MANY_TRACKS) | 0);  /* check that SP_ERROR_OFFLINE_TOO_MANY_TRACKS is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OFFLINE_DISK_CACHE(unsigned long long *o)
{
  int n = (SP_ERROR_OFFLINE_DISK_CACHE) <= 0;
  *o = (unsigned long long)((SP_ERROR_OFFLINE_DISK_CACHE) | 0);  /* check that SP_ERROR_OFFLINE_DISK_CACHE is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OFFLINE_EXPIRED(unsigned long long *o)
{
  int n = (SP_ERROR_OFFLINE_EXPIRED) <= 0;
  *o = (unsigned long long)((SP_ERROR_OFFLINE_EXPIRED) | 0);  /* check that SP_ERROR_OFFLINE_EXPIRED is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OFFLINE_NOT_ALLOWED(unsigned long long *o)
{
  int n = (SP_ERROR_OFFLINE_NOT_ALLOWED) <= 0;
  *o = (unsigned long long)((SP_ERROR_OFFLINE_NOT_ALLOWED) | 0);  /* check that SP_ERROR_OFFLINE_NOT_ALLOWED is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OFFLINE_LICENSE_LOST(unsigned long long *o)
{
  int n = (SP_ERROR_OFFLINE_LICENSE_LOST) <= 0;
  *o = (unsigned long long)((SP_ERROR_OFFLINE_LICENSE_LOST) | 0);  /* check that SP_ERROR_OFFLINE_LICENSE_LOST is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_OFFLINE_LICENSE_ERROR(unsigned long long *o)
{
  int n = (SP_ERROR_OFFLINE_LICENSE_ERROR) <= 0;
  *o = (unsigned long long)((SP_ERROR_OFFLINE_LICENSE_ERROR) | 0);  /* check that SP_ERROR_OFFLINE_LICENSE_ERROR is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_LASTFM_AUTH_ERROR(unsigned long long *o)
{
  int n = (SP_ERROR_LASTFM_AUTH_ERROR) <= 0;
  *o = (unsigned long long)((SP_ERROR_LASTFM_AUTH_ERROR) | 0);  /* check that SP_ERROR_LASTFM_AUTH_ERROR is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_INVALID_ARGUMENT(unsigned long long *o)
{
  int n = (SP_ERROR_INVALID_ARGUMENT) <= 0;
  *o = (unsigned long long)((SP_ERROR_INVALID_ARGUMENT) | 0);  /* check that SP_ERROR_INVALID_ARGUMENT is an integer */
  return n;
}

static int _cffi_const_SP_ERROR_SYSTEM_FAILURE(unsigned long long *o)
{
  int n = (SP_ERROR_SYSTEM_FAILURE) <= 0;
  *o = (unsigned long long)((SP_ERROR_SYSTEM_FAILURE) | 0);  /* check that SP_ERROR_SYSTEM_FAILURE is an integer */
  return n;
}

static int _cffi_const_SP_IMAGE_SIZE_NORMAL(unsigned long long *o)
{
  int n = (SP_IMAGE_SIZE_NORMAL) <= 0;
  *o = (unsigned long long)((SP_IMAGE_SIZE_NORMAL) | 0);  /* check that SP_IMAGE_SIZE_NORMAL is an integer */
  return n;
}

static int _cffi_const_SP_IMAGE_SIZE_SMALL(unsigned long long *o)
{
  int n = (SP_IMAGE_SIZE_SMALL) <= 0;
  *o = (unsigned long long)((SP_IMAGE_SIZE_SMALL) | 0);  /* check that SP_IMAGE_SIZE_SMALL is an integer */
  return n;
}

static int _cffi_const_SP_IMAGE_SIZE_LARGE(unsigned long long *o)
{
  int n = (SP_IMAGE_SIZE_LARGE) <= 0;
  *o = (unsigned long long)((SP_IMAGE_SIZE_LARGE) | 0);  /* check that SP_IMAGE_SIZE_LARGE is an integer */
  return n;
}

static int _cffi_const_SP_PLAYLIST_OFFLINE_STATUS_NO(unsigned long long *o)
{
  int n = (SP_PLAYLIST_OFFLINE_STATUS_NO) <= 0;
  *o = (unsigned long long)((SP_PLAYLIST_OFFLINE_STATUS_NO) | 0);  /* check that SP_PLAYLIST_OFFLINE_STATUS_NO is an integer */
  return n;
}

static int _cffi_const_SP_PLAYLIST_OFFLINE_STATUS_YES(unsigned long long *o)
{
  int n = (SP_PLAYLIST_OFFLINE_STATUS_YES) <= 0;
  *o = (unsigned long long)((SP_PLAYLIST_OFFLINE_STATUS_YES) | 0);  /* check that SP_PLAYLIST_OFFLINE_STATUS_YES is an integer */
  return n;
}

static int _cffi_const_SP_PLAYLIST_OFFLINE_STATUS_DOWNLOADING(unsigned long long *o)
{
  int n = (SP_PLAYLIST_OFFLINE_STATUS_DOWNLOADING) <= 0;
  *o = (unsigned long long)((SP_PLAYLIST_OFFLINE_STATUS_DOWNLOADING) | 0);  /* check that SP_PLAYLIST_OFFLINE_STATUS_DOWNLOADING is an integer */
  return n;
}

static int _cffi_const_SP_PLAYLIST_OFFLINE_STATUS_WAITING(unsigned long long *o)
{
  int n = (SP_PLAYLIST_OFFLINE_STATUS_WAITING) <= 0;
  *o = (unsigned long long)((SP_PLAYLIST_OFFLINE_STATUS_WAITING) | 0);  /* check that SP_PLAYLIST_OFFLINE_STATUS_WAITING is an integer */
  return n;
}

static int _cffi_const_SP_PLAYLIST_TYPE_PLAYLIST(unsigned long long *o)
{
  int n = (SP_PLAYLIST_TYPE_PLAYLIST) <= 0;
  *o = (unsigned long long)((SP_PLAYLIST_TYPE_PLAYLIST) | 0);  /* check that SP_PLAYLIST_TYPE_PLAYLIST is an integer */
  return n;
}

static int _cffi_const_SP_PLAYLIST_TYPE_START_FOLDER(unsigned long long *o)
{
  int n = (SP_PLAYLIST_TYPE_START_FOLDER) <= 0;
  *o = (unsigned long long)((SP_PLAYLIST_TYPE_START_FOLDER) | 0);  /* check that SP_PLAYLIST_TYPE_START_FOLDER is an integer */
  return n;
}

static int _cffi_const_SP_PLAYLIST_TYPE_END_FOLDER(unsigned long long *o)
{
  int n = (SP_PLAYLIST_TYPE_END_FOLDER) <= 0;
  *o = (unsigned long long)((SP_PLAYLIST_TYPE_END_FOLDER) | 0);  /* check that SP_PLAYLIST_TYPE_END_FOLDER is an integer */
  return n;
}

static int _cffi_const_SP_PLAYLIST_TYPE_PLACEHOLDER(unsigned long long *o)
{
  int n = (SP_PLAYLIST_TYPE_PLACEHOLDER) <= 0;
  *o = (unsigned long long)((SP_PLAYLIST_TYPE_PLACEHOLDER) | 0);  /* check that SP_PLAYLIST_TYPE_PLACEHOLDER is an integer */
  return n;
}

static int _cffi_const_SP_RELATION_TYPE_UNKNOWN(unsigned long long *o)
{
  int n = (SP_RELATION_TYPE_UNKNOWN) <= 0;
  *o = (unsigned long long)((SP_RELATION_TYPE_UNKNOWN) | 0);  /* check that SP_RELATION_TYPE_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_SP_RELATION_TYPE_NONE(unsigned long long *o)
{
  int n = (SP_RELATION_TYPE_NONE) <= 0;
  *o = (unsigned long long)((SP_RELATION_TYPE_NONE) | 0);  /* check that SP_RELATION_TYPE_NONE is an integer */
  return n;
}

static int _cffi_const_SP_RELATION_TYPE_UNIDIRECTIONAL(unsigned long long *o)
{
  int n = (SP_RELATION_TYPE_UNIDIRECTIONAL) <= 0;
  *o = (unsigned long long)((SP_RELATION_TYPE_UNIDIRECTIONAL) | 0);  /* check that SP_RELATION_TYPE_UNIDIRECTIONAL is an integer */
  return n;
}

static int _cffi_const_SP_RELATION_TYPE_BIDIRECTIONAL(unsigned long long *o)
{
  int n = (SP_RELATION_TYPE_BIDIRECTIONAL) <= 0;
  *o = (unsigned long long)((SP_RELATION_TYPE_BIDIRECTIONAL) | 0);  /* check that SP_RELATION_TYPE_BIDIRECTIONAL is an integer */
  return n;
}

static int _cffi_const_SP_SAMPLETYPE_INT16_NATIVE_ENDIAN(unsigned long long *o)
{
  int n = (SP_SAMPLETYPE_INT16_NATIVE_ENDIAN) <= 0;
  *o = (unsigned long long)((SP_SAMPLETYPE_INT16_NATIVE_ENDIAN) | 0);  /* check that SP_SAMPLETYPE_INT16_NATIVE_ENDIAN is an integer */
  return n;
}

static int _cffi_const_SP_SCROBBLING_STATE_USE_GLOBAL_SETTING(unsigned long long *o)
{
  int n = (SP_SCROBBLING_STATE_USE_GLOBAL_SETTING) <= 0;
  *o = (unsigned long long)((SP_SCROBBLING_STATE_USE_GLOBAL_SETTING) | 0);  /* check that SP_SCROBBLING_STATE_USE_GLOBAL_SETTING is an integer */
  return n;
}

static int _cffi_const_SP_SCROBBLING_STATE_LOCAL_ENABLED(unsigned long long *o)
{
  int n = (SP_SCROBBLING_STATE_LOCAL_ENABLED) <= 0;
  *o = (unsigned long long)((SP_SCROBBLING_STATE_LOCAL_ENABLED) | 0);  /* check that SP_SCROBBLING_STATE_LOCAL_ENABLED is an integer */
  return n;
}

static int _cffi_const_SP_SCROBBLING_STATE_LOCAL_DISABLED(unsigned long long *o)
{
  int n = (SP_SCROBBLING_STATE_LOCAL_DISABLED) <= 0;
  *o = (unsigned long long)((SP_SCROBBLING_STATE_LOCAL_DISABLED) | 0);  /* check that SP_SCROBBLING_STATE_LOCAL_DISABLED is an integer */
  return n;
}

static int _cffi_const_SP_SCROBBLING_STATE_GLOBAL_ENABLED(unsigned long long *o)
{
  int n = (SP_SCROBBLING_STATE_GLOBAL_ENABLED) <= 0;
  *o = (unsigned long long)((SP_SCROBBLING_STATE_GLOBAL_ENABLED) | 0);  /* check that SP_SCROBBLING_STATE_GLOBAL_ENABLED is an integer */
  return n;
}

static int _cffi_const_SP_SCROBBLING_STATE_GLOBAL_DISABLED(unsigned long long *o)
{
  int n = (SP_SCROBBLING_STATE_GLOBAL_DISABLED) <= 0;
  *o = (unsigned long long)((SP_SCROBBLING_STATE_GLOBAL_DISABLED) | 0);  /* check that SP_SCROBBLING_STATE_GLOBAL_DISABLED is an integer */
  return n;
}

static int _cffi_const_SP_SEARCH_STANDARD(unsigned long long *o)
{
  int n = (SP_SEARCH_STANDARD) <= 0;
  *o = (unsigned long long)((SP_SEARCH_STANDARD) | 0);  /* check that SP_SEARCH_STANDARD is an integer */
  return n;
}

static int _cffi_const_SP_SEARCH_SUGGEST(unsigned long long *o)
{
  int n = (SP_SEARCH_SUGGEST) <= 0;
  *o = (unsigned long long)((SP_SEARCH_SUGGEST) | 0);  /* check that SP_SEARCH_SUGGEST is an integer */
  return n;
}

static int _cffi_const_SP_SOCIAL_PROVIDER_SPOTIFY(unsigned long long *o)
{
  int n = (SP_SOCIAL_PROVIDER_SPOTIFY) <= 0;
  *o = (unsigned long long)((SP_SOCIAL_PROVIDER_SPOTIFY) | 0);  /* check that SP_SOCIAL_PROVIDER_SPOTIFY is an integer */
  return n;
}

static int _cffi_const_SP_SOCIAL_PROVIDER_FACEBOOK(unsigned long long *o)
{
  int n = (SP_SOCIAL_PROVIDER_FACEBOOK) <= 0;
  *o = (unsigned long long)((SP_SOCIAL_PROVIDER_FACEBOOK) | 0);  /* check that SP_SOCIAL_PROVIDER_FACEBOOK is an integer */
  return n;
}

static int _cffi_const_SP_SOCIAL_PROVIDER_LASTFM(unsigned long long *o)
{
  int n = (SP_SOCIAL_PROVIDER_LASTFM) <= 0;
  *o = (unsigned long long)((SP_SOCIAL_PROVIDER_LASTFM) | 0);  /* check that SP_SOCIAL_PROVIDER_LASTFM is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_OFFLINE_NO(unsigned long long *o)
{
  int n = (SP_TRACK_OFFLINE_NO) <= 0;
  *o = (unsigned long long)((SP_TRACK_OFFLINE_NO) | 0);  /* check that SP_TRACK_OFFLINE_NO is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_OFFLINE_WAITING(unsigned long long *o)
{
  int n = (SP_TRACK_OFFLINE_WAITING) <= 0;
  *o = (unsigned long long)((SP_TRACK_OFFLINE_WAITING) | 0);  /* check that SP_TRACK_OFFLINE_WAITING is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_OFFLINE_DOWNLOADING(unsigned long long *o)
{
  int n = (SP_TRACK_OFFLINE_DOWNLOADING) <= 0;
  *o = (unsigned long long)((SP_TRACK_OFFLINE_DOWNLOADING) | 0);  /* check that SP_TRACK_OFFLINE_DOWNLOADING is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_OFFLINE_DONE(unsigned long long *o)
{
  int n = (SP_TRACK_OFFLINE_DONE) <= 0;
  *o = (unsigned long long)((SP_TRACK_OFFLINE_DONE) | 0);  /* check that SP_TRACK_OFFLINE_DONE is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_OFFLINE_ERROR(unsigned long long *o)
{
  int n = (SP_TRACK_OFFLINE_ERROR) <= 0;
  *o = (unsigned long long)((SP_TRACK_OFFLINE_ERROR) | 0);  /* check that SP_TRACK_OFFLINE_ERROR is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_OFFLINE_DONE_EXPIRED(unsigned long long *o)
{
  int n = (SP_TRACK_OFFLINE_DONE_EXPIRED) <= 0;
  *o = (unsigned long long)((SP_TRACK_OFFLINE_DONE_EXPIRED) | 0);  /* check that SP_TRACK_OFFLINE_DONE_EXPIRED is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_OFFLINE_LIMIT_EXCEEDED(unsigned long long *o)
{
  int n = (SP_TRACK_OFFLINE_LIMIT_EXCEEDED) <= 0;
  *o = (unsigned long long)((SP_TRACK_OFFLINE_LIMIT_EXCEEDED) | 0);  /* check that SP_TRACK_OFFLINE_LIMIT_EXCEEDED is an integer */
  return n;
}

static int _cffi_const_SP_TRACK_OFFLINE_DONE_RESYNC(unsigned long long *o)
{
  int n = (SP_TRACK_OFFLINE_DONE_RESYNC) <= 0;
  *o = (unsigned long long)((SP_TRACK_OFFLINE_DONE_RESYNC) | 0);  /* check that SP_TRACK_OFFLINE_DONE_RESYNC is an integer */
  return n;
}

static sp_error _cffi_d_sp_album_add_ref(sp_album * x0)
{
  return sp_album_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_add_ref(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_add_ref _cffi_d_sp_album_add_ref
#endif

static sp_artist * _cffi_d_sp_album_artist(sp_album * x0)
{
  return sp_album_artist(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_artist(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artist * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_artist(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_artist _cffi_d_sp_album_artist
#endif

static unsigned char const * _cffi_d_sp_album_cover(sp_album * x0, sp_image_size x1)
{
  return sp_album_cover(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_cover(PyObject *self, PyObject *args)
{
  sp_album * x0;
  sp_image_size x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_album_cover", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(397), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_cover(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(375));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_cover _cffi_d_sp_album_cover
#endif

static unsigned char _cffi_d_sp_album_is_available(sp_album * x0)
{
  return sp_album_is_available(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_is_available(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_is_available(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_is_available _cffi_d_sp_album_is_available
#endif

static unsigned char _cffi_d_sp_album_is_loaded(sp_album * x0)
{
  return sp_album_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_is_loaded _cffi_d_sp_album_is_loaded
#endif

static char const * _cffi_d_sp_album_name(sp_album * x0)
{
  return sp_album_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_name(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_name _cffi_d_sp_album_name
#endif

static sp_error _cffi_d_sp_album_release(sp_album * x0)
{
  return sp_album_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_release(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_release _cffi_d_sp_album_release
#endif

static sp_albumtype _cffi_d_sp_album_type(sp_album * x0)
{
  return sp_album_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_type(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_albumtype result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(766));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_type _cffi_d_sp_album_type
#endif

static int _cffi_d_sp_album_year(sp_album * x0)
{
  return sp_album_year(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_album_year(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_album_year(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_album_year _cffi_d_sp_album_year
#endif

static sp_error _cffi_d_sp_albumbrowse_add_ref(sp_albumbrowse * x0)
{
  return sp_albumbrowse_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_add_ref(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_add_ref _cffi_d_sp_albumbrowse_add_ref
#endif

static sp_album * _cffi_d_sp_albumbrowse_album(sp_albumbrowse * x0)
{
  return sp_albumbrowse_album(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_album(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_album * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_album(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_album _cffi_d_sp_albumbrowse_album
#endif

static sp_artist * _cffi_d_sp_albumbrowse_artist(sp_albumbrowse * x0)
{
  return sp_albumbrowse_artist(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_artist(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artist * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_artist(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_artist _cffi_d_sp_albumbrowse_artist
#endif

static int _cffi_d_sp_albumbrowse_backend_request_duration(sp_albumbrowse * x0)
{
  return sp_albumbrowse_backend_request_duration(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_backend_request_duration(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_backend_request_duration(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_backend_request_duration _cffi_d_sp_albumbrowse_backend_request_duration
#endif

static char const * _cffi_d_sp_albumbrowse_copyright(sp_albumbrowse * x0, int x1)
{
  return sp_albumbrowse_copyright(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_copyright(PyObject *self, PyObject *args)
{
  sp_albumbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_albumbrowse_copyright", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_copyright(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_copyright _cffi_d_sp_albumbrowse_copyright
#endif

static sp_albumbrowse * _cffi_d_sp_albumbrowse_create(sp_session * x0, sp_album * x1, void(* x2)(sp_albumbrowse *, void *), void * x3)
{
  return sp_albumbrowse_create(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_create(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_album * x1;
  void(* x2)(sp_albumbrowse *, void *);
  void * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_albumbrowse * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "sp_albumbrowse_create", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (void(*)(sp_albumbrowse *, void *))_cffi_to_c_pointer(arg2, _cffi_type(129));
  if (x2 == (void(*)(sp_albumbrowse *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_create(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_create _cffi_d_sp_albumbrowse_create
#endif

static sp_error _cffi_d_sp_albumbrowse_error(sp_albumbrowse * x0)
{
  return sp_albumbrowse_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_error(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_error _cffi_d_sp_albumbrowse_error
#endif

static unsigned char _cffi_d_sp_albumbrowse_is_loaded(sp_albumbrowse * x0)
{
  return sp_albumbrowse_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_is_loaded _cffi_d_sp_albumbrowse_is_loaded
#endif

static int _cffi_d_sp_albumbrowse_num_copyrights(sp_albumbrowse * x0)
{
  return sp_albumbrowse_num_copyrights(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_num_copyrights(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_num_copyrights(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_num_copyrights _cffi_d_sp_albumbrowse_num_copyrights
#endif

static int _cffi_d_sp_albumbrowse_num_tracks(sp_albumbrowse * x0)
{
  return sp_albumbrowse_num_tracks(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_num_tracks(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_num_tracks(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_num_tracks _cffi_d_sp_albumbrowse_num_tracks
#endif

static sp_error _cffi_d_sp_albumbrowse_release(sp_albumbrowse * x0)
{
  return sp_albumbrowse_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_release(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_release _cffi_d_sp_albumbrowse_release
#endif

static char const * _cffi_d_sp_albumbrowse_review(sp_albumbrowse * x0)
{
  return sp_albumbrowse_review(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_review(PyObject *self, PyObject *arg0)
{
  sp_albumbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_review(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_review _cffi_d_sp_albumbrowse_review
#endif

static sp_track * _cffi_d_sp_albumbrowse_track(sp_albumbrowse * x0, int x1)
{
  return sp_albumbrowse_track(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_albumbrowse_track(PyObject *self, PyObject *args)
{
  sp_albumbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_albumbrowse_track", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_albumbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_albumbrowse_track(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_albumbrowse_track _cffi_d_sp_albumbrowse_track
#endif

static sp_error _cffi_d_sp_artist_add_ref(sp_artist * x0)
{
  return sp_artist_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artist_add_ref(PyObject *self, PyObject *arg0)
{
  sp_artist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artist_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artist_add_ref _cffi_d_sp_artist_add_ref
#endif

static unsigned char _cffi_d_sp_artist_is_loaded(sp_artist * x0)
{
  return sp_artist_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artist_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_artist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artist_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artist_is_loaded _cffi_d_sp_artist_is_loaded
#endif

static char const * _cffi_d_sp_artist_name(sp_artist * x0)
{
  return sp_artist_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artist_name(PyObject *self, PyObject *arg0)
{
  sp_artist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artist_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artist_name _cffi_d_sp_artist_name
#endif

static unsigned char const * _cffi_d_sp_artist_portrait(sp_artist * x0, sp_image_size x1)
{
  return sp_artist_portrait(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artist_portrait(PyObject *self, PyObject *args)
{
  sp_artist * x0;
  sp_image_size x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_artist_portrait", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(397), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artist_portrait(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(375));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artist_portrait _cffi_d_sp_artist_portrait
#endif

static sp_error _cffi_d_sp_artist_release(sp_artist * x0)
{
  return sp_artist_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artist_release(PyObject *self, PyObject *arg0)
{
  sp_artist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artist_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artist_release _cffi_d_sp_artist_release
#endif

static sp_error _cffi_d_sp_artistbrowse_add_ref(sp_artistbrowse * x0)
{
  return sp_artistbrowse_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_add_ref(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_add_ref _cffi_d_sp_artistbrowse_add_ref
#endif

static sp_album * _cffi_d_sp_artistbrowse_album(sp_artistbrowse * x0, int x1)
{
  return sp_artistbrowse_album(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_album(PyObject *self, PyObject *args)
{
  sp_artistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_album * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_artistbrowse_album", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_album(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_album _cffi_d_sp_artistbrowse_album
#endif

static sp_artist * _cffi_d_sp_artistbrowse_artist(sp_artistbrowse * x0)
{
  return sp_artistbrowse_artist(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_artist(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artist * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_artist(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_artist _cffi_d_sp_artistbrowse_artist
#endif

static int _cffi_d_sp_artistbrowse_backend_request_duration(sp_artistbrowse * x0)
{
  return sp_artistbrowse_backend_request_duration(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_backend_request_duration(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_backend_request_duration(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_backend_request_duration _cffi_d_sp_artistbrowse_backend_request_duration
#endif

static char const * _cffi_d_sp_artistbrowse_biography(sp_artistbrowse * x0)
{
  return sp_artistbrowse_biography(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_biography(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_biography(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_biography _cffi_d_sp_artistbrowse_biography
#endif

static sp_artistbrowse * _cffi_d_sp_artistbrowse_create(sp_session * x0, sp_artist * x1, sp_artistbrowse_type x2, void(* x3)(sp_artistbrowse *, void *), void * x4)
{
  return sp_artistbrowse_create(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_create(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_artist * x1;
  sp_artistbrowse_type x2;
  void(* x3)(sp_artistbrowse *, void *);
  void * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artistbrowse * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "sp_artistbrowse_create", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_artist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(166), arg2) < 0)
    return NULL;

  x3 = (void(*)(sp_artistbrowse *, void *))_cffi_to_c_pointer(arg3, _cffi_type(167));
  if (x3 == (void(*)(sp_artistbrowse *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_create(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(14));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_create _cffi_d_sp_artistbrowse_create
#endif

static sp_error _cffi_d_sp_artistbrowse_error(sp_artistbrowse * x0)
{
  return sp_artistbrowse_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_error(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_error _cffi_d_sp_artistbrowse_error
#endif

static unsigned char _cffi_d_sp_artistbrowse_is_loaded(sp_artistbrowse * x0)
{
  return sp_artistbrowse_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_is_loaded _cffi_d_sp_artistbrowse_is_loaded
#endif

static int _cffi_d_sp_artistbrowse_num_albums(sp_artistbrowse * x0)
{
  return sp_artistbrowse_num_albums(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_num_albums(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_num_albums(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_num_albums _cffi_d_sp_artistbrowse_num_albums
#endif

static int _cffi_d_sp_artistbrowse_num_portraits(sp_artistbrowse * x0)
{
  return sp_artistbrowse_num_portraits(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_num_portraits(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_num_portraits(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_num_portraits _cffi_d_sp_artistbrowse_num_portraits
#endif

static int _cffi_d_sp_artistbrowse_num_similar_artists(sp_artistbrowse * x0)
{
  return sp_artistbrowse_num_similar_artists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_num_similar_artists(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_num_similar_artists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_num_similar_artists _cffi_d_sp_artistbrowse_num_similar_artists
#endif

static int _cffi_d_sp_artistbrowse_num_tophit_tracks(sp_artistbrowse * x0)
{
  return sp_artistbrowse_num_tophit_tracks(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_num_tophit_tracks(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_num_tophit_tracks(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_num_tophit_tracks _cffi_d_sp_artistbrowse_num_tophit_tracks
#endif

static int _cffi_d_sp_artistbrowse_num_tracks(sp_artistbrowse * x0)
{
  return sp_artistbrowse_num_tracks(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_num_tracks(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_num_tracks(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_num_tracks _cffi_d_sp_artistbrowse_num_tracks
#endif

static unsigned char const * _cffi_d_sp_artistbrowse_portrait(sp_artistbrowse * x0, int x1)
{
  return sp_artistbrowse_portrait(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_portrait(PyObject *self, PyObject *args)
{
  sp_artistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_artistbrowse_portrait", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_portrait(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(375));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_portrait _cffi_d_sp_artistbrowse_portrait
#endif

static sp_error _cffi_d_sp_artistbrowse_release(sp_artistbrowse * x0)
{
  return sp_artistbrowse_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_release(PyObject *self, PyObject *arg0)
{
  sp_artistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_release _cffi_d_sp_artistbrowse_release
#endif

static sp_artist * _cffi_d_sp_artistbrowse_similar_artist(sp_artistbrowse * x0, int x1)
{
  return sp_artistbrowse_similar_artist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_similar_artist(PyObject *self, PyObject *args)
{
  sp_artistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_artistbrowse_similar_artist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_similar_artist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_similar_artist _cffi_d_sp_artistbrowse_similar_artist
#endif

static sp_track * _cffi_d_sp_artistbrowse_tophit_track(sp_artistbrowse * x0, int x1)
{
  return sp_artistbrowse_tophit_track(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_tophit_track(PyObject *self, PyObject *args)
{
  sp_artistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_artistbrowse_tophit_track", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_tophit_track(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_tophit_track _cffi_d_sp_artistbrowse_tophit_track
#endif

static sp_track * _cffi_d_sp_artistbrowse_track(sp_artistbrowse * x0, int x1)
{
  return sp_artistbrowse_track(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_artistbrowse_track(PyObject *self, PyObject *args)
{
  sp_artistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_artistbrowse_track", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_artistbrowse_track(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_artistbrowse_track _cffi_d_sp_artistbrowse_track
#endif

static char const * _cffi_d_sp_build_id(void)
{
  return sp_build_id();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_build_id(PyObject *self, PyObject *noarg)
{
  char const * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_build_id(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  return pyresult;
}
#else
#  define _cffi_f_sp_build_id _cffi_d_sp_build_id
#endif

static char const * _cffi_d_sp_error_message(sp_error x0)
{
  return sp_error_message(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_error_message(PyObject *self, PyObject *arg0)
{
  sp_error x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(17), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_error_message(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  return pyresult;
}
#else
#  define _cffi_f_sp_error_message _cffi_d_sp_error_message
#endif

static sp_error _cffi_d_sp_image_add_load_callback(sp_image * x0, void(* x1)(sp_image *, void *), void * x2)
{
  return sp_image_add_load_callback(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_add_load_callback(PyObject *self, PyObject *args)
{
  sp_image * x0;
  void(* x1)(sp_image *, void *);
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_image_add_load_callback", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(sp_image *, void *))_cffi_to_c_pointer(arg1, _cffi_type(190));
  if (x1 == (void(*)(sp_image *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_add_load_callback(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_add_load_callback _cffi_d_sp_image_add_load_callback
#endif

static sp_error _cffi_d_sp_image_add_ref(sp_image * x0)
{
  return sp_image_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_add_ref(PyObject *self, PyObject *arg0)
{
  sp_image * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_add_ref _cffi_d_sp_image_add_ref
#endif

static sp_image * _cffi_d_sp_image_create(sp_session * x0, unsigned char const * x1)
{
  return sp_image_create(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_create(PyObject *self, PyObject *args)
{
  sp_session * x0;
  unsigned char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_image * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_image_create", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(375), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(375), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_create(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(186));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_create _cffi_d_sp_image_create
#endif

static sp_image * _cffi_d_sp_image_create_from_link(sp_session * x0, sp_link * x1)
{
  return sp_image_create_from_link(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_create_from_link(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_link * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_image * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_image_create_from_link", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_create_from_link(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(186));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_create_from_link _cffi_d_sp_image_create_from_link
#endif

static void const * _cffi_d_sp_image_data(sp_image * x0, size_t * x1)
{
  return sp_image_data(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_data(PyObject *self, PyObject *args)
{
  sp_image * x0;
  size_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_image_data", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(640), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (size_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(640), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_data(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(92));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_data _cffi_d_sp_image_data
#endif

static sp_error _cffi_d_sp_image_error(sp_image * x0)
{
  return sp_image_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_error(PyObject *self, PyObject *arg0)
{
  sp_image * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_error _cffi_d_sp_image_error
#endif

static sp_imageformat _cffi_d_sp_image_format(sp_image * x0)
{
  return sp_image_format(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_format(PyObject *self, PyObject *arg0)
{
  sp_image * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_imageformat result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_format(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(773));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_format _cffi_d_sp_image_format
#endif

static unsigned char const * _cffi_d_sp_image_image_id(sp_image * x0)
{
  return sp_image_image_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_image_id(PyObject *self, PyObject *arg0)
{
  sp_image * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_image_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(375));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_image_id _cffi_d_sp_image_image_id
#endif

static unsigned char _cffi_d_sp_image_is_loaded(sp_image * x0)
{
  return sp_image_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_image * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_is_loaded _cffi_d_sp_image_is_loaded
#endif

static sp_error _cffi_d_sp_image_release(sp_image * x0)
{
  return sp_image_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_release(PyObject *self, PyObject *arg0)
{
  sp_image * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_release _cffi_d_sp_image_release
#endif

static sp_error _cffi_d_sp_image_remove_load_callback(sp_image * x0, void(* x1)(sp_image *, void *), void * x2)
{
  return sp_image_remove_load_callback(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_image_remove_load_callback(PyObject *self, PyObject *args)
{
  sp_image * x0;
  void(* x1)(sp_image *, void *);
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_image_remove_load_callback", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(sp_image *, void *))_cffi_to_c_pointer(arg1, _cffi_type(190));
  if (x1 == (void(*)(sp_image *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_image_remove_load_callback(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_image_remove_load_callback _cffi_d_sp_image_remove_load_callback
#endif

static sp_error _cffi_d_sp_inbox_add_ref(sp_inbox * x0)
{
  return sp_inbox_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_inbox_add_ref(PyObject *self, PyObject *arg0)
{
  sp_inbox * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(194), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_inbox *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(194), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_inbox_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_inbox_add_ref _cffi_d_sp_inbox_add_ref
#endif

static sp_error _cffi_d_sp_inbox_error(sp_inbox * x0)
{
  return sp_inbox_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_inbox_error(PyObject *self, PyObject *arg0)
{
  sp_inbox * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(194), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_inbox *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(194), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_inbox_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_inbox_error _cffi_d_sp_inbox_error
#endif

static sp_inbox * _cffi_d_sp_inbox_post_tracks(sp_session * x0, char const * x1, sp_track * const * x2, int x3, char const * x4, void(* x5)(sp_inbox *, void *), void * x6)
{
  return sp_inbox_post_tracks(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_inbox_post_tracks(PyObject *self, PyObject *args)
{
  sp_session * x0;
  char const * x1;
  sp_track * const * x2;
  int x3;
  char const * x4;
  void(* x5)(sp_inbox *, void *);
  void * x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_inbox * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "sp_inbox_post_tracks", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(229), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (sp_track * const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(229), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (void(*)(sp_inbox *, void *))_cffi_to_c_pointer(arg5, _cffi_type(386));
  if (x5 == (void(*)(sp_inbox *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg6, (char **)&x6);
  if (datasize != 0) {
    x6 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg6, (char **)&x6,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_inbox_post_tracks(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(194));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_inbox_post_tracks _cffi_d_sp_inbox_post_tracks
#endif

static sp_error _cffi_d_sp_inbox_release(sp_inbox * x0)
{
  return sp_inbox_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_inbox_release(PyObject *self, PyObject *arg0)
{
  sp_inbox * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(194), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_inbox *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(194), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_inbox_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_inbox_release _cffi_d_sp_inbox_release
#endif

static sp_error _cffi_d_sp_link_add_ref(sp_link * x0)
{
  return sp_link_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_add_ref(PyObject *self, PyObject *arg0)
{
  sp_link * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_add_ref _cffi_d_sp_link_add_ref
#endif

static sp_album * _cffi_d_sp_link_as_album(sp_link * x0)
{
  return sp_link_as_album(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_as_album(PyObject *self, PyObject *arg0)
{
  sp_link * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_album * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_as_album(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_as_album _cffi_d_sp_link_as_album
#endif

static sp_artist * _cffi_d_sp_link_as_artist(sp_link * x0)
{
  return sp_link_as_artist(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_as_artist(PyObject *self, PyObject *arg0)
{
  sp_link * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artist * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_as_artist(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_as_artist _cffi_d_sp_link_as_artist
#endif

static int _cffi_d_sp_link_as_string(sp_link * x0, char * x1, int x2)
{
  return sp_link_as_string(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_as_string(PyObject *self, PyObject *args)
{
  sp_link * x0;
  char * x1;
  int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_link_as_string", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(55), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(55), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_as_string(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_as_string _cffi_d_sp_link_as_string
#endif

static sp_track * _cffi_d_sp_link_as_track(sp_link * x0)
{
  return sp_link_as_track(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_as_track(PyObject *self, PyObject *arg0)
{
  sp_link * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_as_track(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_as_track _cffi_d_sp_link_as_track
#endif

static sp_track * _cffi_d_sp_link_as_track_and_offset(sp_link * x0, int * x1)
{
  return sp_link_as_track_and_offset(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_as_track_and_offset(PyObject *self, PyObject *args)
{
  sp_link * x0;
  int * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_link_as_track_and_offset", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(282), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (int *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(282), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_as_track_and_offset(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_as_track_and_offset _cffi_d_sp_link_as_track_and_offset
#endif

static sp_user * _cffi_d_sp_link_as_user(sp_link * x0)
{
  return sp_link_as_user(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_as_user(PyObject *self, PyObject *arg0)
{
  sp_link * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_user * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_as_user(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(40));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_as_user _cffi_d_sp_link_as_user
#endif

static sp_link * _cffi_d_sp_link_create_from_album(sp_album * x0)
{
  return sp_link_create_from_album(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_album(PyObject *self, PyObject *arg0)
{
  sp_album * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_album(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_album _cffi_d_sp_link_create_from_album
#endif

static sp_link * _cffi_d_sp_link_create_from_album_cover(sp_album * x0, sp_image_size x1)
{
  return sp_link_create_from_album_cover(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_album_cover(PyObject *self, PyObject *args)
{
  sp_album * x0;
  sp_image_size x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_link_create_from_album_cover", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_album *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(397), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_album_cover(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_album_cover _cffi_d_sp_link_create_from_album_cover
#endif

static sp_link * _cffi_d_sp_link_create_from_artist(sp_artist * x0)
{
  return sp_link_create_from_artist(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_artist(PyObject *self, PyObject *arg0)
{
  sp_artist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_artist(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_artist _cffi_d_sp_link_create_from_artist
#endif

static sp_link * _cffi_d_sp_link_create_from_artist_portrait(sp_artist * x0, sp_image_size x1)
{
  return sp_link_create_from_artist_portrait(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_artist_portrait(PyObject *self, PyObject *args)
{
  sp_artist * x0;
  sp_image_size x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_link_create_from_artist_portrait", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(397), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_artist_portrait(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_artist_portrait _cffi_d_sp_link_create_from_artist_portrait
#endif

static sp_link * _cffi_d_sp_link_create_from_artistbrowse_portrait(sp_artistbrowse * x0, int x1)
{
  return sp_link_create_from_artistbrowse_portrait(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_artistbrowse_portrait(PyObject *self, PyObject *args)
{
  sp_artistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_link_create_from_artistbrowse_portrait", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_artistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_artistbrowse_portrait(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_artistbrowse_portrait _cffi_d_sp_link_create_from_artistbrowse_portrait
#endif

static sp_link * _cffi_d_sp_link_create_from_image(sp_image * x0)
{
  return sp_link_create_from_image(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_image(PyObject *self, PyObject *arg0)
{
  sp_image * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_image *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_image(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_image _cffi_d_sp_link_create_from_image
#endif

static sp_link * _cffi_d_sp_link_create_from_playlist(sp_playlist * x0)
{
  return sp_link_create_from_playlist(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_playlist(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_playlist(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_playlist _cffi_d_sp_link_create_from_playlist
#endif

static sp_link * _cffi_d_sp_link_create_from_search(sp_search * x0)
{
  return sp_link_create_from_search(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_search(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_search(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_search _cffi_d_sp_link_create_from_search
#endif

static sp_link * _cffi_d_sp_link_create_from_string(char const * x0)
{
  return sp_link_create_from_string(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_string(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_string(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_string _cffi_d_sp_link_create_from_string
#endif

static sp_link * _cffi_d_sp_link_create_from_track(sp_track * x0, int x1)
{
  return sp_link_create_from_track(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_track(PyObject *self, PyObject *args)
{
  sp_track * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_link_create_from_track", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_track(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_track _cffi_d_sp_link_create_from_track
#endif

static sp_link * _cffi_d_sp_link_create_from_user(sp_user * x0)
{
  return sp_link_create_from_user(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_create_from_user(PyObject *self, PyObject *arg0)
{
  sp_user * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_link * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(40), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_user *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(40), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_create_from_user(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_create_from_user _cffi_d_sp_link_create_from_user
#endif

static sp_error _cffi_d_sp_link_release(sp_link * x0)
{
  return sp_link_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_release(PyObject *self, PyObject *arg0)
{
  sp_link * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_release _cffi_d_sp_link_release
#endif

static sp_linktype _cffi_d_sp_link_type(sp_link * x0)
{
  return sp_link_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_link_type(PyObject *self, PyObject *arg0)
{
  sp_link * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_linktype result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_link_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(776));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_link_type _cffi_d_sp_link_type
#endif

static sp_track * _cffi_d_sp_localtrack_create(char const * x0, char const * x1, char const * x2, int x3)
{
  return sp_localtrack_create(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_localtrack_create(PyObject *self, PyObject *args)
{
  char const * x0;
  char const * x1;
  char const * x2;
  int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "sp_localtrack_create", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_localtrack_create(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_localtrack_create _cffi_d_sp_localtrack_create
#endif

static int _cffi_d_sp_offline_num_playlists(sp_session * x0)
{
  return sp_offline_num_playlists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_offline_num_playlists(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_offline_num_playlists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_offline_num_playlists _cffi_d_sp_offline_num_playlists
#endif

static unsigned char _cffi_d_sp_offline_sync_get_status(sp_session * x0, sp_offline_sync_status * x1)
{
  return sp_offline_sync_get_status(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_offline_sync_get_status(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_offline_sync_status * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_offline_sync_get_status", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(613), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_offline_sync_status *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(613), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_offline_sync_get_status(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_offline_sync_get_status _cffi_d_sp_offline_sync_get_status
#endif

static int _cffi_d_sp_offline_time_left(sp_session * x0)
{
  return sp_offline_time_left(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_offline_time_left(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_offline_time_left(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_offline_time_left _cffi_d_sp_offline_time_left
#endif

static int _cffi_d_sp_offline_tracks_to_sync(sp_session * x0)
{
  return sp_offline_tracks_to_sync(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_offline_tracks_to_sync(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_offline_tracks_to_sync(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_offline_tracks_to_sync _cffi_d_sp_offline_tracks_to_sync
#endif

static sp_error _cffi_d_sp_playlist_add_callbacks(sp_playlist * x0, sp_playlist_callbacks * x1, void * x2)
{
  return sp_playlist_add_callbacks(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_add_callbacks(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  sp_playlist_callbacks * x1;
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlist_add_callbacks", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(224), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist_callbacks *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(224), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_add_callbacks(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_add_callbacks _cffi_d_sp_playlist_add_callbacks
#endif

static sp_error _cffi_d_sp_playlist_add_ref(sp_playlist * x0)
{
  return sp_playlist_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_add_ref(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_add_ref _cffi_d_sp_playlist_add_ref
#endif

static sp_error _cffi_d_sp_playlist_add_tracks(sp_playlist * x0, sp_track * const * x1, int x2, int x3, sp_session * x4)
{
  return sp_playlist_add_tracks(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_add_tracks(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  sp_track * const * x1;
  int x2;
  int x3;
  sp_session * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "sp_playlist_add_tracks", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(229), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track * const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(229), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_add_tracks(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_add_tracks _cffi_d_sp_playlist_add_tracks
#endif

static sp_playlist * _cffi_d_sp_playlist_create(sp_session * x0, sp_link * x1)
{
  return sp_playlist_create(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_create(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_link * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_create", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_create(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_create _cffi_d_sp_playlist_create
#endif

static char const * _cffi_d_sp_playlist_get_description(sp_playlist * x0)
{
  return sp_playlist_get_description(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_get_description(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_get_description(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_get_description _cffi_d_sp_playlist_get_description
#endif

static unsigned char _cffi_d_sp_playlist_get_image(sp_playlist * x0, unsigned char * x1)
{
  return sp_playlist_get_image(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_get_image(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  unsigned char * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_get_image", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(337), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(337), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_get_image(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_get_image _cffi_d_sp_playlist_get_image
#endif

static int _cffi_d_sp_playlist_get_offline_download_completed(sp_session * x0, sp_playlist * x1)
{
  return sp_playlist_get_offline_download_completed(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_get_offline_download_completed(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_playlist * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_get_offline_download_completed", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_get_offline_download_completed(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_get_offline_download_completed _cffi_d_sp_playlist_get_offline_download_completed
#endif

static sp_playlist_offline_status _cffi_d_sp_playlist_get_offline_status(sp_session * x0, sp_playlist * x1)
{
  return sp_playlist_get_offline_status(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_get_offline_status(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_playlist * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist_offline_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_get_offline_status", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_get_offline_status(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(780));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_get_offline_status _cffi_d_sp_playlist_get_offline_status
#endif

static unsigned char _cffi_d_sp_playlist_has_pending_changes(sp_playlist * x0)
{
  return sp_playlist_has_pending_changes(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_has_pending_changes(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_has_pending_changes(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_has_pending_changes _cffi_d_sp_playlist_has_pending_changes
#endif

static unsigned char _cffi_d_sp_playlist_is_collaborative(sp_playlist * x0)
{
  return sp_playlist_is_collaborative(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_is_collaborative(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_is_collaborative(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_is_collaborative _cffi_d_sp_playlist_is_collaborative
#endif

static unsigned char _cffi_d_sp_playlist_is_in_ram(sp_session * x0, sp_playlist * x1)
{
  return sp_playlist_is_in_ram(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_is_in_ram(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_playlist * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_is_in_ram", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_is_in_ram(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_is_in_ram _cffi_d_sp_playlist_is_in_ram
#endif

static unsigned char _cffi_d_sp_playlist_is_loaded(sp_playlist * x0)
{
  return sp_playlist_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_is_loaded _cffi_d_sp_playlist_is_loaded
#endif

static char const * _cffi_d_sp_playlist_name(sp_playlist * x0)
{
  return sp_playlist_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_name(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_name _cffi_d_sp_playlist_name
#endif

static unsigned int _cffi_d_sp_playlist_num_subscribers(sp_playlist * x0)
{
  return sp_playlist_num_subscribers(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_num_subscribers(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_num_subscribers(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_num_subscribers _cffi_d_sp_playlist_num_subscribers
#endif

static int _cffi_d_sp_playlist_num_tracks(sp_playlist * x0)
{
  return sp_playlist_num_tracks(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_num_tracks(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_num_tracks(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_num_tracks _cffi_d_sp_playlist_num_tracks
#endif

static sp_user * _cffi_d_sp_playlist_owner(sp_playlist * x0)
{
  return sp_playlist_owner(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_owner(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_user * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_owner(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(40));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_owner _cffi_d_sp_playlist_owner
#endif

static sp_error _cffi_d_sp_playlist_release(sp_playlist * x0)
{
  return sp_playlist_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_release(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_release _cffi_d_sp_playlist_release
#endif

static sp_error _cffi_d_sp_playlist_remove_callbacks(sp_playlist * x0, sp_playlist_callbacks * x1, void * x2)
{
  return sp_playlist_remove_callbacks(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_remove_callbacks(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  sp_playlist_callbacks * x1;
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlist_remove_callbacks", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(224), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist_callbacks *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(224), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_remove_callbacks(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_remove_callbacks _cffi_d_sp_playlist_remove_callbacks
#endif

static sp_error _cffi_d_sp_playlist_remove_tracks(sp_playlist * x0, int const * x1, int x2)
{
  return sp_playlist_remove_tracks(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_remove_tracks(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  int const * x1;
  int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlist_remove_tracks", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(208), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (int const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(208), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_remove_tracks(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_remove_tracks _cffi_d_sp_playlist_remove_tracks
#endif

static sp_error _cffi_d_sp_playlist_rename(sp_playlist * x0, char const * x1)
{
  return sp_playlist_rename(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_rename(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_rename", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_rename(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_rename _cffi_d_sp_playlist_rename
#endif

static sp_error _cffi_d_sp_playlist_reorder_tracks(sp_playlist * x0, int const * x1, int x2, int x3)
{
  return sp_playlist_reorder_tracks(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_reorder_tracks(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  int const * x1;
  int x2;
  int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "sp_playlist_reorder_tracks", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(208), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (int const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(208), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_reorder_tracks(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_reorder_tracks _cffi_d_sp_playlist_reorder_tracks
#endif

static sp_error _cffi_d_sp_playlist_set_autolink_tracks(sp_playlist * x0, unsigned char x1)
{
  return sp_playlist_set_autolink_tracks(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_set_autolink_tracks(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_set_autolink_tracks", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_set_autolink_tracks(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_set_autolink_tracks _cffi_d_sp_playlist_set_autolink_tracks
#endif

static sp_error _cffi_d_sp_playlist_set_collaborative(sp_playlist * x0, unsigned char x1)
{
  return sp_playlist_set_collaborative(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_set_collaborative(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_set_collaborative", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_set_collaborative(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_set_collaborative _cffi_d_sp_playlist_set_collaborative
#endif

static sp_error _cffi_d_sp_playlist_set_in_ram(sp_session * x0, sp_playlist * x1, unsigned char x2)
{
  return sp_playlist_set_in_ram(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_set_in_ram(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_playlist * x1;
  unsigned char x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlist_set_in_ram", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_set_in_ram(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_set_in_ram _cffi_d_sp_playlist_set_in_ram
#endif

static sp_error _cffi_d_sp_playlist_set_offline_mode(sp_session * x0, sp_playlist * x1, unsigned char x2)
{
  return sp_playlist_set_offline_mode(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_set_offline_mode(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_playlist * x1;
  unsigned char x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlist_set_offline_mode", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_set_offline_mode(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_set_offline_mode _cffi_d_sp_playlist_set_offline_mode
#endif

static sp_subscribers * _cffi_d_sp_playlist_subscribers(sp_playlist * x0)
{
  return sp_playlist_subscribers(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_subscribers(PyObject *self, PyObject *arg0)
{
  sp_playlist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_subscribers * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_subscribers(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(358));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_subscribers _cffi_d_sp_playlist_subscribers
#endif

static sp_error _cffi_d_sp_playlist_subscribers_free(sp_subscribers * x0)
{
  return sp_playlist_subscribers_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_subscribers_free(PyObject *self, PyObject *arg0)
{
  sp_subscribers * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(358), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_subscribers *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(358), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_subscribers_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_subscribers_free _cffi_d_sp_playlist_subscribers_free
#endif

static sp_track * _cffi_d_sp_playlist_track(sp_playlist * x0, int x1)
{
  return sp_playlist_track(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_track(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_track", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_track(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_track _cffi_d_sp_playlist_track
#endif

static int _cffi_d_sp_playlist_track_create_time(sp_playlist * x0, int x1)
{
  return sp_playlist_track_create_time(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_track_create_time(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_track_create_time", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_track_create_time(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_track_create_time _cffi_d_sp_playlist_track_create_time
#endif

static sp_user * _cffi_d_sp_playlist_track_creator(sp_playlist * x0, int x1)
{
  return sp_playlist_track_creator(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_track_creator(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_user * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_track_creator", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_track_creator(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(40));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_track_creator _cffi_d_sp_playlist_track_creator
#endif

static char const * _cffi_d_sp_playlist_track_message(sp_playlist * x0, int x1)
{
  return sp_playlist_track_message(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_track_message(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_track_message", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_track_message(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_track_message _cffi_d_sp_playlist_track_message
#endif

static unsigned char _cffi_d_sp_playlist_track_seen(sp_playlist * x0, int x1)
{
  return sp_playlist_track_seen(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_track_seen(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_track_seen", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_track_seen(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_track_seen _cffi_d_sp_playlist_track_seen
#endif

static sp_error _cffi_d_sp_playlist_track_set_seen(sp_playlist * x0, int x1, unsigned char x2)
{
  return sp_playlist_track_set_seen(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_track_set_seen(PyObject *self, PyObject *args)
{
  sp_playlist * x0;
  int x1;
  unsigned char x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlist_track_set_seen", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_track_set_seen(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_track_set_seen _cffi_d_sp_playlist_track_set_seen
#endif

static sp_error _cffi_d_sp_playlist_update_subscribers(sp_session * x0, sp_playlist * x1)
{
  return sp_playlist_update_subscribers(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlist_update_subscribers(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_playlist * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlist_update_subscribers", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlist_update_subscribers(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlist_update_subscribers _cffi_d_sp_playlist_update_subscribers
#endif

static sp_error _cffi_d_sp_playlistcontainer_add_callbacks(sp_playlistcontainer * x0, sp_playlistcontainer_callbacks * x1, void * x2)
{
  return sp_playlistcontainer_add_callbacks(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_add_callbacks(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  sp_playlistcontainer_callbacks * x1;
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_add_callbacks", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(264), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer_callbacks *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(264), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_add_callbacks(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_add_callbacks _cffi_d_sp_playlistcontainer_add_callbacks
#endif

static sp_error _cffi_d_sp_playlistcontainer_add_folder(sp_playlistcontainer * x0, int x1, char const * x2)
{
  return sp_playlistcontainer_add_folder(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_add_folder(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  int x1;
  char const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_add_folder", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_add_folder(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_add_folder _cffi_d_sp_playlistcontainer_add_folder
#endif

static sp_playlist * _cffi_d_sp_playlistcontainer_add_new_playlist(sp_playlistcontainer * x0, char const * x1)
{
  return sp_playlistcontainer_add_new_playlist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_add_new_playlist(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_add_new_playlist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_add_new_playlist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_add_new_playlist _cffi_d_sp_playlistcontainer_add_new_playlist
#endif

static sp_playlist * _cffi_d_sp_playlistcontainer_add_playlist(sp_playlistcontainer * x0, sp_link * x1)
{
  return sp_playlistcontainer_add_playlist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_add_playlist(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  sp_link * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_add_playlist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_link *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_add_playlist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_add_playlist _cffi_d_sp_playlistcontainer_add_playlist
#endif

static sp_error _cffi_d_sp_playlistcontainer_add_ref(sp_playlistcontainer * x0)
{
  return sp_playlistcontainer_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_add_ref(PyObject *self, PyObject *arg0)
{
  sp_playlistcontainer * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_add_ref _cffi_d_sp_playlistcontainer_add_ref
#endif

static int _cffi_d_sp_playlistcontainer_clear_unseen_tracks(sp_playlistcontainer * x0, sp_playlist * x1)
{
  return sp_playlistcontainer_clear_unseen_tracks(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_clear_unseen_tracks(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  sp_playlist * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_clear_unseen_tracks", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_clear_unseen_tracks(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_clear_unseen_tracks _cffi_d_sp_playlistcontainer_clear_unseen_tracks
#endif

static int _cffi_d_sp_playlistcontainer_get_unseen_tracks(sp_playlistcontainer * x0, sp_playlist * x1, sp_track * * x2, int x3)
{
  return sp_playlistcontainer_get_unseen_tracks(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_get_unseen_tracks(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  sp_playlist * x1;
  sp_track * * x2;
  int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_get_unseen_tracks", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(75), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (sp_track * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(75), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_get_unseen_tracks(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_get_unseen_tracks _cffi_d_sp_playlistcontainer_get_unseen_tracks
#endif

static unsigned char _cffi_d_sp_playlistcontainer_is_loaded(sp_playlistcontainer * x0)
{
  return sp_playlistcontainer_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_playlistcontainer * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_is_loaded _cffi_d_sp_playlistcontainer_is_loaded
#endif

static sp_error _cffi_d_sp_playlistcontainer_move_playlist(sp_playlistcontainer * x0, int x1, int x2, unsigned char x3)
{
  return sp_playlistcontainer_move_playlist(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_move_playlist(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  int x1;
  int x2;
  unsigned char x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_move_playlist", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_move_playlist(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_move_playlist _cffi_d_sp_playlistcontainer_move_playlist
#endif

static int _cffi_d_sp_playlistcontainer_num_playlists(sp_playlistcontainer * x0)
{
  return sp_playlistcontainer_num_playlists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_num_playlists(PyObject *self, PyObject *arg0)
{
  sp_playlistcontainer * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_num_playlists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_num_playlists _cffi_d_sp_playlistcontainer_num_playlists
#endif

static sp_user * _cffi_d_sp_playlistcontainer_owner(sp_playlistcontainer * x0)
{
  return sp_playlistcontainer_owner(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_owner(PyObject *self, PyObject *arg0)
{
  sp_playlistcontainer * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_user * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_owner(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(40));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_owner _cffi_d_sp_playlistcontainer_owner
#endif

static sp_playlist * _cffi_d_sp_playlistcontainer_playlist(sp_playlistcontainer * x0, int x1)
{
  return sp_playlistcontainer_playlist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_playlist(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_playlist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_playlist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_playlist _cffi_d_sp_playlistcontainer_playlist
#endif

static uint64_t _cffi_d_sp_playlistcontainer_playlist_folder_id(sp_playlistcontainer * x0, int x1)
{
  return sp_playlistcontainer_playlist_folder_id(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_playlist_folder_id(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_playlist_folder_id", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_playlist_folder_id(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_playlist_folder_id _cffi_d_sp_playlistcontainer_playlist_folder_id
#endif

static sp_error _cffi_d_sp_playlistcontainer_playlist_folder_name(sp_playlistcontainer * x0, int x1, char * x2, int x3)
{
  return sp_playlistcontainer_playlist_folder_name(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_playlist_folder_name(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  int x1;
  char * x2;
  int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_playlist_folder_name", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(55), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(55), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_playlist_folder_name(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_playlist_folder_name _cffi_d_sp_playlistcontainer_playlist_folder_name
#endif

static sp_playlist_type _cffi_d_sp_playlistcontainer_playlist_type(sp_playlistcontainer * x0, int x1)
{
  return sp_playlistcontainer_playlist_type(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_playlist_type(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist_type result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_playlist_type", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_playlist_type(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(781));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_playlist_type _cffi_d_sp_playlistcontainer_playlist_type
#endif

static sp_error _cffi_d_sp_playlistcontainer_release(sp_playlistcontainer * x0)
{
  return sp_playlistcontainer_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_release(PyObject *self, PyObject *arg0)
{
  sp_playlistcontainer * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_release _cffi_d_sp_playlistcontainer_release
#endif

static sp_error _cffi_d_sp_playlistcontainer_remove_callbacks(sp_playlistcontainer * x0, sp_playlistcontainer_callbacks * x1, void * x2)
{
  return sp_playlistcontainer_remove_callbacks(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_remove_callbacks(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  sp_playlistcontainer_callbacks * x1;
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_remove_callbacks", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(264), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer_callbacks *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(264), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_remove_callbacks(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_remove_callbacks _cffi_d_sp_playlistcontainer_remove_callbacks
#endif

static sp_error _cffi_d_sp_playlistcontainer_remove_playlist(sp_playlistcontainer * x0, int x1)
{
  return sp_playlistcontainer_remove_playlist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_playlistcontainer_remove_playlist(PyObject *self, PyObject *args)
{
  sp_playlistcontainer * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_playlistcontainer_remove_playlist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_playlistcontainer *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_playlistcontainer_remove_playlist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_playlistcontainer_remove_playlist _cffi_d_sp_playlistcontainer_remove_playlist
#endif

static sp_error _cffi_d_sp_search_add_ref(sp_search * x0)
{
  return sp_search_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_add_ref(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_add_ref _cffi_d_sp_search_add_ref
#endif

static sp_album * _cffi_d_sp_search_album(sp_search * x0, int x1)
{
  return sp_search_album(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_album(PyObject *self, PyObject *args)
{
  sp_search * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_album * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_search_album", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_album(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_album _cffi_d_sp_search_album
#endif

static sp_artist * _cffi_d_sp_search_artist(sp_search * x0, int x1)
{
  return sp_search_artist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_artist(PyObject *self, PyObject *args)
{
  sp_search * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_search_artist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_artist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_artist _cffi_d_sp_search_artist
#endif

static sp_search * _cffi_d_sp_search_create(sp_session * x0, char const * x1, int x2, int x3, int x4, int x5, int x6, int x7, int x8, int x9, sp_search_type x10, void(* x11)(sp_search *, void *), void * x12)
{
  return sp_search_create(x0, x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_create(PyObject *self, PyObject *args)
{
  sp_session * x0;
  char const * x1;
  int x2;
  int x3;
  int x4;
  int x5;
  int x6;
  int x7;
  int x8;
  int x9;
  sp_search_type x10;
  void(* x11)(sp_search *, void *);
  void * x12;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_search * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;
  PyObject *arg8;
  PyObject *arg9;
  PyObject *arg10;
  PyObject *arg11;
  PyObject *arg12;

  if (!PyArg_UnpackTuple(args, "sp_search_create", 13, 13, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7, &arg8, &arg9, &arg10, &arg11, &arg12))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, int);
  if (x5 == (int)-1 && PyErr_Occurred())
    return NULL;

  x6 = _cffi_to_c_int(arg6, int);
  if (x6 == (int)-1 && PyErr_Occurred())
    return NULL;

  x7 = _cffi_to_c_int(arg7, int);
  if (x7 == (int)-1 && PyErr_Occurred())
    return NULL;

  x8 = _cffi_to_c_int(arg8, int);
  if (x8 == (int)-1 && PyErr_Occurred())
    return NULL;

  x9 = _cffi_to_c_int(arg9, int);
  if (x9 == (int)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x10, _cffi_type(482), arg10) < 0)
    return NULL;

  x11 = (void(*)(sp_search *, void *))_cffi_to_c_pointer(arg11, _cffi_type(483));
  if (x11 == (void(*)(sp_search *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg12, (char **)&x12);
  if (datasize != 0) {
    x12 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg12, (char **)&x12,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_create(x0, x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(27));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_create _cffi_d_sp_search_create
#endif

static char const * _cffi_d_sp_search_did_you_mean(sp_search * x0)
{
  return sp_search_did_you_mean(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_did_you_mean(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_did_you_mean(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_did_you_mean _cffi_d_sp_search_did_you_mean
#endif

static sp_error _cffi_d_sp_search_error(sp_search * x0)
{
  return sp_search_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_error(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_error _cffi_d_sp_search_error
#endif

static unsigned char _cffi_d_sp_search_is_loaded(sp_search * x0)
{
  return sp_search_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_is_loaded _cffi_d_sp_search_is_loaded
#endif

static int _cffi_d_sp_search_num_albums(sp_search * x0)
{
  return sp_search_num_albums(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_num_albums(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_num_albums(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_num_albums _cffi_d_sp_search_num_albums
#endif

static int _cffi_d_sp_search_num_artists(sp_search * x0)
{
  return sp_search_num_artists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_num_artists(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_num_artists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_num_artists _cffi_d_sp_search_num_artists
#endif

static int _cffi_d_sp_search_num_playlists(sp_search * x0)
{
  return sp_search_num_playlists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_num_playlists(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_num_playlists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_num_playlists _cffi_d_sp_search_num_playlists
#endif

static int _cffi_d_sp_search_num_tracks(sp_search * x0)
{
  return sp_search_num_tracks(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_num_tracks(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_num_tracks(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_num_tracks _cffi_d_sp_search_num_tracks
#endif

static sp_playlist * _cffi_d_sp_search_playlist(sp_search * x0, int x1)
{
  return sp_search_playlist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_playlist(PyObject *self, PyObject *args)
{
  sp_search * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_search_playlist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_playlist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_playlist _cffi_d_sp_search_playlist
#endif

static char const * _cffi_d_sp_search_playlist_image_uri(sp_search * x0, int x1)
{
  return sp_search_playlist_image_uri(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_playlist_image_uri(PyObject *self, PyObject *args)
{
  sp_search * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_search_playlist_image_uri", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_playlist_image_uri(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_playlist_image_uri _cffi_d_sp_search_playlist_image_uri
#endif

static char const * _cffi_d_sp_search_playlist_name(sp_search * x0, int x1)
{
  return sp_search_playlist_name(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_playlist_name(PyObject *self, PyObject *args)
{
  sp_search * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_search_playlist_name", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_playlist_name(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_playlist_name _cffi_d_sp_search_playlist_name
#endif

static char const * _cffi_d_sp_search_playlist_uri(sp_search * x0, int x1)
{
  return sp_search_playlist_uri(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_playlist_uri(PyObject *self, PyObject *args)
{
  sp_search * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_search_playlist_uri", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_playlist_uri(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_playlist_uri _cffi_d_sp_search_playlist_uri
#endif

static char const * _cffi_d_sp_search_query(sp_search * x0)
{
  return sp_search_query(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_query(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_query(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_query _cffi_d_sp_search_query
#endif

static sp_error _cffi_d_sp_search_release(sp_search * x0)
{
  return sp_search_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_release(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_release _cffi_d_sp_search_release
#endif

static int _cffi_d_sp_search_total_albums(sp_search * x0)
{
  return sp_search_total_albums(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_total_albums(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_total_albums(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_total_albums _cffi_d_sp_search_total_albums
#endif

static int _cffi_d_sp_search_total_artists(sp_search * x0)
{
  return sp_search_total_artists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_total_artists(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_total_artists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_total_artists _cffi_d_sp_search_total_artists
#endif

static int _cffi_d_sp_search_total_playlists(sp_search * x0)
{
  return sp_search_total_playlists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_total_playlists(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_total_playlists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_total_playlists _cffi_d_sp_search_total_playlists
#endif

static int _cffi_d_sp_search_total_tracks(sp_search * x0)
{
  return sp_search_total_tracks(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_total_tracks(PyObject *self, PyObject *arg0)
{
  sp_search * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_total_tracks(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_total_tracks _cffi_d_sp_search_total_tracks
#endif

static sp_track * _cffi_d_sp_search_track(sp_search * x0, int x1)
{
  return sp_search_track(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_search_track(PyObject *self, PyObject *args)
{
  sp_search * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_search_track", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(27), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_search *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(27), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_search_track(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_search_track _cffi_d_sp_search_track
#endif

static sp_connectionstate _cffi_d_sp_session_connectionstate(sp_session * x0)
{
  return sp_session_connectionstate(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_connectionstate(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_connectionstate result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_connectionstate(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(771));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_connectionstate _cffi_d_sp_session_connectionstate
#endif

static sp_error _cffi_d_sp_session_create(sp_session_config const * x0, sp_session * * x1)
{
  return sp_session_create(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_create(PyObject *self, PyObject *args)
{
  sp_session_config const * x0;
  sp_session * * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_create", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(354), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session_config const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(354), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(355), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_session * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(355), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_create(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_create _cffi_d_sp_session_create
#endif

static sp_error _cffi_d_sp_session_flush_caches(sp_session * x0)
{
  return sp_session_flush_caches(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_flush_caches(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_flush_caches(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_flush_caches _cffi_d_sp_session_flush_caches
#endif

static sp_error _cffi_d_sp_session_forget_me(sp_session * x0)
{
  return sp_session_forget_me(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_forget_me(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_forget_me(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_forget_me _cffi_d_sp_session_forget_me
#endif

static unsigned char _cffi_d_sp_session_get_volume_normalization(sp_session * x0)
{
  return sp_session_get_volume_normalization(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_get_volume_normalization(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_get_volume_normalization(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_get_volume_normalization _cffi_d_sp_session_get_volume_normalization
#endif

static sp_playlist * _cffi_d_sp_session_inbox_create(sp_session * x0)
{
  return sp_session_inbox_create(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_inbox_create(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_inbox_create(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_inbox_create _cffi_d_sp_session_inbox_create
#endif

static unsigned char _cffi_d_sp_session_is_private_session(sp_session * x0)
{
  return sp_session_is_private_session(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_is_private_session(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_is_private_session(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_is_private_session _cffi_d_sp_session_is_private_session
#endif

static sp_error _cffi_d_sp_session_is_scrobbling(sp_session * x0, sp_social_provider x1, sp_scrobbling_state * x2)
{
  return sp_session_is_scrobbling(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_is_scrobbling(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_social_provider x1;
  sp_scrobbling_state * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_session_is_scrobbling", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(320), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(327), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (sp_scrobbling_state *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(327), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_is_scrobbling(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_is_scrobbling _cffi_d_sp_session_is_scrobbling
#endif

static sp_error _cffi_d_sp_session_is_scrobbling_possible(sp_session * x0, sp_social_provider x1, unsigned char * x2)
{
  return sp_session_is_scrobbling_possible(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_is_scrobbling_possible(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_social_provider x1;
  unsigned char * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_session_is_scrobbling_possible", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(320), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(337), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(337), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_is_scrobbling_possible(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_is_scrobbling_possible _cffi_d_sp_session_is_scrobbling_possible
#endif

static sp_error _cffi_d_sp_session_login(sp_session * x0, char const * x1, char const * x2, unsigned char x3, char const * x4)
{
  return sp_session_login(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_login(PyObject *self, PyObject *args)
{
  sp_session * x0;
  char const * x1;
  char const * x2;
  unsigned char x3;
  char const * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "sp_session_login", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_login(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_login _cffi_d_sp_session_login
#endif

static sp_error _cffi_d_sp_session_logout(sp_session * x0)
{
  return sp_session_logout(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_logout(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_logout(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_logout _cffi_d_sp_session_logout
#endif

static sp_error _cffi_d_sp_session_player_load(sp_session * x0, sp_track * x1)
{
  return sp_session_player_load(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_player_load(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_track * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_player_load", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_player_load(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_player_load _cffi_d_sp_session_player_load
#endif

static sp_error _cffi_d_sp_session_player_play(sp_session * x0, unsigned char x1)
{
  return sp_session_player_play(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_player_play(PyObject *self, PyObject *args)
{
  sp_session * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_player_play", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_player_play(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_player_play _cffi_d_sp_session_player_play
#endif

static sp_error _cffi_d_sp_session_player_prefetch(sp_session * x0, sp_track * x1)
{
  return sp_session_player_prefetch(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_player_prefetch(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_track * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_player_prefetch", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_player_prefetch(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_player_prefetch _cffi_d_sp_session_player_prefetch
#endif

static sp_error _cffi_d_sp_session_player_seek(sp_session * x0, int x1)
{
  return sp_session_player_seek(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_player_seek(PyObject *self, PyObject *args)
{
  sp_session * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_player_seek", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_player_seek(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_player_seek _cffi_d_sp_session_player_seek
#endif

static sp_error _cffi_d_sp_session_player_unload(sp_session * x0)
{
  return sp_session_player_unload(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_player_unload(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_player_unload(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_player_unload _cffi_d_sp_session_player_unload
#endif

static sp_playlistcontainer * _cffi_d_sp_session_playlistcontainer(sp_session * x0)
{
  return sp_session_playlistcontainer(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_playlistcontainer(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlistcontainer * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_playlistcontainer(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(66));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_playlistcontainer _cffi_d_sp_session_playlistcontainer
#endif

static sp_error _cffi_d_sp_session_preferred_bitrate(sp_session * x0, sp_bitrate x1)
{
  return sp_session_preferred_bitrate(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_preferred_bitrate(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_bitrate x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_preferred_bitrate", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(294), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_preferred_bitrate(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_preferred_bitrate _cffi_d_sp_session_preferred_bitrate
#endif

static sp_error _cffi_d_sp_session_preferred_offline_bitrate(sp_session * x0, sp_bitrate x1, unsigned char x2)
{
  return sp_session_preferred_offline_bitrate(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_preferred_offline_bitrate(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_bitrate x1;
  unsigned char x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_session_preferred_offline_bitrate", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(294), arg1) < 0)
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_preferred_offline_bitrate(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_preferred_offline_bitrate _cffi_d_sp_session_preferred_offline_bitrate
#endif

static sp_error _cffi_d_sp_session_process_events(sp_session * x0, int * x1)
{
  return sp_session_process_events(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_process_events(PyObject *self, PyObject *args)
{
  sp_session * x0;
  int * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_process_events", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(282), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (int *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(282), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_process_events(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_process_events _cffi_d_sp_session_process_events
#endif

static sp_playlistcontainer * _cffi_d_sp_session_publishedcontainer_for_user_create(sp_session * x0, char const * x1)
{
  return sp_session_publishedcontainer_for_user_create(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_publishedcontainer_for_user_create(PyObject *self, PyObject *args)
{
  sp_session * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlistcontainer * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_publishedcontainer_for_user_create", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_publishedcontainer_for_user_create(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(66));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_publishedcontainer_for_user_create _cffi_d_sp_session_publishedcontainer_for_user_create
#endif

static sp_error _cffi_d_sp_session_release(sp_session * x0)
{
  return sp_session_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_release(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_release _cffi_d_sp_session_release
#endif

static sp_error _cffi_d_sp_session_relogin(sp_session * x0)
{
  return sp_session_relogin(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_relogin(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_relogin(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_relogin _cffi_d_sp_session_relogin
#endif

static int _cffi_d_sp_session_remembered_user(sp_session * x0, char * x1, size_t x2)
{
  return sp_session_remembered_user(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_remembered_user(PyObject *self, PyObject *args)
{
  sp_session * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_session_remembered_user", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(55), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(55), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_remembered_user(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_remembered_user _cffi_d_sp_session_remembered_user
#endif

static sp_error _cffi_d_sp_session_set_cache_size(sp_session * x0, size_t x1)
{
  return sp_session_set_cache_size(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_set_cache_size(PyObject *self, PyObject *args)
{
  sp_session * x0;
  size_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_set_cache_size", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_set_cache_size(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_set_cache_size _cffi_d_sp_session_set_cache_size
#endif

static sp_error _cffi_d_sp_session_set_connection_rules(sp_session * x0, sp_connection_rules x1)
{
  return sp_session_set_connection_rules(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_set_connection_rules(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_connection_rules x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_set_connection_rules", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(303), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_set_connection_rules(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_set_connection_rules _cffi_d_sp_session_set_connection_rules
#endif

static sp_error _cffi_d_sp_session_set_connection_type(sp_session * x0, sp_connection_type x1)
{
  return sp_session_set_connection_type(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_set_connection_type(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_connection_type x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_set_connection_type", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(307), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_set_connection_type(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_set_connection_type _cffi_d_sp_session_set_connection_type
#endif

static sp_error _cffi_d_sp_session_set_private_session(sp_session * x0, unsigned char x1)
{
  return sp_session_set_private_session(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_set_private_session(PyObject *self, PyObject *args)
{
  sp_session * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_set_private_session", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_set_private_session(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_set_private_session _cffi_d_sp_session_set_private_session
#endif

static sp_error _cffi_d_sp_session_set_scrobbling(sp_session * x0, sp_social_provider x1, sp_scrobbling_state x2)
{
  return sp_session_set_scrobbling(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_set_scrobbling(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_social_provider x1;
  sp_scrobbling_state x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "sp_session_set_scrobbling", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(320), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(332), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_set_scrobbling(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_set_scrobbling _cffi_d_sp_session_set_scrobbling
#endif

static sp_error _cffi_d_sp_session_set_social_credentials(sp_session * x0, sp_social_provider x1, char const * x2, char const * x3)
{
  return sp_session_set_social_credentials(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_set_social_credentials(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_social_provider x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "sp_session_set_social_credentials", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(320), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_set_social_credentials(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_set_social_credentials _cffi_d_sp_session_set_social_credentials
#endif

static sp_error _cffi_d_sp_session_set_volume_normalization(sp_session * x0, unsigned char x1)
{
  return sp_session_set_volume_normalization(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_set_volume_normalization(PyObject *self, PyObject *args)
{
  sp_session * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_set_volume_normalization", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_set_volume_normalization(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_set_volume_normalization _cffi_d_sp_session_set_volume_normalization
#endif

static sp_playlist * _cffi_d_sp_session_starred_create(sp_session * x0)
{
  return sp_session_starred_create(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_starred_create(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_starred_create(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_starred_create _cffi_d_sp_session_starred_create
#endif

static sp_playlist * _cffi_d_sp_session_starred_for_user_create(sp_session * x0, char const * x1)
{
  return sp_session_starred_for_user_create(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_starred_for_user_create(PyObject *self, PyObject *args)
{
  sp_session * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_playlist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_session_starred_for_user_create", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_starred_for_user_create(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_starred_for_user_create _cffi_d_sp_session_starred_for_user_create
#endif

static sp_user * _cffi_d_sp_session_user(sp_session * x0)
{
  return sp_session_user(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_user(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_user * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_user(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(40));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_user _cffi_d_sp_session_user
#endif

static int _cffi_d_sp_session_user_country(sp_session * x0)
{
  return sp_session_user_country(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_user_country(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_user_country(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_user_country _cffi_d_sp_session_user_country
#endif

static char const * _cffi_d_sp_session_user_name(sp_session * x0)
{
  return sp_session_user_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_user_name(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_user_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_user_name _cffi_d_sp_session_user_name
#endif

static void * _cffi_d_sp_session_userdata(sp_session * x0)
{
  return sp_session_userdata(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_session_userdata(PyObject *self, PyObject *arg0)
{
  sp_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_session_userdata(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(130));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_session_userdata _cffi_d_sp_session_userdata
#endif

static sp_error _cffi_d_sp_toplistbrowse_add_ref(sp_toplistbrowse * x0)
{
  return sp_toplistbrowse_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_add_ref(PyObject *self, PyObject *arg0)
{
  sp_toplistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_add_ref _cffi_d_sp_toplistbrowse_add_ref
#endif

static sp_album * _cffi_d_sp_toplistbrowse_album(sp_toplistbrowse * x0, int x1)
{
  return sp_toplistbrowse_album(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_album(PyObject *self, PyObject *args)
{
  sp_toplistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_album * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_toplistbrowse_album", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_album(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_album _cffi_d_sp_toplistbrowse_album
#endif

static sp_artist * _cffi_d_sp_toplistbrowse_artist(sp_toplistbrowse * x0, int x1)
{
  return sp_toplistbrowse_artist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_artist(PyObject *self, PyObject *args)
{
  sp_toplistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_toplistbrowse_artist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_artist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_artist _cffi_d_sp_toplistbrowse_artist
#endif

static int _cffi_d_sp_toplistbrowse_backend_request_duration(sp_toplistbrowse * x0)
{
  return sp_toplistbrowse_backend_request_duration(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_backend_request_duration(PyObject *self, PyObject *arg0)
{
  sp_toplistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_backend_request_duration(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_backend_request_duration _cffi_d_sp_toplistbrowse_backend_request_duration
#endif

static sp_toplistbrowse * _cffi_d_sp_toplistbrowse_create(sp_session * x0, sp_toplisttype x1, sp_toplistregion x2, char const * x3, void(* x4)(sp_toplistbrowse *, void *), void * x5)
{
  return sp_toplistbrowse_create(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_create(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_toplisttype x1;
  sp_toplistregion x2;
  char const * x3;
  void(* x4)(sp_toplistbrowse *, void *);
  void * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_toplistbrowse * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_toplistbrowse_create", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(491), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(492), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = (void(*)(sp_toplistbrowse *, void *))_cffi_to_c_pointer(arg4, _cffi_type(494));
  if (x4 == (void(*)(sp_toplistbrowse *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_create(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(100));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_create _cffi_d_sp_toplistbrowse_create
#endif

static sp_error _cffi_d_sp_toplistbrowse_error(sp_toplistbrowse * x0)
{
  return sp_toplistbrowse_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_error(PyObject *self, PyObject *arg0)
{
  sp_toplistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_error _cffi_d_sp_toplistbrowse_error
#endif

static unsigned char _cffi_d_sp_toplistbrowse_is_loaded(sp_toplistbrowse * x0)
{
  return sp_toplistbrowse_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_toplistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_is_loaded _cffi_d_sp_toplistbrowse_is_loaded
#endif

static int _cffi_d_sp_toplistbrowse_num_albums(sp_toplistbrowse * x0)
{
  return sp_toplistbrowse_num_albums(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_num_albums(PyObject *self, PyObject *arg0)
{
  sp_toplistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_num_albums(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_num_albums _cffi_d_sp_toplistbrowse_num_albums
#endif

static int _cffi_d_sp_toplistbrowse_num_artists(sp_toplistbrowse * x0)
{
  return sp_toplistbrowse_num_artists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_num_artists(PyObject *self, PyObject *arg0)
{
  sp_toplistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_num_artists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_num_artists _cffi_d_sp_toplistbrowse_num_artists
#endif

static int _cffi_d_sp_toplistbrowse_num_tracks(sp_toplistbrowse * x0)
{
  return sp_toplistbrowse_num_tracks(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_num_tracks(PyObject *self, PyObject *arg0)
{
  sp_toplistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_num_tracks(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_num_tracks _cffi_d_sp_toplistbrowse_num_tracks
#endif

static sp_error _cffi_d_sp_toplistbrowse_release(sp_toplistbrowse * x0)
{
  return sp_toplistbrowse_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_release(PyObject *self, PyObject *arg0)
{
  sp_toplistbrowse * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_release _cffi_d_sp_toplistbrowse_release
#endif

static sp_track * _cffi_d_sp_toplistbrowse_track(sp_toplistbrowse * x0, int x1)
{
  return sp_toplistbrowse_track(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_toplistbrowse_track(PyObject *self, PyObject *args)
{
  sp_toplistbrowse * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_toplistbrowse_track", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(100), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_toplistbrowse *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(100), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_toplistbrowse_track(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_toplistbrowse_track _cffi_d_sp_toplistbrowse_track
#endif

static sp_error _cffi_d_sp_track_add_ref(sp_track * x0)
{
  return sp_track_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_add_ref(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_add_ref _cffi_d_sp_track_add_ref
#endif

static sp_album * _cffi_d_sp_track_album(sp_track * x0)
{
  return sp_track_album(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_album(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_album * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_album(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_album _cffi_d_sp_track_album
#endif

static sp_artist * _cffi_d_sp_track_artist(sp_track * x0, int x1)
{
  return sp_track_artist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_artist(PyObject *self, PyObject *args)
{
  sp_track * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_artist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_track_artist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_artist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_artist _cffi_d_sp_track_artist
#endif

static int _cffi_d_sp_track_disc(sp_track * x0)
{
  return sp_track_disc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_disc(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_disc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_disc _cffi_d_sp_track_disc
#endif

static int _cffi_d_sp_track_duration(sp_track * x0)
{
  return sp_track_duration(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_duration(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_duration(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_duration _cffi_d_sp_track_duration
#endif

static sp_error _cffi_d_sp_track_error(sp_track * x0)
{
  return sp_track_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_error(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_error _cffi_d_sp_track_error
#endif

static sp_track_availability _cffi_d_sp_track_get_availability(sp_session * x0, sp_track * x1)
{
  return sp_track_get_availability(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_get_availability(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_track * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track_availability result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_track_get_availability", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_get_availability(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(794));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_get_availability _cffi_d_sp_track_get_availability
#endif

static sp_track * _cffi_d_sp_track_get_playable(sp_session * x0, sp_track * x1)
{
  return sp_track_get_playable(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_get_playable(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_track * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_track_get_playable", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_get_playable(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_get_playable _cffi_d_sp_track_get_playable
#endif

static int _cffi_d_sp_track_index(sp_track * x0)
{
  return sp_track_index(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_index(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_index(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_index _cffi_d_sp_track_index
#endif

static unsigned char _cffi_d_sp_track_is_autolinked(sp_session * x0, sp_track * x1)
{
  return sp_track_is_autolinked(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_is_autolinked(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_track * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_track_is_autolinked", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_is_autolinked(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_is_autolinked _cffi_d_sp_track_is_autolinked
#endif

static unsigned char _cffi_d_sp_track_is_loaded(sp_track * x0)
{
  return sp_track_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_is_loaded _cffi_d_sp_track_is_loaded
#endif

static unsigned char _cffi_d_sp_track_is_local(sp_session * x0, sp_track * x1)
{
  return sp_track_is_local(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_is_local(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_track * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_track_is_local", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_is_local(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_is_local _cffi_d_sp_track_is_local
#endif

static unsigned char _cffi_d_sp_track_is_placeholder(sp_track * x0)
{
  return sp_track_is_placeholder(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_is_placeholder(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_is_placeholder(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_is_placeholder _cffi_d_sp_track_is_placeholder
#endif

static unsigned char _cffi_d_sp_track_is_starred(sp_session * x0, sp_track * x1)
{
  return sp_track_is_starred(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_is_starred(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_track * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "sp_track_is_starred", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_is_starred(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_is_starred _cffi_d_sp_track_is_starred
#endif

static char const * _cffi_d_sp_track_name(sp_track * x0)
{
  return sp_track_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_name(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_name _cffi_d_sp_track_name
#endif

static int _cffi_d_sp_track_num_artists(sp_track * x0)
{
  return sp_track_num_artists(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_num_artists(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_num_artists(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_num_artists _cffi_d_sp_track_num_artists
#endif

static sp_track_offline_status _cffi_d_sp_track_offline_get_status(sp_track * x0)
{
  return sp_track_offline_get_status(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_offline_get_status(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_track_offline_status result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_offline_get_status(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(795));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_offline_get_status _cffi_d_sp_track_offline_get_status
#endif

static int _cffi_d_sp_track_popularity(sp_track * x0)
{
  return sp_track_popularity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_popularity(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_popularity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_popularity _cffi_d_sp_track_popularity
#endif

static sp_error _cffi_d_sp_track_release(sp_track * x0)
{
  return sp_track_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_release(PyObject *self, PyObject *arg0)
{
  sp_track * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_track *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_release _cffi_d_sp_track_release
#endif

static sp_error _cffi_d_sp_track_set_starred(sp_session * x0, sp_track * const * x1, int x2, unsigned char x3)
{
  return sp_track_set_starred(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_track_set_starred(PyObject *self, PyObject *args)
{
  sp_session * x0;
  sp_track * const * x1;
  int x2;
  unsigned char x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "sp_track_set_starred", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(229), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (sp_track * const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(229), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_track_set_starred(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_track_set_starred _cffi_d_sp_track_set_starred
#endif

static sp_error _cffi_d_sp_user_add_ref(sp_user * x0)
{
  return sp_user_add_ref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_user_add_ref(PyObject *self, PyObject *arg0)
{
  sp_user * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(40), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_user *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(40), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_user_add_ref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_user_add_ref _cffi_d_sp_user_add_ref
#endif

static char const * _cffi_d_sp_user_canonical_name(sp_user * x0)
{
  return sp_user_canonical_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_user_canonical_name(PyObject *self, PyObject *arg0)
{
  sp_user * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(40), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_user *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(40), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_user_canonical_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_user_canonical_name _cffi_d_sp_user_canonical_name
#endif

static char const * _cffi_d_sp_user_display_name(sp_user * x0)
{
  return sp_user_display_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_user_display_name(PyObject *self, PyObject *arg0)
{
  sp_user * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(40), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_user *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(40), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_user_display_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_user_display_name _cffi_d_sp_user_display_name
#endif

static unsigned char _cffi_d_sp_user_is_loaded(sp_user * x0)
{
  return sp_user_is_loaded(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_user_is_loaded(PyObject *self, PyObject *arg0)
{
  sp_user * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(40), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_user *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(40), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_user_is_loaded(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_user_is_loaded _cffi_d_sp_user_is_loaded
#endif

static sp_error _cffi_d_sp_user_release(sp_user * x0)
{
  return sp_user_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_user_release(PyObject *self, PyObject *arg0)
{
  sp_user * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  sp_error result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(40), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (sp_user *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(40), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = sp_user_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_sp_user_release _cffi_d_sp_user_release
#endif

static int _cffi_const_SPOTIFY_API_VERSION(unsigned long long *o)
{
  int n = (SPOTIFY_API_VERSION) <= 0;
  *o = (unsigned long long)((SPOTIFY_API_VERSION) | 0);  /* check that SPOTIFY_API_VERSION is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld__sp_audio_buffer_stats(sp_audio_buffer_stats *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->samples) | 0);  /* check that 'sp_audio_buffer_stats.samples' is an integer */
  (void)((p->stutter) | 0);  /* check that 'sp_audio_buffer_stats.stutter' is an integer */
}
struct _cffi_align__sp_audio_buffer_stats { char x; sp_audio_buffer_stats y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__sp_audioformat(sp_audioformat *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { sp_sampletype *tmp = &p->sample_type; (void)tmp; }
  (void)((p->sample_rate) | 0);  /* check that 'sp_audioformat.sample_rate' is an integer */
  (void)((p->channels) | 0);  /* check that 'sp_audioformat.channels' is an integer */
}
struct _cffi_align__sp_audioformat { char x; sp_audioformat y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__sp_offline_sync_status(sp_offline_sync_status *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->queued_tracks) | 0);  /* check that 'sp_offline_sync_status.queued_tracks' is an integer */
  (void)((p->queued_bytes) | 0);  /* check that 'sp_offline_sync_status.queued_bytes' is an integer */
  (void)((p->done_tracks) | 0);  /* check that 'sp_offline_sync_status.done_tracks' is an integer */
  (void)((p->done_bytes) | 0);  /* check that 'sp_offline_sync_status.done_bytes' is an integer */
  (void)((p->copied_tracks) | 0);  /* check that 'sp_offline_sync_status.copied_tracks' is an integer */
  (void)((p->copied_bytes) | 0);  /* check that 'sp_offline_sync_status.copied_bytes' is an integer */
  (void)((p->willnotcopy_tracks) | 0);  /* check that 'sp_offline_sync_status.willnotcopy_tracks' is an integer */
  (void)((p->error_tracks) | 0);  /* check that 'sp_offline_sync_status.error_tracks' is an integer */
  (void)((p->syncing) | 0);  /* check that 'sp_offline_sync_status.syncing' is an integer */
}
struct _cffi_align__sp_offline_sync_status { char x; sp_offline_sync_status y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__sp_playlist_callbacks(sp_playlist_callbacks *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void(* *tmp)(sp_playlist *, sp_track * const *, int, int, void *) = &p->tracks_added; (void)tmp; }
  { void(* *tmp)(sp_playlist *, int const *, int, void *) = &p->tracks_removed; (void)tmp; }
  { void(* *tmp)(sp_playlist *, int const *, int, int, void *) = &p->tracks_moved; (void)tmp; }
  { void(* *tmp)(sp_playlist *, void *) = &p->playlist_renamed; (void)tmp; }
  { void(* *tmp)(sp_playlist *, void *) = &p->playlist_state_changed; (void)tmp; }
  { void(* *tmp)(sp_playlist *, unsigned char, void *) = &p->playlist_update_in_progress; (void)tmp; }
  { void(* *tmp)(sp_playlist *, void *) = &p->playlist_metadata_updated; (void)tmp; }
  { void(* *tmp)(sp_playlist *, int, sp_user *, int, void *) = &p->track_created_changed; (void)tmp; }
  { void(* *tmp)(sp_playlist *, int, unsigned char, void *) = &p->track_seen_changed; (void)tmp; }
  { void(* *tmp)(sp_playlist *, char const *, void *) = &p->description_changed; (void)tmp; }
  { void(* *tmp)(sp_playlist *, unsigned char const *, void *) = &p->image_changed; (void)tmp; }
  { void(* *tmp)(sp_playlist *, int, char const *, void *) = &p->track_message_changed; (void)tmp; }
  { void(* *tmp)(sp_playlist *, void *) = &p->subscribers_changed; (void)tmp; }
}
struct _cffi_align__sp_playlist_callbacks { char x; sp_playlist_callbacks y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__sp_playlistcontainer_callbacks(sp_playlistcontainer_callbacks *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void(* *tmp)(sp_playlistcontainer *, sp_playlist *, int, void *) = &p->playlist_added; (void)tmp; }
  { void(* *tmp)(sp_playlistcontainer *, sp_playlist *, int, void *) = &p->playlist_removed; (void)tmp; }
  { void(* *tmp)(sp_playlistcontainer *, sp_playlist *, int, int, void *) = &p->playlist_moved; (void)tmp; }
  { void(* *tmp)(sp_playlistcontainer *, void *) = &p->container_loaded; (void)tmp; }
}
struct _cffi_align__sp_playlistcontainer_callbacks { char x; sp_playlistcontainer_callbacks y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__sp_session_callbacks(sp_session_callbacks *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void(* *tmp)(sp_session *, sp_error) = &p->logged_in; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->logged_out; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->metadata_updated; (void)tmp; }
  { void(* *tmp)(sp_session *, sp_error) = &p->connection_error; (void)tmp; }
  { void(* *tmp)(sp_session *, char const *) = &p->message_to_user; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->notify_main_thread; (void)tmp; }
  { int(* *tmp)(sp_session *, sp_audioformat const *, void const *, int) = &p->music_delivery; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->play_token_lost; (void)tmp; }
  { void(* *tmp)(sp_session *, char const *) = &p->log_message; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->end_of_track; (void)tmp; }
  { void(* *tmp)(sp_session *, sp_error) = &p->streaming_error; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->userinfo_updated; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->start_playback; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->stop_playback; (void)tmp; }
  { void(* *tmp)(sp_session *, sp_audio_buffer_stats *) = &p->get_audio_buffer_stats; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->offline_status_updated; (void)tmp; }
  { void(* *tmp)(sp_session *, sp_error) = &p->offline_error; (void)tmp; }
  { void(* *tmp)(sp_session *, char const *) = &p->credentials_blob_updated; (void)tmp; }
  { void(* *tmp)(sp_session *) = &p->connectionstate_updated; (void)tmp; }
  { void(* *tmp)(sp_session *, sp_error) = &p->scrobble_error; (void)tmp; }
  { void(* *tmp)(sp_session *, unsigned char) = &p->private_session_mode_changed; (void)tmp; }
}
struct _cffi_align__sp_session_callbacks { char x; sp_session_callbacks y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__sp_session_config(sp_session_config *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->api_version) | 0);  /* check that 'sp_session_config.api_version' is an integer */
  { char const * *tmp = &p->cache_location; (void)tmp; }
  { char const * *tmp = &p->settings_location; (void)tmp; }
  { void const * *tmp = &p->application_key; (void)tmp; }
  (void)((p->application_key_size) | 0);  /* check that 'sp_session_config.application_key_size' is an integer */
  { char const * *tmp = &p->user_agent; (void)tmp; }
  { sp_session_callbacks const * *tmp = &p->callbacks; (void)tmp; }
  { void * *tmp = &p->userdata; (void)tmp; }
  (void)((p->compress_playlists) | 0);  /* check that 'sp_session_config.compress_playlists' is an integer */
  (void)((p->dont_save_metadata_for_playlists) | 0);  /* check that 'sp_session_config.dont_save_metadata_for_playlists' is an integer */
  (void)((p->initially_unload_playlists) | 0);  /* check that 'sp_session_config.initially_unload_playlists' is an integer */
  { char const * *tmp = &p->device_id; (void)tmp; }
  { char const * *tmp = &p->proxy; (void)tmp; }
  { char const * *tmp = &p->proxy_username; (void)tmp; }
  { char const * *tmp = &p->proxy_password; (void)tmp; }
  { char const * *tmp = &p->tracefile; (void)tmp; }
}
struct _cffi_align__sp_session_config { char x; sp_session_config y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__sp_subscribers(sp_subscribers *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->count) | 0);  /* check that 'sp_subscribers.count' is an integer */
  { char *(*tmp)[1] = &p->subscribers; (void)tmp; }
}
struct _cffi_align__sp_subscribers { char x; sp_subscribers y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "SPOTIFY_API_VERSION", (void *)_cffi_const_SPOTIFY_API_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SP_ALBUMTYPE_ALBUM", (void *)_cffi_const_SP_ALBUMTYPE_ALBUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ALBUMTYPE_COMPILATION", (void *)_cffi_const_SP_ALBUMTYPE_COMPILATION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ALBUMTYPE_SINGLE", (void *)_cffi_const_SP_ALBUMTYPE_SINGLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ALBUMTYPE_UNKNOWN", (void *)_cffi_const_SP_ALBUMTYPE_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ARTISTBROWSE_FULL", (void *)_cffi_const_SP_ARTISTBROWSE_FULL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ARTISTBROWSE_NO_ALBUMS", (void *)_cffi_const_SP_ARTISTBROWSE_NO_ALBUMS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ARTISTBROWSE_NO_TRACKS", (void *)_cffi_const_SP_ARTISTBROWSE_NO_TRACKS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_BITRATE_160k", (void *)_cffi_const_SP_BITRATE_160k, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_BITRATE_320k", (void *)_cffi_const_SP_BITRATE_320k, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_BITRATE_96k", (void *)_cffi_const_SP_BITRATE_96k, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_RULE_ALLOW_SYNC_OVER_MOBILE", (void *)_cffi_const_SP_CONNECTION_RULE_ALLOW_SYNC_OVER_MOBILE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI", (void *)_cffi_const_SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_RULE_NETWORK", (void *)_cffi_const_SP_CONNECTION_RULE_NETWORK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_RULE_NETWORK_IF_ROAMING", (void *)_cffi_const_SP_CONNECTION_RULE_NETWORK_IF_ROAMING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_STATE_DISCONNECTED", (void *)_cffi_const_SP_CONNECTION_STATE_DISCONNECTED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_STATE_LOGGED_IN", (void *)_cffi_const_SP_CONNECTION_STATE_LOGGED_IN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_STATE_LOGGED_OUT", (void *)_cffi_const_SP_CONNECTION_STATE_LOGGED_OUT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_STATE_OFFLINE", (void *)_cffi_const_SP_CONNECTION_STATE_OFFLINE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_STATE_UNDEFINED", (void *)_cffi_const_SP_CONNECTION_STATE_UNDEFINED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_TYPE_MOBILE", (void *)_cffi_const_SP_CONNECTION_TYPE_MOBILE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_TYPE_MOBILE_ROAMING", (void *)_cffi_const_SP_CONNECTION_TYPE_MOBILE_ROAMING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_TYPE_NONE", (void *)_cffi_const_SP_CONNECTION_TYPE_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_TYPE_UNKNOWN", (void *)_cffi_const_SP_CONNECTION_TYPE_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_TYPE_WIFI", (void *)_cffi_const_SP_CONNECTION_TYPE_WIFI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_CONNECTION_TYPE_WIRED", (void *)_cffi_const_SP_CONNECTION_TYPE_WIRED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_API_INITIALIZATION_FAILED", (void *)_cffi_const_SP_ERROR_API_INITIALIZATION_FAILED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_APPLICATION_BANNED", (void *)_cffi_const_SP_ERROR_APPLICATION_BANNED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_BAD_API_VERSION", (void *)_cffi_const_SP_ERROR_BAD_API_VERSION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_BAD_APPLICATION_KEY", (void *)_cffi_const_SP_ERROR_BAD_APPLICATION_KEY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_BAD_USERNAME_OR_PASSWORD", (void *)_cffi_const_SP_ERROR_BAD_USERNAME_OR_PASSWORD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_BAD_USER_AGENT", (void *)_cffi_const_SP_ERROR_BAD_USER_AGENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_CANT_OPEN_TRACE_FILE", (void *)_cffi_const_SP_ERROR_CANT_OPEN_TRACE_FILE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_CLIENT_TOO_OLD", (void *)_cffi_const_SP_ERROR_CLIENT_TOO_OLD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_INBOX_IS_FULL", (void *)_cffi_const_SP_ERROR_INBOX_IS_FULL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_INDEX_OUT_OF_RANGE", (void *)_cffi_const_SP_ERROR_INDEX_OUT_OF_RANGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_INVALID_ARGUMENT", (void *)_cffi_const_SP_ERROR_INVALID_ARGUMENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_INVALID_DEVICE_ID", (void *)_cffi_const_SP_ERROR_INVALID_DEVICE_ID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_INVALID_INDATA", (void *)_cffi_const_SP_ERROR_INVALID_INDATA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_IS_LOADING", (void *)_cffi_const_SP_ERROR_IS_LOADING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_LASTFM_AUTH_ERROR", (void *)_cffi_const_SP_ERROR_LASTFM_AUTH_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_MISSING_CALLBACK", (void *)_cffi_const_SP_ERROR_MISSING_CALLBACK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_NETWORK_DISABLED", (void *)_cffi_const_SP_ERROR_NETWORK_DISABLED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_NO_CACHE", (void *)_cffi_const_SP_ERROR_NO_CACHE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_NO_CREDENTIALS", (void *)_cffi_const_SP_ERROR_NO_CREDENTIALS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_NO_STREAM_AVAILABLE", (void *)_cffi_const_SP_ERROR_NO_STREAM_AVAILABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_NO_SUCH_USER", (void *)_cffi_const_SP_ERROR_NO_SUCH_USER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OFFLINE_DISK_CACHE", (void *)_cffi_const_SP_ERROR_OFFLINE_DISK_CACHE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OFFLINE_EXPIRED", (void *)_cffi_const_SP_ERROR_OFFLINE_EXPIRED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OFFLINE_LICENSE_ERROR", (void *)_cffi_const_SP_ERROR_OFFLINE_LICENSE_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OFFLINE_LICENSE_LOST", (void *)_cffi_const_SP_ERROR_OFFLINE_LICENSE_LOST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OFFLINE_NOT_ALLOWED", (void *)_cffi_const_SP_ERROR_OFFLINE_NOT_ALLOWED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OFFLINE_TOO_MANY_TRACKS", (void *)_cffi_const_SP_ERROR_OFFLINE_TOO_MANY_TRACKS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OK", (void *)_cffi_const_SP_ERROR_OK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OTHER_PERMANENT", (void *)_cffi_const_SP_ERROR_OTHER_PERMANENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_OTHER_TRANSIENT", (void *)_cffi_const_SP_ERROR_OTHER_TRANSIENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_PERMISSION_DENIED", (void *)_cffi_const_SP_ERROR_PERMISSION_DENIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_SYSTEM_FAILURE", (void *)_cffi_const_SP_ERROR_SYSTEM_FAILURE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_TRACK_NOT_PLAYABLE", (void *)_cffi_const_SP_ERROR_TRACK_NOT_PLAYABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_UNABLE_TO_CONTACT_SERVER", (void *)_cffi_const_SP_ERROR_UNABLE_TO_CONTACT_SERVER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_USER_BANNED", (void *)_cffi_const_SP_ERROR_USER_BANNED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_ERROR_USER_NEEDS_PREMIUM", (void *)_cffi_const_SP_ERROR_USER_NEEDS_PREMIUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_IMAGE_FORMAT_JPEG", (void *)_cffi_const_SP_IMAGE_FORMAT_JPEG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_IMAGE_FORMAT_UNKNOWN", (void *)_cffi_const_SP_IMAGE_FORMAT_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_IMAGE_SIZE_LARGE", (void *)_cffi_const_SP_IMAGE_SIZE_LARGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_IMAGE_SIZE_NORMAL", (void *)_cffi_const_SP_IMAGE_SIZE_NORMAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_IMAGE_SIZE_SMALL", (void *)_cffi_const_SP_IMAGE_SIZE_SMALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_ALBUM", (void *)_cffi_const_SP_LINKTYPE_ALBUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_ARTIST", (void *)_cffi_const_SP_LINKTYPE_ARTIST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_IMAGE", (void *)_cffi_const_SP_LINKTYPE_IMAGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_INVALID", (void *)_cffi_const_SP_LINKTYPE_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_LOCALTRACK", (void *)_cffi_const_SP_LINKTYPE_LOCALTRACK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_PLAYLIST", (void *)_cffi_const_SP_LINKTYPE_PLAYLIST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_PROFILE", (void *)_cffi_const_SP_LINKTYPE_PROFILE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_SEARCH", (void *)_cffi_const_SP_LINKTYPE_SEARCH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_STARRED", (void *)_cffi_const_SP_LINKTYPE_STARRED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_LINKTYPE_TRACK", (void *)_cffi_const_SP_LINKTYPE_TRACK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_PLAYLIST_OFFLINE_STATUS_DOWNLOADING", (void *)_cffi_const_SP_PLAYLIST_OFFLINE_STATUS_DOWNLOADING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_PLAYLIST_OFFLINE_STATUS_NO", (void *)_cffi_const_SP_PLAYLIST_OFFLINE_STATUS_NO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_PLAYLIST_OFFLINE_STATUS_WAITING", (void *)_cffi_const_SP_PLAYLIST_OFFLINE_STATUS_WAITING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_PLAYLIST_OFFLINE_STATUS_YES", (void *)_cffi_const_SP_PLAYLIST_OFFLINE_STATUS_YES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_PLAYLIST_TYPE_END_FOLDER", (void *)_cffi_const_SP_PLAYLIST_TYPE_END_FOLDER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_PLAYLIST_TYPE_PLACEHOLDER", (void *)_cffi_const_SP_PLAYLIST_TYPE_PLACEHOLDER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_PLAYLIST_TYPE_PLAYLIST", (void *)_cffi_const_SP_PLAYLIST_TYPE_PLAYLIST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_PLAYLIST_TYPE_START_FOLDER", (void *)_cffi_const_SP_PLAYLIST_TYPE_START_FOLDER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_RELATION_TYPE_BIDIRECTIONAL", (void *)_cffi_const_SP_RELATION_TYPE_BIDIRECTIONAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_RELATION_TYPE_NONE", (void *)_cffi_const_SP_RELATION_TYPE_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_RELATION_TYPE_UNIDIRECTIONAL", (void *)_cffi_const_SP_RELATION_TYPE_UNIDIRECTIONAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_RELATION_TYPE_UNKNOWN", (void *)_cffi_const_SP_RELATION_TYPE_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SAMPLETYPE_INT16_NATIVE_ENDIAN", (void *)_cffi_const_SP_SAMPLETYPE_INT16_NATIVE_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SCROBBLING_STATE_GLOBAL_DISABLED", (void *)_cffi_const_SP_SCROBBLING_STATE_GLOBAL_DISABLED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SCROBBLING_STATE_GLOBAL_ENABLED", (void *)_cffi_const_SP_SCROBBLING_STATE_GLOBAL_ENABLED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SCROBBLING_STATE_LOCAL_DISABLED", (void *)_cffi_const_SP_SCROBBLING_STATE_LOCAL_DISABLED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SCROBBLING_STATE_LOCAL_ENABLED", (void *)_cffi_const_SP_SCROBBLING_STATE_LOCAL_ENABLED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SCROBBLING_STATE_USE_GLOBAL_SETTING", (void *)_cffi_const_SP_SCROBBLING_STATE_USE_GLOBAL_SETTING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SEARCH_STANDARD", (void *)_cffi_const_SP_SEARCH_STANDARD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SEARCH_SUGGEST", (void *)_cffi_const_SP_SEARCH_SUGGEST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SOCIAL_PROVIDER_FACEBOOK", (void *)_cffi_const_SP_SOCIAL_PROVIDER_FACEBOOK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SOCIAL_PROVIDER_LASTFM", (void *)_cffi_const_SP_SOCIAL_PROVIDER_LASTFM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_SOCIAL_PROVIDER_SPOTIFY", (void *)_cffi_const_SP_SOCIAL_PROVIDER_SPOTIFY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TOPLIST_REGION_EVERYWHERE", (void *)_cffi_const_SP_TOPLIST_REGION_EVERYWHERE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TOPLIST_REGION_USER", (void *)_cffi_const_SP_TOPLIST_REGION_USER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TOPLIST_TYPE_ALBUMS", (void *)_cffi_const_SP_TOPLIST_TYPE_ALBUMS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TOPLIST_TYPE_ARTISTS", (void *)_cffi_const_SP_TOPLIST_TYPE_ARTISTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TOPLIST_TYPE_TRACKS", (void *)_cffi_const_SP_TOPLIST_TYPE_TRACKS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_AVAILABILITY_AVAILABLE", (void *)_cffi_const_SP_TRACK_AVAILABILITY_AVAILABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_AVAILABILITY_BANNED_BY_ARTIST", (void *)_cffi_const_SP_TRACK_AVAILABILITY_BANNED_BY_ARTIST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_AVAILABILITY_NOT_STREAMABLE", (void *)_cffi_const_SP_TRACK_AVAILABILITY_NOT_STREAMABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_AVAILABILITY_UNAVAILABLE", (void *)_cffi_const_SP_TRACK_AVAILABILITY_UNAVAILABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_OFFLINE_DONE", (void *)_cffi_const_SP_TRACK_OFFLINE_DONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_OFFLINE_DONE_EXPIRED", (void *)_cffi_const_SP_TRACK_OFFLINE_DONE_EXPIRED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_OFFLINE_DONE_RESYNC", (void *)_cffi_const_SP_TRACK_OFFLINE_DONE_RESYNC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_OFFLINE_DOWNLOADING", (void *)_cffi_const_SP_TRACK_OFFLINE_DOWNLOADING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_OFFLINE_ERROR", (void *)_cffi_const_SP_TRACK_OFFLINE_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_OFFLINE_LIMIT_EXCEEDED", (void *)_cffi_const_SP_TRACK_OFFLINE_LIMIT_EXCEEDED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_OFFLINE_NO", (void *)_cffi_const_SP_TRACK_OFFLINE_NO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SP_TRACK_OFFLINE_WAITING", (void *)_cffi_const_SP_TRACK_OFFLINE_WAITING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "sp_album_add_ref", (void *)_cffi_f_sp_album_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 173), (void *)_cffi_d_sp_album_add_ref },
  { "sp_album_artist", (void *)_cffi_f_sp_album_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 135), (void *)_cffi_d_sp_album_artist },
  { "sp_album_cover", (void *)_cffi_f_sp_album_cover, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 561), (void *)_cffi_d_sp_album_cover },
  { "sp_album_is_available", (void *)_cffi_f_sp_album_is_available, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 576), (void *)_cffi_d_sp_album_is_available },
  { "sp_album_is_loaded", (void *)_cffi_f_sp_album_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 576), (void *)_cffi_d_sp_album_is_loaded },
  { "sp_album_name", (void *)_cffi_f_sp_album_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_sp_album_name },
  { "sp_album_release", (void *)_cffi_f_sp_album_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 173), (void *)_cffi_d_sp_album_release },
  { "sp_album_type", (void *)_cffi_f_sp_album_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 132), (void *)_cffi_d_sp_album_type },
  { "sp_album_year", (void *)_cffi_f_sp_album_year, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 44), (void *)_cffi_d_sp_album_year },
  { "sp_albumbrowse_add_ref", (void *)_cffi_f_sp_albumbrowse_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 176), (void *)_cffi_d_sp_albumbrowse_add_ref },
  { "sp_albumbrowse_album", (void *)_cffi_f_sp_albumbrowse_album, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 105), (void *)_cffi_d_sp_albumbrowse_album },
  { "sp_albumbrowse_artist", (void *)_cffi_f_sp_albumbrowse_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 138), (void *)_cffi_d_sp_albumbrowse_artist },
  { "sp_albumbrowse_backend_request_duration", (void *)_cffi_f_sp_albumbrowse_backend_request_duration, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_sp_albumbrowse_backend_request_duration },
  { "sp_albumbrowse_copyright", (void *)_cffi_f_sp_albumbrowse_copyright, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 6), (void *)_cffi_d_sp_albumbrowse_copyright },
  { "sp_albumbrowse_create", (void *)_cffi_f_sp_albumbrowse_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 126), (void *)_cffi_d_sp_albumbrowse_create },
  { "sp_albumbrowse_error", (void *)_cffi_f_sp_albumbrowse_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 176), (void *)_cffi_d_sp_albumbrowse_error },
  { "sp_albumbrowse_is_loaded", (void *)_cffi_f_sp_albumbrowse_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 579), (void *)_cffi_d_sp_albumbrowse_is_loaded },
  { "sp_albumbrowse_num_copyrights", (void *)_cffi_f_sp_albumbrowse_num_copyrights, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_sp_albumbrowse_num_copyrights },
  { "sp_albumbrowse_num_tracks", (void *)_cffi_f_sp_albumbrowse_num_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_sp_albumbrowse_num_tracks },
  { "sp_albumbrowse_release", (void *)_cffi_f_sp_albumbrowse_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 176), (void *)_cffi_d_sp_albumbrowse_release },
  { "sp_albumbrowse_review", (void *)_cffi_f_sp_albumbrowse_review, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_sp_albumbrowse_review },
  { "sp_albumbrowse_track", (void *)_cffi_f_sp_albumbrowse_track, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 503), (void *)_cffi_d_sp_albumbrowse_track },
  { "sp_artist_add_ref", (void *)_cffi_f_sp_artist_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 179), (void *)_cffi_d_sp_artist_add_ref },
  { "sp_artist_is_loaded", (void *)_cffi_f_sp_artist_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 582), (void *)_cffi_d_sp_artist_is_loaded },
  { "sp_artist_name", (void *)_cffi_f_sp_artist_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 10), (void *)_cffi_d_sp_artist_name },
  { "sp_artist_portrait", (void *)_cffi_f_sp_artist_portrait, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 565), (void *)_cffi_d_sp_artist_portrait },
  { "sp_artist_release", (void *)_cffi_f_sp_artist_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 179), (void *)_cffi_d_sp_artist_release },
  { "sp_artistbrowse_add_ref", (void *)_cffi_f_sp_artistbrowse_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 182), (void *)_cffi_d_sp_artistbrowse_add_ref },
  { "sp_artistbrowse_album", (void *)_cffi_f_sp_artistbrowse_album, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 108), (void *)_cffi_d_sp_artistbrowse_album },
  { "sp_artistbrowse_artist", (void *)_cffi_f_sp_artistbrowse_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 141), (void *)_cffi_d_sp_artistbrowse_artist },
  { "sp_artistbrowse_backend_request_duration", (void *)_cffi_f_sp_artistbrowse_backend_request_duration, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 50), (void *)_cffi_d_sp_artistbrowse_backend_request_duration },
  { "sp_artistbrowse_biography", (void *)_cffi_f_sp_artistbrowse_biography, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 13), (void *)_cffi_d_sp_artistbrowse_biography },
  { "sp_artistbrowse_create", (void *)_cffi_f_sp_artistbrowse_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 163), (void *)_cffi_d_sp_artistbrowse_create },
  { "sp_artistbrowse_error", (void *)_cffi_f_sp_artistbrowse_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 182), (void *)_cffi_d_sp_artistbrowse_error },
  { "sp_artistbrowse_is_loaded", (void *)_cffi_f_sp_artistbrowse_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 585), (void *)_cffi_d_sp_artistbrowse_is_loaded },
  { "sp_artistbrowse_num_albums", (void *)_cffi_f_sp_artistbrowse_num_albums, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 50), (void *)_cffi_d_sp_artistbrowse_num_albums },
  { "sp_artistbrowse_num_portraits", (void *)_cffi_f_sp_artistbrowse_num_portraits, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 50), (void *)_cffi_d_sp_artistbrowse_num_portraits },
  { "sp_artistbrowse_num_similar_artists", (void *)_cffi_f_sp_artistbrowse_num_similar_artists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 50), (void *)_cffi_d_sp_artistbrowse_num_similar_artists },
  { "sp_artistbrowse_num_tophit_tracks", (void *)_cffi_f_sp_artistbrowse_num_tophit_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 50), (void *)_cffi_d_sp_artistbrowse_num_tophit_tracks },
  { "sp_artistbrowse_num_tracks", (void *)_cffi_f_sp_artistbrowse_num_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 50), (void *)_cffi_d_sp_artistbrowse_num_tracks },
  { "sp_artistbrowse_portrait", (void *)_cffi_f_sp_artistbrowse_portrait, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 569), (void *)_cffi_d_sp_artistbrowse_portrait },
  { "sp_artistbrowse_release", (void *)_cffi_f_sp_artistbrowse_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 182), (void *)_cffi_d_sp_artistbrowse_release },
  { "sp_artistbrowse_similar_artist", (void *)_cffi_f_sp_artistbrowse_similar_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 144), (void *)_cffi_d_sp_artistbrowse_similar_artist },
  { "sp_artistbrowse_tophit_track", (void *)_cffi_f_sp_artistbrowse_tophit_track, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 507), (void *)_cffi_d_sp_artistbrowse_tophit_track },
  { "sp_artistbrowse_track", (void *)_cffi_f_sp_artistbrowse_track, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 507), (void *)_cffi_d_sp_artistbrowse_track },
  { "sp_build_id", (void *)_cffi_f_sp_build_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 42), (void *)_cffi_d_sp_build_id },
  { "sp_error_message", (void *)_cffi_f_sp_error_message, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 16), (void *)_cffi_d_sp_error_message },
  { "sp_image_add_load_callback", (void *)_cffi_f_sp_image_add_load_callback, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 188), (void *)_cffi_d_sp_image_add_load_callback },
  { "sp_image_add_ref", (void *)_cffi_f_sp_image_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 185), (void *)_cffi_d_sp_image_add_ref },
  { "sp_image_create", (void *)_cffi_f_sp_image_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 373), (void *)_cffi_d_sp_image_create },
  { "sp_image_create_from_link", (void *)_cffi_f_sp_image_create_from_link, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 369), (void *)_cffi_d_sp_image_create_from_link },
  { "sp_image_data", (void *)_cffi_f_sp_image_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 638), (void *)_cffi_d_sp_image_data },
  { "sp_image_error", (void *)_cffi_f_sp_image_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 185), (void *)_cffi_d_sp_image_error },
  { "sp_image_format", (void *)_cffi_f_sp_image_format, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 377), (void *)_cffi_d_sp_image_format },
  { "sp_image_image_id", (void *)_cffi_f_sp_image_image_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 573), (void *)_cffi_d_sp_image_image_id },
  { "sp_image_is_loaded", (void *)_cffi_f_sp_image_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 588), (void *)_cffi_d_sp_image_is_loaded },
  { "sp_image_release", (void *)_cffi_f_sp_image_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 185), (void *)_cffi_d_sp_image_release },
  { "sp_image_remove_load_callback", (void *)_cffi_f_sp_image_remove_load_callback, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 188), (void *)_cffi_d_sp_image_remove_load_callback },
  { "sp_inbox_add_ref", (void *)_cffi_f_sp_inbox_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 193), (void *)_cffi_d_sp_inbox_add_ref },
  { "sp_inbox_error", (void *)_cffi_f_sp_inbox_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 193), (void *)_cffi_d_sp_inbox_error },
  { "sp_inbox_post_tracks", (void *)_cffi_f_sp_inbox_post_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 380), (void *)_cffi_d_sp_inbox_post_tracks },
  { "sp_inbox_release", (void *)_cffi_f_sp_inbox_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 193), (void *)_cffi_d_sp_inbox_release },
  { "sp_link_add_ref", (void *)_cffi_f_sp_link_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 196), (void *)_cffi_d_sp_link_add_ref },
  { "sp_link_as_album", (void *)_cffi_f_sp_link_as_album, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 112), (void *)_cffi_d_sp_link_as_album },
  { "sp_link_as_artist", (void *)_cffi_f_sp_link_as_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 148), (void *)_cffi_d_sp_link_as_artist },
  { "sp_link_as_string", (void *)_cffi_f_sp_link_as_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 53), (void *)_cffi_d_sp_link_as_string },
  { "sp_link_as_track", (void *)_cffi_f_sp_link_as_track, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 511), (void *)_cffi_d_sp_link_as_track },
  { "sp_link_as_track_and_offset", (void *)_cffi_f_sp_link_as_track_and_offset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 514), (void *)_cffi_d_sp_link_as_track_and_offset },
  { "sp_link_as_user", (void *)_cffi_f_sp_link_as_user, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 541), (void *)_cffi_d_sp_link_as_user },
  { "sp_link_create_from_album", (void *)_cffi_f_sp_link_create_from_album, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 392), (void *)_cffi_d_sp_link_create_from_album },
  { "sp_link_create_from_album_cover", (void *)_cffi_f_sp_link_create_from_album_cover, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 395), (void *)_cffi_d_sp_link_create_from_album_cover },
  { "sp_link_create_from_artist", (void *)_cffi_f_sp_link_create_from_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 399), (void *)_cffi_d_sp_link_create_from_artist },
  { "sp_link_create_from_artist_portrait", (void *)_cffi_f_sp_link_create_from_artist_portrait, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 402), (void *)_cffi_d_sp_link_create_from_artist_portrait },
  { "sp_link_create_from_artistbrowse_portrait", (void *)_cffi_f_sp_link_create_from_artistbrowse_portrait, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 406), (void *)_cffi_d_sp_link_create_from_artistbrowse_portrait },
  { "sp_link_create_from_image", (void *)_cffi_f_sp_link_create_from_image, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 410), (void *)_cffi_d_sp_link_create_from_image },
  { "sp_link_create_from_playlist", (void *)_cffi_f_sp_link_create_from_playlist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 413), (void *)_cffi_d_sp_link_create_from_playlist },
  { "sp_link_create_from_search", (void *)_cffi_f_sp_link_create_from_search, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 416), (void *)_cffi_d_sp_link_create_from_search },
  { "sp_link_create_from_string", (void *)_cffi_f_sp_link_create_from_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 389), (void *)_cffi_d_sp_link_create_from_string },
  { "sp_link_create_from_track", (void *)_cffi_f_sp_link_create_from_track, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 419), (void *)_cffi_d_sp_link_create_from_track },
  { "sp_link_create_from_user", (void *)_cffi_f_sp_link_create_from_user, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 423), (void *)_cffi_d_sp_link_create_from_user },
  { "sp_link_release", (void *)_cffi_f_sp_link_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 196), (void *)_cffi_d_sp_link_release },
  { "sp_link_type", (void *)_cffi_f_sp_link_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 426), (void *)_cffi_d_sp_link_type },
  { "sp_localtrack_create", (void *)_cffi_f_sp_localtrack_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 497), (void *)_cffi_d_sp_localtrack_create },
  { "sp_offline_num_playlists", (void *)_cffi_f_sp_offline_num_playlists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 81), (void *)_cffi_d_sp_offline_num_playlists },
  { "sp_offline_sync_get_status", (void *)_cffi_f_sp_offline_sync_get_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 611), (void *)_cffi_d_sp_offline_sync_get_status },
  { "sp_offline_time_left", (void *)_cffi_f_sp_offline_time_left, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 81), (void *)_cffi_d_sp_offline_time_left },
  { "sp_offline_tracks_to_sync", (void *)_cffi_f_sp_offline_tracks_to_sync, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 81), (void *)_cffi_d_sp_offline_tracks_to_sync },
  { "sp_playlist_add_callbacks", (void *)_cffi_f_sp_playlist_add_callbacks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 222), (void *)_cffi_d_sp_playlist_add_callbacks },
  { "sp_playlist_add_ref", (void *)_cffi_f_sp_playlist_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 199), (void *)_cffi_d_sp_playlist_add_ref },
  { "sp_playlist_add_tracks", (void *)_cffi_f_sp_playlist_add_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 227), (void *)_cffi_d_sp_playlist_add_tracks },
  { "sp_playlist_create", (void *)_cffi_f_sp_playlist_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 452), (void *)_cffi_d_sp_playlist_create },
  { "sp_playlist_get_description", (void *)_cffi_f_sp_playlist_get_description, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 19), (void *)_cffi_d_sp_playlist_get_description },
  { "sp_playlist_get_image", (void *)_cffi_f_sp_playlist_get_image, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 598), (void *)_cffi_d_sp_playlist_get_image },
  { "sp_playlist_get_offline_download_completed", (void *)_cffi_f_sp_playlist_get_offline_download_completed, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 95), (void *)_cffi_d_sp_playlist_get_offline_download_completed },
  { "sp_playlist_get_offline_status", (void *)_cffi_f_sp_playlist_get_offline_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 456), (void *)_cffi_d_sp_playlist_get_offline_status },
  { "sp_playlist_has_pending_changes", (void *)_cffi_f_sp_playlist_has_pending_changes, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 591), (void *)_cffi_d_sp_playlist_has_pending_changes },
  { "sp_playlist_is_collaborative", (void *)_cffi_f_sp_playlist_is_collaborative, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 591), (void *)_cffi_d_sp_playlist_is_collaborative },
  { "sp_playlist_is_in_ram", (void *)_cffi_f_sp_playlist_is_in_ram, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 615), (void *)_cffi_d_sp_playlist_is_in_ram },
  { "sp_playlist_is_loaded", (void *)_cffi_f_sp_playlist_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 591), (void *)_cffi_d_sp_playlist_is_loaded },
  { "sp_playlist_name", (void *)_cffi_f_sp_playlist_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 19), (void *)_cffi_d_sp_playlist_name },
  { "sp_playlist_num_subscribers", (void *)_cffi_f_sp_playlist_num_subscribers, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 632), (void *)_cffi_d_sp_playlist_num_subscribers },
  { "sp_playlist_num_tracks", (void *)_cffi_f_sp_playlist_num_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 58), (void *)_cffi_d_sp_playlist_num_tracks },
  { "sp_playlist_owner", (void *)_cffi_f_sp_playlist_owner, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 544), (void *)_cffi_d_sp_playlist_owner },
  { "sp_playlist_release", (void *)_cffi_f_sp_playlist_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 199), (void *)_cffi_d_sp_playlist_release },
  { "sp_playlist_remove_callbacks", (void *)_cffi_f_sp_playlist_remove_callbacks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 222), (void *)_cffi_d_sp_playlist_remove_callbacks },
  { "sp_playlist_remove_tracks", (void *)_cffi_f_sp_playlist_remove_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 206), (void *)_cffi_d_sp_playlist_remove_tracks },
  { "sp_playlist_rename", (void *)_cffi_f_sp_playlist_rename, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 202), (void *)_cffi_d_sp_playlist_rename },
  { "sp_playlist_reorder_tracks", (void *)_cffi_f_sp_playlist_reorder_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 211), (void *)_cffi_d_sp_playlist_reorder_tracks },
  { "sp_playlist_set_autolink_tracks", (void *)_cffi_f_sp_playlist_set_autolink_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 234), (void *)_cffi_d_sp_playlist_set_autolink_tracks },
  { "sp_playlist_set_collaborative", (void *)_cffi_f_sp_playlist_set_collaborative, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 234), (void *)_cffi_d_sp_playlist_set_collaborative },
  { "sp_playlist_set_in_ram", (void *)_cffi_f_sp_playlist_set_in_ram, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 313), (void *)_cffi_d_sp_playlist_set_in_ram },
  { "sp_playlist_set_offline_mode", (void *)_cffi_f_sp_playlist_set_offline_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 313), (void *)_cffi_d_sp_playlist_set_offline_mode },
  { "sp_playlist_subscribers", (void *)_cffi_f_sp_playlist_subscribers, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 486), (void *)_cffi_d_sp_playlist_subscribers },
  { "sp_playlist_subscribers_free", (void *)_cffi_f_sp_playlist_subscribers_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 357), (void *)_cffi_d_sp_playlist_subscribers_free },
  { "sp_playlist_track", (void *)_cffi_f_sp_playlist_track, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 518), (void *)_cffi_d_sp_playlist_track },
  { "sp_playlist_track_create_time", (void *)_cffi_f_sp_playlist_track_create_time, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 61), (void *)_cffi_d_sp_playlist_track_create_time },
  { "sp_playlist_track_creator", (void *)_cffi_f_sp_playlist_track_creator, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 547), (void *)_cffi_d_sp_playlist_track_creator },
  { "sp_playlist_track_message", (void *)_cffi_f_sp_playlist_track_message, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 22), (void *)_cffi_d_sp_playlist_track_message },
  { "sp_playlist_track_seen", (void *)_cffi_f_sp_playlist_track_seen, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 594), (void *)_cffi_d_sp_playlist_track_seen },
  { "sp_playlist_track_set_seen", (void *)_cffi_f_sp_playlist_track_set_seen, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 217), (void *)_cffi_d_sp_playlist_track_set_seen },
  { "sp_playlist_update_subscribers", (void *)_cffi_f_sp_playlist_update_subscribers, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 309), (void *)_cffi_d_sp_playlist_update_subscribers },
  { "sp_playlistcontainer_add_callbacks", (void *)_cffi_f_sp_playlistcontainer_add_callbacks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 262), (void *)_cffi_d_sp_playlistcontainer_add_callbacks },
  { "sp_playlistcontainer_add_folder", (void *)_cffi_f_sp_playlistcontainer_add_folder, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 251), (void *)_cffi_d_sp_playlistcontainer_add_folder },
  { "sp_playlistcontainer_add_new_playlist", (void *)_cffi_f_sp_playlistcontainer_add_new_playlist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 429), (void *)_cffi_d_sp_playlistcontainer_add_new_playlist },
  { "sp_playlistcontainer_add_playlist", (void *)_cffi_f_sp_playlistcontainer_add_playlist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 437), (void *)_cffi_d_sp_playlistcontainer_add_playlist },
  { "sp_playlistcontainer_add_ref", (void *)_cffi_f_sp_playlistcontainer_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 238), (void *)_cffi_d_sp_playlistcontainer_add_ref },
  { "sp_playlistcontainer_clear_unseen_tracks", (void *)_cffi_f_sp_playlistcontainer_clear_unseen_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 68), (void *)_cffi_d_sp_playlistcontainer_clear_unseen_tracks },
  { "sp_playlistcontainer_get_unseen_tracks", (void *)_cffi_f_sp_playlistcontainer_get_unseen_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_sp_playlistcontainer_get_unseen_tracks },
  { "sp_playlistcontainer_is_loaded", (void *)_cffi_f_sp_playlistcontainer_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 602), (void *)_cffi_d_sp_playlistcontainer_is_loaded },
  { "sp_playlistcontainer_move_playlist", (void *)_cffi_f_sp_playlistcontainer_move_playlist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 256), (void *)_cffi_d_sp_playlistcontainer_move_playlist },
  { "sp_playlistcontainer_num_playlists", (void *)_cffi_f_sp_playlistcontainer_num_playlists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 65), (void *)_cffi_d_sp_playlistcontainer_num_playlists },
  { "sp_playlistcontainer_owner", (void *)_cffi_f_sp_playlistcontainer_owner, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 551), (void *)_cffi_d_sp_playlistcontainer_owner },
  { "sp_playlistcontainer_playlist", (void *)_cffi_f_sp_playlistcontainer_playlist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 433), (void *)_cffi_d_sp_playlistcontainer_playlist },
  { "sp_playlistcontainer_playlist_folder_id", (void *)_cffi_f_sp_playlistcontainer_playlist_folder_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 557), (void *)_cffi_d_sp_playlistcontainer_playlist_folder_id },
  { "sp_playlistcontainer_playlist_folder_name", (void *)_cffi_f_sp_playlistcontainer_playlist_folder_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 245), (void *)_cffi_d_sp_playlistcontainer_playlist_folder_name },
  { "sp_playlistcontainer_playlist_type", (void *)_cffi_f_sp_playlistcontainer_playlist_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 460), (void *)_cffi_d_sp_playlistcontainer_playlist_type },
  { "sp_playlistcontainer_release", (void *)_cffi_f_sp_playlistcontainer_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 238), (void *)_cffi_d_sp_playlistcontainer_release },
  { "sp_playlistcontainer_remove_callbacks", (void *)_cffi_f_sp_playlistcontainer_remove_callbacks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 262), (void *)_cffi_d_sp_playlistcontainer_remove_callbacks },
  { "sp_playlistcontainer_remove_playlist", (void *)_cffi_f_sp_playlistcontainer_remove_playlist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 241), (void *)_cffi_d_sp_playlistcontainer_remove_playlist },
  { "sp_search_add_ref", (void *)_cffi_f_sp_search_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 267), (void *)_cffi_d_sp_search_add_ref },
  { "sp_search_album", (void *)_cffi_f_sp_search_album, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_sp_search_album },
  { "sp_search_artist", (void *)_cffi_f_sp_search_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 151), (void *)_cffi_d_sp_search_artist },
  { "sp_search_create", (void *)_cffi_f_sp_search_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 471), (void *)_cffi_d_sp_search_create },
  { "sp_search_did_you_mean", (void *)_cffi_f_sp_search_did_you_mean, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 26), (void *)_cffi_d_sp_search_did_you_mean },
  { "sp_search_error", (void *)_cffi_f_sp_search_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 267), (void *)_cffi_d_sp_search_error },
  { "sp_search_is_loaded", (void *)_cffi_f_sp_search_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 605), (void *)_cffi_d_sp_search_is_loaded },
  { "sp_search_num_albums", (void *)_cffi_f_sp_search_num_albums, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_sp_search_num_albums },
  { "sp_search_num_artists", (void *)_cffi_f_sp_search_num_artists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_sp_search_num_artists },
  { "sp_search_num_playlists", (void *)_cffi_f_sp_search_num_playlists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_sp_search_num_playlists },
  { "sp_search_num_tracks", (void *)_cffi_f_sp_search_num_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_sp_search_num_tracks },
  { "sp_search_playlist", (void *)_cffi_f_sp_search_playlist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 441), (void *)_cffi_d_sp_search_playlist },
  { "sp_search_playlist_image_uri", (void *)_cffi_f_sp_search_playlist_image_uri, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 29), (void *)_cffi_d_sp_search_playlist_image_uri },
  { "sp_search_playlist_name", (void *)_cffi_f_sp_search_playlist_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 29), (void *)_cffi_d_sp_search_playlist_name },
  { "sp_search_playlist_uri", (void *)_cffi_f_sp_search_playlist_uri, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 29), (void *)_cffi_d_sp_search_playlist_uri },
  { "sp_search_query", (void *)_cffi_f_sp_search_query, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 26), (void *)_cffi_d_sp_search_query },
  { "sp_search_release", (void *)_cffi_f_sp_search_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 267), (void *)_cffi_d_sp_search_release },
  { "sp_search_total_albums", (void *)_cffi_f_sp_search_total_albums, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_sp_search_total_albums },
  { "sp_search_total_artists", (void *)_cffi_f_sp_search_total_artists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_sp_search_total_artists },
  { "sp_search_total_playlists", (void *)_cffi_f_sp_search_total_playlists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_sp_search_total_playlists },
  { "sp_search_total_tracks", (void *)_cffi_f_sp_search_total_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_sp_search_total_tracks },
  { "sp_search_track", (void *)_cffi_f_sp_search_track, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 522), (void *)_cffi_d_sp_search_track },
  { "sp_session_connectionstate", (void *)_cffi_f_sp_session_connectionstate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 170), (void *)_cffi_d_sp_session_connectionstate },
  { "sp_session_create", (void *)_cffi_f_sp_session_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 353), (void *)_cffi_d_sp_session_create },
  { "sp_session_flush_caches", (void *)_cffi_f_sp_session_flush_caches, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 270), (void *)_cffi_d_sp_session_flush_caches },
  { "sp_session_forget_me", (void *)_cffi_f_sp_session_forget_me, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 270), (void *)_cffi_d_sp_session_forget_me },
  { "sp_session_get_volume_normalization", (void *)_cffi_f_sp_session_get_volume_normalization, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 608), (void *)_cffi_d_sp_session_get_volume_normalization },
  { "sp_session_inbox_create", (void *)_cffi_f_sp_session_inbox_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 445), (void *)_cffi_d_sp_session_inbox_create },
  { "sp_session_is_private_session", (void *)_cffi_f_sp_session_is_private_session, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 608), (void *)_cffi_d_sp_session_is_private_session },
  { "sp_session_is_scrobbling", (void *)_cffi_f_sp_session_is_scrobbling, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 324), (void *)_cffi_d_sp_session_is_scrobbling },
  { "sp_session_is_scrobbling_possible", (void *)_cffi_f_sp_session_is_scrobbling_possible, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 334), (void *)_cffi_d_sp_session_is_scrobbling_possible },
  { "sp_session_login", (void *)_cffi_f_sp_session_login, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 273), (void *)_cffi_d_sp_session_login },
  { "sp_session_logout", (void *)_cffi_f_sp_session_logout, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 270), (void *)_cffi_d_sp_session_logout },
  { "sp_session_player_load", (void *)_cffi_f_sp_session_player_load, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 345), (void *)_cffi_d_sp_session_player_load },
  { "sp_session_player_play", (void *)_cffi_f_sp_session_player_play, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 349), (void *)_cffi_d_sp_session_player_play },
  { "sp_session_player_prefetch", (void *)_cffi_f_sp_session_player_prefetch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 345), (void *)_cffi_d_sp_session_player_prefetch },
  { "sp_session_player_seek", (void *)_cffi_f_sp_session_player_seek, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 284), (void *)_cffi_d_sp_session_player_seek },
  { "sp_session_player_unload", (void *)_cffi_f_sp_session_player_unload, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 270), (void *)_cffi_d_sp_session_player_unload },
  { "sp_session_playlistcontainer", (void *)_cffi_f_sp_session_playlistcontainer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 464), (void *)_cffi_d_sp_session_playlistcontainer },
  { "sp_session_preferred_bitrate", (void *)_cffi_f_sp_session_preferred_bitrate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 292), (void *)_cffi_d_sp_session_preferred_bitrate },
  { "sp_session_preferred_offline_bitrate", (void *)_cffi_f_sp_session_preferred_offline_bitrate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 296), (void *)_cffi_d_sp_session_preferred_offline_bitrate },
  { "sp_session_process_events", (void *)_cffi_f_sp_session_process_events, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 280), (void *)_cffi_d_sp_session_process_events },
  { "sp_session_publishedcontainer_for_user_create", (void *)_cffi_f_sp_session_publishedcontainer_for_user_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 467), (void *)_cffi_d_sp_session_publishedcontainer_for_user_create },
  { "sp_session_release", (void *)_cffi_f_sp_session_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 270), (void *)_cffi_d_sp_session_release },
  { "sp_session_relogin", (void *)_cffi_f_sp_session_relogin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 270), (void *)_cffi_d_sp_session_relogin },
  { "sp_session_remembered_user", (void *)_cffi_f_sp_session_remembered_user, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 84), (void *)_cffi_d_sp_session_remembered_user },
  { "sp_session_set_cache_size", (void *)_cffi_f_sp_session_set_cache_size, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 288), (void *)_cffi_d_sp_session_set_cache_size },
  { "sp_session_set_connection_rules", (void *)_cffi_f_sp_session_set_connection_rules, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 301), (void *)_cffi_d_sp_session_set_connection_rules },
  { "sp_session_set_connection_type", (void *)_cffi_f_sp_session_set_connection_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 305), (void *)_cffi_d_sp_session_set_connection_type },
  { "sp_session_set_private_session", (void *)_cffi_f_sp_session_set_private_session, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 349), (void *)_cffi_d_sp_session_set_private_session },
  { "sp_session_set_scrobbling", (void *)_cffi_f_sp_session_set_scrobbling, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 329), (void *)_cffi_d_sp_session_set_scrobbling },
  { "sp_session_set_social_credentials", (void *)_cffi_f_sp_session_set_social_credentials, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 318), (void *)_cffi_d_sp_session_set_social_credentials },
  { "sp_session_set_volume_normalization", (void *)_cffi_f_sp_session_set_volume_normalization, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 349), (void *)_cffi_d_sp_session_set_volume_normalization },
  { "sp_session_starred_create", (void *)_cffi_f_sp_session_starred_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 445), (void *)_cffi_d_sp_session_starred_create },
  { "sp_session_starred_for_user_create", (void *)_cffi_f_sp_session_starred_for_user_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 448), (void *)_cffi_d_sp_session_starred_for_user_create },
  { "sp_session_user", (void *)_cffi_f_sp_session_user, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 554), (void *)_cffi_d_sp_session_user },
  { "sp_session_user_country", (void *)_cffi_f_sp_session_user_country, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 81), (void *)_cffi_d_sp_session_user_country },
  { "sp_session_user_name", (void *)_cffi_f_sp_session_user_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 33), (void *)_cffi_d_sp_session_user_name },
  { "sp_session_userdata", (void *)_cffi_f_sp_session_userdata, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 635), (void *)_cffi_d_sp_session_userdata },
  { "sp_toplistbrowse_add_ref", (void *)_cffi_f_sp_toplistbrowse_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 360), (void *)_cffi_d_sp_toplistbrowse_add_ref },
  { "sp_toplistbrowse_album", (void *)_cffi_f_sp_toplistbrowse_album, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 119), (void *)_cffi_d_sp_toplistbrowse_album },
  { "sp_toplistbrowse_artist", (void *)_cffi_f_sp_toplistbrowse_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 155), (void *)_cffi_d_sp_toplistbrowse_artist },
  { "sp_toplistbrowse_backend_request_duration", (void *)_cffi_f_sp_toplistbrowse_backend_request_duration, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 99), (void *)_cffi_d_sp_toplistbrowse_backend_request_duration },
  { "sp_toplistbrowse_create", (void *)_cffi_f_sp_toplistbrowse_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 489), (void *)_cffi_d_sp_toplistbrowse_create },
  { "sp_toplistbrowse_error", (void *)_cffi_f_sp_toplistbrowse_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 360), (void *)_cffi_d_sp_toplistbrowse_error },
  { "sp_toplistbrowse_is_loaded", (void *)_cffi_f_sp_toplistbrowse_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 623), (void *)_cffi_d_sp_toplistbrowse_is_loaded },
  { "sp_toplistbrowse_num_albums", (void *)_cffi_f_sp_toplistbrowse_num_albums, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 99), (void *)_cffi_d_sp_toplistbrowse_num_albums },
  { "sp_toplistbrowse_num_artists", (void *)_cffi_f_sp_toplistbrowse_num_artists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 99), (void *)_cffi_d_sp_toplistbrowse_num_artists },
  { "sp_toplistbrowse_num_tracks", (void *)_cffi_f_sp_toplistbrowse_num_tracks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 99), (void *)_cffi_d_sp_toplistbrowse_num_tracks },
  { "sp_toplistbrowse_release", (void *)_cffi_f_sp_toplistbrowse_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 360), (void *)_cffi_d_sp_toplistbrowse_release },
  { "sp_toplistbrowse_track", (void *)_cffi_f_sp_toplistbrowse_track, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 530), (void *)_cffi_d_sp_toplistbrowse_track },
  { "sp_track_add_ref", (void *)_cffi_f_sp_track_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 363), (void *)_cffi_d_sp_track_add_ref },
  { "sp_track_album", (void *)_cffi_f_sp_track_album, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 123), (void *)_cffi_d_sp_track_album },
  { "sp_track_artist", (void *)_cffi_f_sp_track_artist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 159), (void *)_cffi_d_sp_track_artist },
  { "sp_track_disc", (void *)_cffi_f_sp_track_disc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 102), (void *)_cffi_d_sp_track_disc },
  { "sp_track_duration", (void *)_cffi_f_sp_track_duration, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 102), (void *)_cffi_d_sp_track_duration },
  { "sp_track_error", (void *)_cffi_f_sp_track_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 363), (void *)_cffi_d_sp_track_error },
  { "sp_track_get_availability", (void *)_cffi_f_sp_track_get_availability, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 534), (void *)_cffi_d_sp_track_get_availability },
  { "sp_track_get_playable", (void *)_cffi_f_sp_track_get_playable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 526), (void *)_cffi_d_sp_track_get_playable },
  { "sp_track_index", (void *)_cffi_f_sp_track_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 102), (void *)_cffi_d_sp_track_index },
  { "sp_track_is_autolinked", (void *)_cffi_f_sp_track_is_autolinked, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 619), (void *)_cffi_d_sp_track_is_autolinked },
  { "sp_track_is_loaded", (void *)_cffi_f_sp_track_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 626), (void *)_cffi_d_sp_track_is_loaded },
  { "sp_track_is_local", (void *)_cffi_f_sp_track_is_local, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 619), (void *)_cffi_d_sp_track_is_local },
  { "sp_track_is_placeholder", (void *)_cffi_f_sp_track_is_placeholder, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 626), (void *)_cffi_d_sp_track_is_placeholder },
  { "sp_track_is_starred", (void *)_cffi_f_sp_track_is_starred, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 619), (void *)_cffi_d_sp_track_is_starred },
  { "sp_track_name", (void *)_cffi_f_sp_track_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 36), (void *)_cffi_d_sp_track_name },
  { "sp_track_num_artists", (void *)_cffi_f_sp_track_num_artists, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 102), (void *)_cffi_d_sp_track_num_artists },
  { "sp_track_offline_get_status", (void *)_cffi_f_sp_track_offline_get_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 538), (void *)_cffi_d_sp_track_offline_get_status },
  { "sp_track_popularity", (void *)_cffi_f_sp_track_popularity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 102), (void *)_cffi_d_sp_track_popularity },
  { "sp_track_release", (void *)_cffi_f_sp_track_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 363), (void *)_cffi_d_sp_track_release },
  { "sp_track_set_starred", (void *)_cffi_f_sp_track_set_starred, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 339), (void *)_cffi_d_sp_track_set_starred },
  { "sp_user_add_ref", (void *)_cffi_f_sp_user_add_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 366), (void *)_cffi_d_sp_user_add_ref },
  { "sp_user_canonical_name", (void *)_cffi_f_sp_user_canonical_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 39), (void *)_cffi_d_sp_user_canonical_name },
  { "sp_user_display_name", (void *)_cffi_f_sp_user_display_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 39), (void *)_cffi_d_sp_user_display_name },
  { "sp_user_is_loaded", (void *)_cffi_f_sp_user_is_loaded, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 629), (void *)_cffi_d_sp_user_is_loaded },
  { "sp_user_release", (void *)_cffi_f_sp_user_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 366), (void *)_cffi_d_sp_user_release },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "samples", offsetof(sp_audio_buffer_stats, samples),
               sizeof(((sp_audio_buffer_stats *)0)->samples),
               _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "stutter", offsetof(sp_audio_buffer_stats, stutter),
               sizeof(((sp_audio_buffer_stats *)0)->stutter),
               _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "sample_type", offsetof(sp_audioformat, sample_type),
                   sizeof(((sp_audioformat *)0)->sample_type),
                   _CFFI_OP(_CFFI_OP_NOOP, 785) },
  { "sample_rate", offsetof(sp_audioformat, sample_rate),
                   sizeof(((sp_audioformat *)0)->sample_rate),
                   _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "channels", offsetof(sp_audioformat, channels),
                sizeof(((sp_audioformat *)0)->channels),
                _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "queued_tracks", offsetof(sp_offline_sync_status, queued_tracks),
                     sizeof(((sp_offline_sync_status *)0)->queued_tracks),
                     _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "queued_bytes", offsetof(sp_offline_sync_status, queued_bytes),
                    sizeof(((sp_offline_sync_status *)0)->queued_bytes),
                    _CFFI_OP(_CFFI_OP_NOOP, 797) },
  { "done_tracks", offsetof(sp_offline_sync_status, done_tracks),
                   sizeof(((sp_offline_sync_status *)0)->done_tracks),
                   _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "done_bytes", offsetof(sp_offline_sync_status, done_bytes),
                  sizeof(((sp_offline_sync_status *)0)->done_bytes),
                  _CFFI_OP(_CFFI_OP_NOOP, 797) },
  { "copied_tracks", offsetof(sp_offline_sync_status, copied_tracks),
                     sizeof(((sp_offline_sync_status *)0)->copied_tracks),
                     _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "copied_bytes", offsetof(sp_offline_sync_status, copied_bytes),
                    sizeof(((sp_offline_sync_status *)0)->copied_bytes),
                    _CFFI_OP(_CFFI_OP_NOOP, 797) },
  { "willnotcopy_tracks", offsetof(sp_offline_sync_status, willnotcopy_tracks),
                          sizeof(((sp_offline_sync_status *)0)->willnotcopy_tracks),
                          _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "error_tracks", offsetof(sp_offline_sync_status, error_tracks),
                    sizeof(((sp_offline_sync_status *)0)->error_tracks),
                    _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "syncing", offsetof(sp_offline_sync_status, syncing),
               sizeof(((sp_offline_sync_status *)0)->syncing),
               _CFFI_OP(_CFFI_OP_NOOP, 220) },
  { "tracks_added", offsetof(sp_playlist_callbacks, tracks_added),
                    sizeof(((sp_playlist_callbacks *)0)->tracks_added),
                    _CFFI_OP(_CFFI_OP_NOOP, 805) },
  { "tracks_removed", offsetof(sp_playlist_callbacks, tracks_removed),
                      sizeof(((sp_playlist_callbacks *)0)->tracks_removed),
                      _CFFI_OP(_CFFI_OP_NOOP, 801) },
  { "tracks_moved", offsetof(sp_playlist_callbacks, tracks_moved),
                    sizeof(((sp_playlist_callbacks *)0)->tracks_moved),
                    _CFFI_OP(_CFFI_OP_NOOP, 800) },
  { "playlist_renamed", offsetof(sp_playlist_callbacks, playlist_renamed),
                        sizeof(((sp_playlist_callbacks *)0)->playlist_renamed),
                        _CFFI_OP(_CFFI_OP_NOOP, 808) },
  { "playlist_state_changed", offsetof(sp_playlist_callbacks, playlist_state_changed),
                              sizeof(((sp_playlist_callbacks *)0)->playlist_state_changed),
                              _CFFI_OP(_CFFI_OP_NOOP, 808) },
  { "playlist_update_in_progress", offsetof(sp_playlist_callbacks, playlist_update_in_progress),
                                   sizeof(((sp_playlist_callbacks *)0)->playlist_update_in_progress),
                                   _CFFI_OP(_CFFI_OP_NOOP, 807) },
  { "playlist_metadata_updated", offsetof(sp_playlist_callbacks, playlist_metadata_updated),
                                 sizeof(((sp_playlist_callbacks *)0)->playlist_metadata_updated),
                                 _CFFI_OP(_CFFI_OP_NOOP, 808) },
  { "track_created_changed", offsetof(sp_playlist_callbacks, track_created_changed),
                             sizeof(((sp_playlist_callbacks *)0)->track_created_changed),
                             _CFFI_OP(_CFFI_OP_NOOP, 803) },
  { "track_seen_changed", offsetof(sp_playlist_callbacks, track_seen_changed),
                          sizeof(((sp_playlist_callbacks *)0)->track_seen_changed),
                          _CFFI_OP(_CFFI_OP_NOOP, 804) },
  { "description_changed", offsetof(sp_playlist_callbacks, description_changed),
                           sizeof(((sp_playlist_callbacks *)0)->description_changed),
                           _CFFI_OP(_CFFI_OP_NOOP, 799) },
  { "image_changed", offsetof(sp_playlist_callbacks, image_changed),
                     sizeof(((sp_playlist_callbacks *)0)->image_changed),
                     _CFFI_OP(_CFFI_OP_NOOP, 806) },
  { "track_message_changed", offsetof(sp_playlist_callbacks, track_message_changed),
                             sizeof(((sp_playlist_callbacks *)0)->track_message_changed),
                             _CFFI_OP(_CFFI_OP_NOOP, 802) },
  { "subscribers_changed", offsetof(sp_playlist_callbacks, subscribers_changed),
                           sizeof(((sp_playlist_callbacks *)0)->subscribers_changed),
                           _CFFI_OP(_CFFI_OP_NOOP, 808) },
  { "playlist_added", offsetof(sp_playlistcontainer_callbacks, playlist_added),
                      sizeof(((sp_playlistcontainer_callbacks *)0)->playlist_added),
                      _CFFI_OP(_CFFI_OP_NOOP, 810) },
  { "playlist_removed", offsetof(sp_playlistcontainer_callbacks, playlist_removed),
                        sizeof(((sp_playlistcontainer_callbacks *)0)->playlist_removed),
                        _CFFI_OP(_CFFI_OP_NOOP, 810) },
  { "playlist_moved", offsetof(sp_playlistcontainer_callbacks, playlist_moved),
                      sizeof(((sp_playlistcontainer_callbacks *)0)->playlist_moved),
                      _CFFI_OP(_CFFI_OP_NOOP, 809) },
  { "container_loaded", offsetof(sp_playlistcontainer_callbacks, container_loaded),
                        sizeof(((sp_playlistcontainer_callbacks *)0)->container_loaded),
                        _CFFI_OP(_CFFI_OP_NOOP, 811) },
  { "logged_in", offsetof(sp_session_callbacks, logged_in),
                 sizeof(((sp_session_callbacks *)0)->logged_in),
                 _CFFI_OP(_CFFI_OP_NOOP, 815) },
  { "logged_out", offsetof(sp_session_callbacks, logged_out),
                  sizeof(((sp_session_callbacks *)0)->logged_out),
                  _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "metadata_updated", offsetof(sp_session_callbacks, metadata_updated),
                        sizeof(((sp_session_callbacks *)0)->metadata_updated),
                        _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "connection_error", offsetof(sp_session_callbacks, connection_error),
                        sizeof(((sp_session_callbacks *)0)->connection_error),
                        _CFFI_OP(_CFFI_OP_NOOP, 815) },
  { "message_to_user", offsetof(sp_session_callbacks, message_to_user),
                       sizeof(((sp_session_callbacks *)0)->message_to_user),
                       _CFFI_OP(_CFFI_OP_NOOP, 813) },
  { "notify_main_thread", offsetof(sp_session_callbacks, notify_main_thread),
                          sizeof(((sp_session_callbacks *)0)->notify_main_thread),
                          _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "music_delivery", offsetof(sp_session_callbacks, music_delivery),
                      sizeof(((sp_session_callbacks *)0)->music_delivery),
                      _CFFI_OP(_CFFI_OP_NOOP, 763) },
  { "play_token_lost", offsetof(sp_session_callbacks, play_token_lost),
                       sizeof(((sp_session_callbacks *)0)->play_token_lost),
                       _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "log_message", offsetof(sp_session_callbacks, log_message),
                   sizeof(((sp_session_callbacks *)0)->log_message),
                   _CFFI_OP(_CFFI_OP_NOOP, 813) },
  { "end_of_track", offsetof(sp_session_callbacks, end_of_track),
                    sizeof(((sp_session_callbacks *)0)->end_of_track),
                    _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "streaming_error", offsetof(sp_session_callbacks, streaming_error),
                       sizeof(((sp_session_callbacks *)0)->streaming_error),
                       _CFFI_OP(_CFFI_OP_NOOP, 815) },
  { "userinfo_updated", offsetof(sp_session_callbacks, userinfo_updated),
                        sizeof(((sp_session_callbacks *)0)->userinfo_updated),
                        _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "start_playback", offsetof(sp_session_callbacks, start_playback),
                      sizeof(((sp_session_callbacks *)0)->start_playback),
                      _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "stop_playback", offsetof(sp_session_callbacks, stop_playback),
                     sizeof(((sp_session_callbacks *)0)->stop_playback),
                     _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "get_audio_buffer_stats", offsetof(sp_session_callbacks, get_audio_buffer_stats),
                              sizeof(((sp_session_callbacks *)0)->get_audio_buffer_stats),
                              _CFFI_OP(_CFFI_OP_NOOP, 814) },
  { "offline_status_updated", offsetof(sp_session_callbacks, offline_status_updated),
                              sizeof(((sp_session_callbacks *)0)->offline_status_updated),
                              _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "offline_error", offsetof(sp_session_callbacks, offline_error),
                     sizeof(((sp_session_callbacks *)0)->offline_error),
                     _CFFI_OP(_CFFI_OP_NOOP, 815) },
  { "credentials_blob_updated", offsetof(sp_session_callbacks, credentials_blob_updated),
                                sizeof(((sp_session_callbacks *)0)->credentials_blob_updated),
                                _CFFI_OP(_CFFI_OP_NOOP, 813) },
  { "connectionstate_updated", offsetof(sp_session_callbacks, connectionstate_updated),
                               sizeof(((sp_session_callbacks *)0)->connectionstate_updated),
                               _CFFI_OP(_CFFI_OP_NOOP, 812) },
  { "scrobble_error", offsetof(sp_session_callbacks, scrobble_error),
                      sizeof(((sp_session_callbacks *)0)->scrobble_error),
                      _CFFI_OP(_CFFI_OP_NOOP, 815) },
  { "private_session_mode_changed", offsetof(sp_session_callbacks, private_session_mode_changed),
                                    sizeof(((sp_session_callbacks *)0)->private_session_mode_changed),
                                    _CFFI_OP(_CFFI_OP_NOOP, 816) },
  { "api_version", offsetof(sp_session_config, api_version),
                   sizeof(((sp_session_config *)0)->api_version),
                   _CFFI_OP(_CFFI_OP_NOOP, 8) },
  { "cache_location", offsetof(sp_session_config, cache_location),
                      sizeof(((sp_session_config *)0)->cache_location),
                      _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "settings_location", offsetof(sp_session_config, settings_location),
                         sizeof(((sp_session_config *)0)->settings_location),
                         _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "application_key", offsetof(sp_session_config, application_key),
                       sizeof(((sp_session_config *)0)->application_key),
                       _CFFI_OP(_CFFI_OP_NOOP, 92) },
  { "application_key_size", offsetof(sp_session_config, application_key_size),
                            sizeof(((sp_session_config *)0)->application_key_size),
                            _CFFI_OP(_CFFI_OP_NOOP, 87) },
  { "user_agent", offsetof(sp_session_config, user_agent),
                  sizeof(((sp_session_config *)0)->user_agent),
                  _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "callbacks", offsetof(sp_session_config, callbacks),
                 sizeof(((sp_session_config *)0)->callbacks),
                 _CFFI_OP(_CFFI_OP_NOOP, 788) },
  { "userdata", offsetof(sp_session_config, userdata),
                sizeof(((sp_session_config *)0)->userdata),
                _CFFI_OP(_CFFI_OP_NOOP, 130) },
  { "compress_playlists", offsetof(sp_session_config, compress_playlists),
                          sizeof(((sp_session_config *)0)->compress_playlists),
                          _CFFI_OP(_CFFI_OP_NOOP, 220) },
  { "dont_save_metadata_for_playlists", offsetof(sp_session_config, dont_save_metadata_for_playlists),
                                        sizeof(((sp_session_config *)0)->dont_save_metadata_for_playlists),
                                        _CFFI_OP(_CFFI_OP_NOOP, 220) },
  { "initially_unload_playlists", offsetof(sp_session_config, initially_unload_playlists),
                                  sizeof(((sp_session_config *)0)->initially_unload_playlists),
                                  _CFFI_OP(_CFFI_OP_NOOP, 220) },
  { "device_id", offsetof(sp_session_config, device_id),
                 sizeof(((sp_session_config *)0)->device_id),
                 _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "proxy", offsetof(sp_session_config, proxy),
             sizeof(((sp_session_config *)0)->proxy),
             _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "proxy_username", offsetof(sp_session_config, proxy_username),
                      sizeof(((sp_session_config *)0)->proxy_username),
                      _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "proxy_password", offsetof(sp_session_config, proxy_password),
                      sizeof(((sp_session_config *)0)->proxy_password),
                      _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "tracefile", offsetof(sp_session_config, tracefile),
                 sizeof(((sp_session_config *)0)->tracefile),
                 _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "count", offsetof(sp_subscribers, count),
             sizeof(((sp_subscribers *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 798) },
  { "subscribers", offsetof(sp_subscribers, subscribers),
                   sizeof(((sp_subscribers *)0)->subscribers),
                   _CFFI_OP(_CFFI_OP_NOOP, 760) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "sp_album", 764, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_albumbrowse", 765, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_artist", 767, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_artistbrowse", 768, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_audio_buffer_stats", 769, _CFFI_F_CHECK_FIELDS,
    sizeof(sp_audio_buffer_stats), offsetof(struct _cffi_align__sp_audio_buffer_stats, y), 0, 2 },
  { "sp_audioformat", 770, _CFFI_F_CHECK_FIELDS,
    sizeof(sp_audioformat), offsetof(struct _cffi_align__sp_audioformat, y), 2, 3 },
  { "sp_image", 772, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_inbox", 774, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_link", 775, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_offline_sync_status", 777, _CFFI_F_CHECK_FIELDS,
    sizeof(sp_offline_sync_status), offsetof(struct _cffi_align__sp_offline_sync_status, y), 5, 9 },
  { "sp_playlist", 778, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_playlist_callbacks", 779, _CFFI_F_CHECK_FIELDS,
    sizeof(sp_playlist_callbacks), offsetof(struct _cffi_align__sp_playlist_callbacks, y), 14, 13 },
  { "sp_playlistcontainer", 782, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_playlistcontainer_callbacks", 783, _CFFI_F_CHECK_FIELDS,
    sizeof(sp_playlistcontainer_callbacks), offsetof(struct _cffi_align__sp_playlistcontainer_callbacks, y), 27, 4 },
  { "sp_search", 786, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_session", 787, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_session_callbacks", 789, 0,
    sizeof(sp_session_callbacks), offsetof(struct _cffi_align__sp_session_callbacks, y), 31, 21 },
  { "sp_session_config", 790, 0,
    sizeof(sp_session_config), offsetof(struct _cffi_align__sp_session_config, y), 52, 16 },
  { "sp_subscribers", 791, _CFFI_F_CHECK_FIELDS,
    sizeof(sp_subscribers), offsetof(struct _cffi_align__sp_subscribers, y), 68, 2 },
  { "sp_toplistbrowse", 792, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_track", 793, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "sp_user", 796, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "$sp_albumtype", 766, _cffi_prim_int(sizeof(sp_albumtype), ((sp_albumtype)-1) <= 0),
    "SP_ALBUMTYPE_ALBUM,SP_ALBUMTYPE_SINGLE,SP_ALBUMTYPE_COMPILATION,SP_ALBUMTYPE_UNKNOWN" },
  { "$sp_imageformat", 773, _cffi_prim_int(sizeof(sp_imageformat), ((sp_imageformat)-1) <= 0),
    "SP_IMAGE_FORMAT_UNKNOWN,SP_IMAGE_FORMAT_JPEG" },
  { "$sp_linktype", 776, _cffi_prim_int(sizeof(sp_linktype), ((sp_linktype)-1) <= 0),
    "SP_LINKTYPE_INVALID,SP_LINKTYPE_TRACK,SP_LINKTYPE_ALBUM,SP_LINKTYPE_ARTIST,SP_LINKTYPE_SEARCH,SP_LINKTYPE_PLAYLIST,SP_LINKTYPE_PROFILE,SP_LINKTYPE_STARRED,SP_LINKTYPE_LOCALTRACK,SP_LINKTYPE_IMAGE" },
  { "$sp_toplistregion", 492, _cffi_prim_int(sizeof(sp_toplistregion), ((sp_toplistregion)-1) <= 0),
    "SP_TOPLIST_REGION_EVERYWHERE,SP_TOPLIST_REGION_USER" },
  { "$sp_toplisttype", 491, _cffi_prim_int(sizeof(sp_toplisttype), ((sp_toplisttype)-1) <= 0),
    "SP_TOPLIST_TYPE_ARTISTS,SP_TOPLIST_TYPE_ALBUMS,SP_TOPLIST_TYPE_TRACKS" },
  { "sp_artistbrowse_type", 166, _cffi_prim_int(sizeof(sp_artistbrowse_type), ((sp_artistbrowse_type)-1) <= 0),
    "SP_ARTISTBROWSE_FULL,SP_ARTISTBROWSE_NO_TRACKS,SP_ARTISTBROWSE_NO_ALBUMS" },
  { "sp_availability", 794, _cffi_prim_int(sizeof(sp_track_availability), ((sp_track_availability)-1) <= 0),
    "SP_TRACK_AVAILABILITY_UNAVAILABLE,SP_TRACK_AVAILABILITY_AVAILABLE,SP_TRACK_AVAILABILITY_NOT_STREAMABLE,SP_TRACK_AVAILABILITY_BANNED_BY_ARTIST" },
  { "sp_bitrate", 294, _cffi_prim_int(sizeof(sp_bitrate), ((sp_bitrate)-1) <= 0),
    "SP_BITRATE_160k,SP_BITRATE_320k,SP_BITRATE_96k" },
  { "sp_connection_rules", 303, _cffi_prim_int(sizeof(sp_connection_rules), ((sp_connection_rules)-1) <= 0),
    "SP_CONNECTION_RULE_NETWORK,SP_CONNECTION_RULE_NETWORK_IF_ROAMING,SP_CONNECTION_RULE_ALLOW_SYNC_OVER_MOBILE,SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI" },
  { "sp_connection_type", 307, _cffi_prim_int(sizeof(sp_connection_type), ((sp_connection_type)-1) <= 0),
    "SP_CONNECTION_TYPE_UNKNOWN,SP_CONNECTION_TYPE_NONE,SP_CONNECTION_TYPE_MOBILE,SP_CONNECTION_TYPE_MOBILE_ROAMING,SP_CONNECTION_TYPE_WIFI,SP_CONNECTION_TYPE_WIRED" },
  { "sp_connectionstate", 771, _cffi_prim_int(sizeof(sp_connectionstate), ((sp_connectionstate)-1) <= 0),
    "SP_CONNECTION_STATE_LOGGED_OUT,SP_CONNECTION_STATE_LOGGED_IN,SP_CONNECTION_STATE_DISCONNECTED,SP_CONNECTION_STATE_UNDEFINED,SP_CONNECTION_STATE_OFFLINE" },
  { "sp_error", 17, _cffi_prim_int(sizeof(sp_error), ((sp_error)-1) <= 0),
    "SP_ERROR_OK,SP_ERROR_BAD_API_VERSION,SP_ERROR_API_INITIALIZATION_FAILED,SP_ERROR_TRACK_NOT_PLAYABLE,SP_ERROR_BAD_APPLICATION_KEY,SP_ERROR_BAD_USERNAME_OR_PASSWORD,SP_ERROR_USER_BANNED,SP_ERROR_UNABLE_TO_CONTACT_SERVER,SP_ERROR_CLIENT_TOO_OLD,SP_ERROR_OTHER_PERMANENT,SP_ERROR_BAD_USER_AGENT,SP_ERROR_MISSING_CALLBACK,SP_ERROR_INVALID_INDATA,SP_ERROR_INDEX_OUT_OF_RANGE,SP_ERROR_USER_NEEDS_PREMIUM,SP_ERROR_OTHER_TRANSIENT,SP_ERROR_IS_LOADING,SP_ERROR_NO_STREAM_AVAILABLE,SP_ERROR_PERMISSION_DENIED,SP_ERROR_INBOX_IS_FULL,SP_ERROR_NO_CACHE,SP_ERROR_NO_SUCH_USER,SP_ERROR_NO_CREDENTIALS,SP_ERROR_NETWORK_DISABLED,SP_ERROR_INVALID_DEVICE_ID,SP_ERROR_CANT_OPEN_TRACE_FILE,SP_ERROR_APPLICATION_BANNED,SP_ERROR_OFFLINE_TOO_MANY_TRACKS,SP_ERROR_OFFLINE_DISK_CACHE,SP_ERROR_OFFLINE_EXPIRED,SP_ERROR_OFFLINE_NOT_ALLOWED,SP_ERROR_OFFLINE_LICENSE_LOST,SP_ERROR_OFFLINE_LICENSE_ERROR,SP_ERROR_LASTFM_AUTH_ERROR,SP_ERROR_INVALID_ARGUMENT,SP_ERROR_SYSTEM_FAILURE" },
  { "sp_image_size", 397, _cffi_prim_int(sizeof(sp_image_size), ((sp_image_size)-1) <= 0),
    "SP_IMAGE_SIZE_NORMAL,SP_IMAGE_SIZE_SMALL,SP_IMAGE_SIZE_LARGE" },
  { "sp_playlist_offline_status", 780, _cffi_prim_int(sizeof(sp_playlist_offline_status), ((sp_playlist_offline_status)-1) <= 0),
    "SP_PLAYLIST_OFFLINE_STATUS_NO,SP_PLAYLIST_OFFLINE_STATUS_YES,SP_PLAYLIST_OFFLINE_STATUS_DOWNLOADING,SP_PLAYLIST_OFFLINE_STATUS_WAITING" },
  { "sp_playlist_type", 781, _cffi_prim_int(sizeof(sp_playlist_type), ((sp_playlist_type)-1) <= 0),
    "SP_PLAYLIST_TYPE_PLAYLIST,SP_PLAYLIST_TYPE_START_FOLDER,SP_PLAYLIST_TYPE_END_FOLDER,SP_PLAYLIST_TYPE_PLACEHOLDER" },
  { "sp_relation_type", 784, _cffi_prim_int(sizeof(sp_relation_type), ((sp_relation_type)-1) <= 0),
    "SP_RELATION_TYPE_UNKNOWN,SP_RELATION_TYPE_NONE,SP_RELATION_TYPE_UNIDIRECTIONAL,SP_RELATION_TYPE_BIDIRECTIONAL" },
  { "sp_sampletype", 785, _cffi_prim_int(sizeof(sp_sampletype), ((sp_sampletype)-1) <= 0),
    "SP_SAMPLETYPE_INT16_NATIVE_ENDIAN" },
  { "sp_scrobbling_state", 332, _cffi_prim_int(sizeof(sp_scrobbling_state), ((sp_scrobbling_state)-1) <= 0),
    "SP_SCROBBLING_STATE_USE_GLOBAL_SETTING,SP_SCROBBLING_STATE_LOCAL_ENABLED,SP_SCROBBLING_STATE_LOCAL_DISABLED,SP_SCROBBLING_STATE_GLOBAL_ENABLED,SP_SCROBBLING_STATE_GLOBAL_DISABLED" },
  { "sp_search_type", 482, _cffi_prim_int(sizeof(sp_search_type), ((sp_search_type)-1) <= 0),
    "SP_SEARCH_STANDARD,SP_SEARCH_SUGGEST" },
  { "sp_social_provider", 320, _cffi_prim_int(sizeof(sp_social_provider), ((sp_social_provider)-1) <= 0),
    "SP_SOCIAL_PROVIDER_SPOTIFY,SP_SOCIAL_PROVIDER_FACEBOOK,SP_SOCIAL_PROVIDER_LASTFM" },
  { "sp_track_offline_status", 795, _cffi_prim_int(sizeof(sp_track_offline_status), ((sp_track_offline_status)-1) <= 0),
    "SP_TRACK_OFFLINE_NO,SP_TRACK_OFFLINE_WAITING,SP_TRACK_OFFLINE_DOWNLOADING,SP_TRACK_OFFLINE_DONE,SP_TRACK_OFFLINE_ERROR,SP_TRACK_OFFLINE_DONE_EXPIRED,SP_TRACK_OFFLINE_LIMIT_EXCEEDED,SP_TRACK_OFFLINE_DONE_RESYNC" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "albumbrowse_complete_cb", 642 },
  { "artistbrowse_complete_cb", 646 },
  { "bool", 220 },
  { "byte", 220 },
  { "image_loaded_cb", 650 },
  { "inboxpost_complete_cb", 654 },
  { "search_complete_cb", 733 },
  { "sp_album", 764 },
  { "sp_albumbrowse", 765 },
  { "sp_albumtype", 766 },
  { "sp_artist", 767 },
  { "sp_artistbrowse", 768 },
  { "sp_artistbrowse_type", 166 },
  { "sp_audio_buffer_stats", 769 },
  { "sp_audioformat", 770 },
  { "sp_bitrate", 294 },
  { "sp_connection_rules", 303 },
  { "sp_connection_type", 307 },
  { "sp_connectionstate", 771 },
  { "sp_error", 17 },
  { "sp_image", 772 },
  { "sp_image_size", 397 },
  { "sp_imageformat", 773 },
  { "sp_inbox", 774 },
  { "sp_link", 775 },
  { "sp_linktype", 776 },
  { "sp_offline_sync_status", 777 },
  { "sp_playlist", 778 },
  { "sp_playlist_callbacks", 779 },
  { "sp_playlist_offline_status", 780 },
  { "sp_playlist_type", 781 },
  { "sp_playlistcontainer", 782 },
  { "sp_playlistcontainer_callbacks", 783 },
  { "sp_relation_type", 784 },
  { "sp_sampletype", 785 },
  { "sp_scrobbling_state", 332 },
  { "sp_search", 786 },
  { "sp_search_type", 482 },
  { "sp_session", 787 },
  { "sp_session_callbacks", 789 },
  { "sp_session_config", 790 },
  { "sp_social_provider", 320 },
  { "sp_subscribers", 791 },
  { "sp_toplistbrowse", 792 },
  { "sp_toplistregion", 492 },
  { "sp_toplisttype", 491 },
  { "sp_track", 793 },
  { "sp_track_availability", 794 },
  { "sp_track_offline_status", 795 },
  { "sp_uint64", 797 },
  { "sp_user", 796 },
  { "toplistbrowse_complete_cb", 756 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  352,  /* num_globals */
  22,  /* num_struct_unions */
  21,  /* num_enums */
  52,  /* num_typenames */
  NULL,  /* no includes */
  818,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__spotify(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__spotify(void) { return NULL; }
#  else
     init_spotify(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__spotify(void)
{
  return _cffi_init("spotify._spotify", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_spotify(void)
{
  _cffi_init("spotify._spotify", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
